@@ -221,10 +221,14 @@ public abstract class AJAXServlet extends HttpServlet implements UploadRegistry
 
     public static final String ACTION_LOGIN = "login";
 
+    public static final String ACTION_STORE = "store";
+
     public static final String ACTION_LOGOUT = "logout";
 
     public static final String ACTION_REDIRECT = "redirect";
-
+    
+    public static final String ACTION_REDEEM = "redeem";
+    
     public static final String ACTION_AUTOLOGIN = "autologin";
 
     public static final String ACTION_SAVE_VERSIT = "saveVersit";
@@ -333,6 +337,9 @@ public abstract class AJAXServlet extends HttpServlet implements UploadRegistry
     public static final String PARAMETER_TEMPLATE = "template";
     
     public static final String PARAMETER_UID = "uid";
+    
+    public static final String PARAMETER_SHOW_PRIVATE_APPOINTMENTS = "showPrivate";
+
 
     /**
      * The content type if the response body contains javascript data. Set it with
@@ -351,20 +358,19 @@ public abstract class AJAXServlet extends HttpServlet implements UploadRegistry
 
     private static final String STR_ERROR_PARAMS = "error_params";
 
-    // Javascript
-
-    public static final String JS_FRAGMENT =
-        "<!DOCTYPE HTML PUBLIC \"-//W3C//DTD HTML 4.01//EN\"" + "\"http://www.w3.org/TR/html4/strict.dtd\"><html><head>" + "<META http-equiv=\"Content-Type\" content=\"text/html; charset=UTF-8\"> " + "<script type=\"text/javascript\"> function callback(arg) { " + "parent.callback_**action**(arg); }; callback(**json**);</script></head></html> ";
-
-    protected static final String JS_FRAGMENT_POPUP =
-        "<!DOCTYPE HTML PUBLIC \"-//W3C//DTD HTML 4.01//EN\"" + "\"http://www.w3.org/TR/html4/strict.dtd\"><html><head>" + "<META http-equiv=\"Content-Type\" content=\"text/html; charset=UTF-8\"> " + "<script type=\"text/javascript\"> function callback(arg) { " + "window.opener.callback_**action**(arg); }; callback(**json**);</script></head></html> ";
-
+	// JavaScript for substituteJS()
+	private static final String JS_FRAGMENT = "<!DOCTYPE HTML PUBLIC "
+			+ "\"-//W3C//DTD HTML 4.01//EN\" "
+			+ "\"http://www.w3.org/TR/html4/strict.dtd\"><html><head>"
+			+ "<META http-equiv=\"Content-Type\" "
+			+ "content=\"text/html; charset=UTF-8\">"
+			+ "<script type=\"text/javascript\">"
+			+ "(parent.callback_**action** || window.opener && "
+			+ "window.opener.callback_**action**)(**json**)"
+			+ "</script></head></html>";
+	
     protected static final String SAVE_AS_TYPE = "application/octet-stream";
 
-    public static final String JS_FRAGMENT_JSON = "\\*\\*json\\*\\*";
-
-    public static final String JS_FRAGMENT_ACTION = "\\*\\*action\\*\\*";
-
     protected static final String _doGet = "doGet";
 
     protected static final String _doPut = "doPut";
@@ -555,7 +561,7 @@ public abstract class AJAXServlet extends HttpServlet implements UploadRegistry
             final JSONObject obj = new JSONObject();
             obj.put(STR_ERROR, error);
             obj.put(STR_ERROR_PARAMS, Collections.emptyList());
-            w.write(substitute(JS_FRAGMENT, "json", obj.toString(), "action", action));
+			w.write(substituteJS(obj.toString(), action));
         } catch (final JSONException e) {
             LOG.error(e);
         } finally {
@@ -599,24 +605,10 @@ public abstract class AJAXServlet extends HttpServlet implements UploadRegistry
         sendErrorAsJS(res, msg);
     }
 
-    public static String substitute(final String text, final String... substitutions) {
-        String s = text;
-        assert (substitutions.length % 2 == 0);
-        for (int i = 0; i < substitutions.length; i++) {
-            final String key = substitutions[i];
-            String value = substitutions[++i];
-            value = value.replaceAll("\\\\", "\\\\\\\\"); // fix for 7583:
-            // replaces \ with
-            // \\, because \\ is
-            // later replaced
-            // with \ in
-            // String.replaceAll()
-            value = value.replaceAll("\\$", "\\\\\\$"); // Escape-O-Rama. Turn
-            // all $ in \$
-            s = s.replaceAll("\\*\\*" + key + "\\*\\*", value);
-        }
-        return s;
-    }
+	public static String substituteJS(final String json, final String action) {
+		return JS_FRAGMENT.replace("**json**", json).replace("**action**",
+				action);
+	}
 
     /* --------------------- STUFF FOR UPLOAD --------------------- */
 
@@ -685,6 +677,7 @@ public abstract class AJAXServlet extends HttpServlet implements UploadRegistry
     private static final Set<String> UPLOAD_ACTIONS =
         new HashSet<String>(Arrays.asList(ACTION_NEW, ACTION_UPLOAD, ACTION_APPEND, ACTION_UPDATE, ACTION_ATTACH, ACTION_COPY));
 
+
     /**
      * (Statically) Processes specified request's upload provided that request is of content type <code>multipart/*</code>.
      * 
@@ -847,13 +840,13 @@ public abstract class AJAXServlet extends HttpServlet implements UploadRegistry
          */
     }
 
-    protected void writeResponse(final Response response, final HttpServletResponse httpServletResponse) throws IOException {
-        httpServletResponse.setContentType(CONTENTTYPE_JAVASCRIPT);
+    protected void writeResponse(final Response response, final HttpServletResponse servletResponse) throws IOException {
+        servletResponse.setContentType(CONTENTTYPE_JAVASCRIPT);
         try {
-            ResponseWriter.write(response, httpServletResponse.getWriter());
+            ResponseWriter.write(response, servletResponse.getWriter());
         } catch (final JSONException e) {
             log(RESPONSE_ERROR, e);
-            sendError(httpServletResponse);
+            sendError(servletResponse);
         }
     }
 
