@@ -166,7 +166,7 @@ public class Attachment extends PermissionServlet {
         try {
             session = new ServerSessionAdapter(getSessionObject(req));
         } catch (final ContextException e) {
-            handle(res, e, action, JS_FRAGMENT_POPUP);
+            handle(res, e, action);
             return;
         }
 
@@ -180,7 +180,7 @@ public class Attachment extends PermissionServlet {
             try {
                 require(req, res, PARAMETER_FOLDERID, PARAMETER_ATTACHEDID, PARAMETER_MODULE, PARAMETER_ID);
             } catch (final UploadException e) {
-                handle(res, e, action, JS_FRAGMENT_POPUP);
+                handle(res, e, action);
                 return;
             }
             int folderId, attachedId, moduleId, id;
@@ -214,6 +214,7 @@ public class Attachment extends PermissionServlet {
             if (!attRequest.action(action, new ServletRequestAdapter(req, res))) {
                 unknownAction("GET", action, res, false);
             }
+            res.setContentType(AJAXServlet.CONTENTTYPE_JAVASCRIPT);
             try {
                 ((JSONObject) writer.getObject()).write(res.getWriter());
             } catch (final JSONException e) {
@@ -236,7 +237,7 @@ public class Attachment extends PermissionServlet {
             return Integer.parseInt(value);
         } catch (final NumberFormatException nfe) {
             final AttachmentException t = EXCEPTIONS.create(1, parameter, value);
-            handle(res, t, action, contentType == null ? JS_FRAGMENT_POPUP : null);
+            handle(res, t, action);
             throw new OXAborted();
         }
     }
@@ -254,7 +255,7 @@ public class Attachment extends PermissionServlet {
         try {
             session = new ServerSessionAdapter(getSessionObject(req));
         } catch (final ContextException e) {
-            handle(res, e, action, JS_FRAGMENT_POPUP);
+            handle(res, e, action);
             return;
         }
 
@@ -263,6 +264,7 @@ public class Attachment extends PermissionServlet {
         if (!attRequest.action(action, new ServletRequestAdapter(req, res))) {
             unknownAction("PUT", action, res, false);
         }
+        res.setContentType(AJAXServlet.CONTENTTYPE_JAVASCRIPT);
         try {
             ((JSONObject) writer.getObject()).write(res.getWriter());
         } catch (final JSONException e) {
@@ -292,7 +294,7 @@ public class Attachment extends PermissionServlet {
         try {
             session = new ServerSessionAdapter(getSessionObject(req));
         } catch (final ContextException e) {
-            handle(res, e, action, JS_FRAGMENT_POPUP);
+            handle(res, e, action);
             return;
         }
 
@@ -342,7 +344,7 @@ public class Attachment extends PermissionServlet {
                         // session.getUserId(), session.getContext()));
                         checkSize(sum);
                     }
-                    attach(res, attachments, uploadFiles, ctx, user, userConfig);
+                    attach(res, attachments, uploadFiles, session, ctx, user, userConfig);
                 } finally {
                     if (upload != null) {
                         upload.cleanUp();
@@ -355,12 +357,9 @@ public class Attachment extends PermissionServlet {
             try {
                 res.setContentType(MIME_TEXT_HTML_CHARSET_UTF8);
 
-                throw new UploadServletException(res, substitute(
-                    JS_FRAGMENT,
-                    "json",
-                    ResponseWriter.getJSON(resp).toString(),
-                    "action",
-                    "error"), x.getMessage(), x);
+				throw new UploadServletException(res, substituteJS(
+						ResponseWriter.getJSON(resp).toString(), "error"),
+						x.getMessage(), x);
             } catch (final JSONException e) {
                 LOG.error("Giving up", e);
             }
@@ -438,7 +437,7 @@ public class Attachment extends PermissionServlet {
             // in a new window. To call the JS callback routine from a popup we
             // can use parent.callback_error() but
             // must use window.opener.callback_error()
-            rollback(t, res, ResponseFields.ERROR, contentType == null ? JS_FRAGMENT_POPUP : null);
+			rollback(t, res, ResponseFields.ERROR);
             return;
         } finally {
             if (documentData != null) {
@@ -466,20 +465,20 @@ public class Attachment extends PermissionServlet {
         }
     }
 
-    private void rollback(final Throwable t, final HttpServletResponse res, final String action, final String fragmentOverride) {
+    private void rollback(final Throwable t, final HttpServletResponse res, final String action) {
         try {
             ATTACHMENT_BASE.rollback();
         } catch (final TransactionException e) {
             LOG.debug("", e);
         }
         if (t instanceof AbstractOXException) {
-            handle(res, (AbstractOXException) t, action, fragmentOverride);
+            handle(res, (AbstractOXException) t, action);
         } else {
-            handle(res, new OXException(t), action, fragmentOverride);
+            handle(res, new OXException(t), action);
         }
     }
 
-    private void attach(final HttpServletResponse res, final List<AttachmentMetadata> attachments, final List<UploadFile> uploadFiles, final Context ctx, final User user, final UserConfiguration userConfig) {
+    private void attach(final HttpServletResponse res, final List<AttachmentMetadata> attachments, final List<UploadFile> uploadFiles, ServerSession session, final Context ctx, final User user, final UserConfiguration userConfig) {
         initAttachments(attachments, uploadFiles);
         PrintWriter w = null;
         try {
@@ -500,7 +499,7 @@ public class Attachment extends PermissionServlet {
                 attachment.setId(AttachmentBase.NEW);
 
                 final long modified = ATTACHMENT_BASE.attachToObject(attachment, new BufferedInputStream(new FileInputStream(
-                    uploadFile.getTmpFile())), ctx, user, userConfig);
+                    uploadFile.getTmpFile())), session, ctx, user, userConfig);
                 if (modified > timestamp) {
                     timestamp = modified;
                 }
@@ -510,7 +509,7 @@ public class Attachment extends PermissionServlet {
             result.put(ResponseFields.DATA, arr);
             result.put(ResponseFields.TIMESTAMP, timestamp);
             w = res.getWriter();
-            w.print(substitute(JS_FRAGMENT, "json", result.toString(), "action", ACTION_ATTACH));
+			w.print(substituteJS(result.toString(), ACTION_ATTACH));
             ATTACHMENT_BASE.commit();
         } catch (final OXException t) {
             try {
@@ -518,7 +517,7 @@ public class Attachment extends PermissionServlet {
             } catch (final TransactionException e) {
                 LOG.error(e);
             }
-            handle(res, t, ResponseFields.ERROR, null);
+            handle(res, t, ResponseFields.ERROR);
             return;
         } catch (final JSONException e) {
             try {
@@ -526,7 +525,7 @@ public class Attachment extends PermissionServlet {
             } catch (final TransactionException x) {
                 LOG.error(e);
             }
-            handle(res, new OXException(e), ResponseFields.ERROR, null);
+            handle(res, new OXException(e), ResponseFields.ERROR);
             return;
         } catch (final IOException e) {
             try {
@@ -534,7 +533,7 @@ public class Attachment extends PermissionServlet {
             } catch (final TransactionException x) {
                 LOG.error(e);
             }
-            handle(res, new OXException(e), ResponseFields.ERROR, null);
+            handle(res, new OXException(e), ResponseFields.ERROR);
             return;
         } finally {
             try {
@@ -579,7 +578,7 @@ public class Attachment extends PermissionServlet {
         }
     }
 
-    private void handle(final HttpServletResponse res, final AbstractOXException t, final String action, final String fragmentOverride) {
+    private void handle(final HttpServletResponse res, final AbstractOXException t, final String action) {
         LL.log(t);
 
         res.setContentType(MIME_TEXT_HTML_CHARSET_UTF8);
@@ -591,8 +590,7 @@ public class Attachment extends PermissionServlet {
         try {
             writer = new UnsynchronizedStringWriter();
             ResponseWriter.write(resp, writer);
-            res.getWriter().write(
-                substitute((fragmentOverride != null) ? fragmentOverride : JS_FRAGMENT, "json", writer.toString(), "action", action));
+			res.getWriter().write(substituteJS(writer.toString(), action));
         } catch (final JSONException e) {
             LOG.error("", t);
         } catch (final IOException e) {
