@@ -105,7 +105,6 @@ import com.openexchange.mail.mime.MIMEType2ExtMap;
 import com.openexchange.mail.usersetting.UserSettingMail;
 import com.openexchange.mail.usersetting.UserSettingMailStorage;
 import com.openexchange.tools.UnsynchronizedStringWriter;
-import com.openexchange.tools.encoding.Helper;
 import com.openexchange.tools.exceptions.LoggingLogic;
 import com.openexchange.tools.servlet.UploadServletException;
 import com.openexchange.tools.servlet.http.Tools;
@@ -184,13 +183,13 @@ public class Infostore extends PermissionServlet {
                     throw se;
                 }
                 res.setContentType(MIME_TEXT_HTML);
-                res.getWriter().write(substitute(JS_FRAGMENT, STR_ACTION, STR_ERROR, STR_JSON, w.toString()));
+                res.getWriter().write(substituteJS(w.toString(), STR_ERROR));
             }
             int id;
             try {
                 id = Integer.valueOf(req.getParameter(PARAMETER_ID));
             } catch (final NumberFormatException x) {
-                handleOXException(res, new AbstractOXException("Invalid number"), STR_ERROR, true, JS_FRAGMENT);
+                handleOXException(res, new AbstractOXException("Invalid number"), STR_ERROR, true);
                 return;
             }
 
@@ -199,7 +198,7 @@ public class Infostore extends PermissionServlet {
 
             final String contentType = req.getParameter(PARAMETER_CONTENT_TYPE);
 
-            document(res, req.getHeader("user-agent"), isIE(req), isIE7(req), id, version, contentType, ctx, user, userConfig);
+            document(res, req.getHeader("user-agent"), id, version, contentType, ctx, user, userConfig);
 
             return;
         }
@@ -336,36 +335,26 @@ public class Infostore extends PermissionServlet {
                 }
             }
         } catch (final OXException x) {
-            handleOXException(res, x, action, true, null);
+            handleOXException(res, x, action, true);
         } catch (final UploadException x) {
             final Response resp = new Response();
             resp.setException(new AbstractOXException(x.getMessage())); // FIXME
             try {
                 res.setContentType("text/html; charset=UTF-8");
-
-                throw new UploadServletException(res, substitute(
-                    JS_FRAGMENT,
-                    STR_JSON,
-                    ResponseWriter.getJSON(resp).toString(),
-                    STR_ACTION,
-                    action), x.getMessage(), x);
+                throw new UploadServletException(res, substituteJS(
+                        ResponseWriter.getJSON(resp).toString(), action),
+                        x.getMessage(), x);
             } catch (final JSONException e) {
                 LOG.error("Giving up", e);
             }
-        } catch (final JSONException e) {
-            handleOXException(res, e, action, true, null);
         } catch (final Throwable t) {
             final Response resp = new Response();
             resp.setException(new AbstractOXException(t.getMessage())); // FIXME
             try {
                 res.setContentType("text/html; charset=UTF-8");
-
-                throw new UploadServletException(res, substitute(
-                    JS_FRAGMENT,
-                    STR_JSON,
-                    ResponseWriter.getJSON(resp).toString(),
-                    STR_ACTION,
-                    action), t.getMessage(), t);
+                throw new UploadServletException(res, substituteJS(
+                        ResponseWriter.getJSON(resp).toString(), action),
+                        t.getMessage(), t);
             } catch (final JSONException e) {
                 LOG.error("Giving up", e);
             }
@@ -445,7 +434,7 @@ public class Infostore extends PermissionServlet {
             w = res.getWriter();
             final JSONObject obj = new JSONObject();
             obj.put(ResponseFields.DATA, newDocument.getId());
-            w.print(substitute(JS_FRAGMENT, STR_JSON, obj.toString(), STR_ACTION, ACTION_NEW));
+            w.print(substituteJS(obj.toString(), ACTION_NEW));
 
             w.flush();
         } catch (final IOException e) {
@@ -512,7 +501,7 @@ public class Infostore extends PermissionServlet {
         PrintWriter w = null;
         try {
             w = res.getWriter();
-            w.write(substitute(JS_FRAGMENT, STR_JSON, "{}", STR_ACTION, ACTION_UPDATE));
+            w.write(substituteJS("{}", ACTION_UPDATE));
             close(w);
         } catch (final IOException e) {
             LOG.warn(e);
@@ -583,7 +572,7 @@ public class Infostore extends PermissionServlet {
             w = res.getWriter();
             final JSONObject obj = new JSONObject();
             obj.put(ResponseFields.DATA, metadata.getId());
-            w.print(substitute(JS_FRAGMENT, STR_JSON, obj.toString(), STR_ACTION, ACTION_NEW));
+            w.print(substituteJS(obj.toString(), ACTION_NEW));
             w.flush();
         } catch (final IOException e) {
             LOG.debug("", e);
@@ -594,7 +583,7 @@ public class Infostore extends PermissionServlet {
         }
     }
 
-    protected void document(final HttpServletResponse res, final String userAgent, final boolean ie, final boolean ie7, final int id, final int version, final String contentType, final Context ctx, final User user, final UserConfiguration userConfig) throws IOException {
+    protected void document(final HttpServletResponse res, final String userAgent, final int id, final int version, final String contentType, final Context ctx, final User user, final UserConfiguration userConfig) throws IOException {
         final InfostoreFacade infostore = getInfostore();
         OutputStream os = null;
         InputStream documentData = null;
@@ -606,10 +595,7 @@ public class Infostore extends PermissionServlet {
 
             res.setContentLength((int) metadata.getFileSize());
             if (SAVE_AS_TYPE.equals(contentType)) {
-                res.setHeader("Content-Disposition", "attachment; filename=\"" + Helper.escape(Helper.encodeFilename(
-                    metadata.getFileName(),
-                    "UTF-8",
-                    ie)) + "\"");
+                Tools.setHeaderForFileDownload(userAgent, res, metadata.getFileName());
                 res.setContentType(contentType);
             } else {
                 final CheckedDownload checkedDownload = DownloadUtility.checkInlineDownload(
@@ -637,7 +623,7 @@ public class Infostore extends PermissionServlet {
 
         } catch (final AbstractOXException x) {
             LOG.debug(x.getMessage(), x);
-            handleOXException(res, x, STR_ERROR, true, JS_FRAGMENT);
+            handleOXException(res, x, STR_ERROR, true);
             return;
         } finally {
 
@@ -663,40 +649,34 @@ public class Infostore extends PermissionServlet {
         }
     }
 
-    private final boolean handleOXException(final HttpServletResponse res, final Throwable t, final String action, final boolean post, final String fragmentOverride) {
+    private final boolean handleOXException(final HttpServletResponse res, final Throwable t, final String action, final boolean post) {
         res.setContentType("text/html; charset=UTF-8");
+        final AbstractOXException e;
         if (t instanceof AbstractOXException) {
-            final Response resp = new Response();
-            resp.setException((AbstractOXException) t);
-            Writer writer = null;
-
-            try {
-                if (post) {
-                    writer = new UnsynchronizedStringWriter();
-                } else {
-                    writer = res.getWriter();
-                }
-                ResponseWriter.write(resp, writer);
-                if (post) {
-                    res.getWriter().write(
-                        substitute(
-                            fragmentOverride != null ? fragmentOverride : JS_FRAGMENT,
-                            STR_JSON,
-                            writer.toString(),
-                            STR_ACTION,
-                            action));
-                }
-            } catch (final JSONException e) {
-                LOG.error("", t);
-            } catch (final IOException e) {
-                LOG.error("", e);
-            }
-
-            LL.log((AbstractOXException) t);
-
-            return true;
+            e = (AbstractOXException) t;
+        } else {
+            e = new AbstractOXException(t); 
         }
-        return false;
+        final Response resp = new Response();
+        resp.setException(e);
+        Writer writer = null;
+        try {
+            if (post) {
+                writer = new UnsynchronizedStringWriter();
+            } else {
+                writer = res.getWriter();
+            }
+            ResponseWriter.write(resp, writer);
+            if (post) {
+                res.getWriter().write(substituteJS(writer.toString(), action));
+            }
+        } catch (final JSONException e1) {
+            LOG.error("", t);
+        } catch (final IOException e1) {
+            LOG.error("", e);
+        }
+        LL.log((AbstractOXException) t);
+        return true;
     }
 
     protected void sendErrorAsJS(final PrintWriter w, final String error, final String... errorParams) {
@@ -767,7 +747,7 @@ public class Infostore extends PermissionServlet {
                 LOG.error("", e);
             }
         }
-        if (!handleOXException(res, t, action, post, null)) {
+        if (!handleOXException(res, t, action, post)) {
             try {
                 sendErrorAsJSHTML(res, t.toString(), action);
                 LOG.error("Got non OXException", t);
