@@ -52,6 +52,9 @@ package com.openexchange.ajax;
 import static com.openexchange.login.Interface.HTTP_JSON;
 import java.io.IOException;
 import java.lang.reflect.UndeclaredThrowableException;
+import java.util.ArrayList;
+import java.util.Collections;
+import java.util.List;
 import java.util.UUID;
 import javax.servlet.ServletConfig;
 import javax.servlet.ServletException;
@@ -66,11 +69,13 @@ import com.openexchange.ajax.container.Response;
 import com.openexchange.ajax.fields.Header;
 import com.openexchange.ajax.fields.LoginFields;
 import com.openexchange.ajax.helper.Send;
+import com.openexchange.ajax.login.HashCalculator;
 import com.openexchange.ajax.writer.LoginWriter;
 import com.openexchange.ajax.writer.ResponseWriter;
-import com.openexchange.ajp13.AJPv13RequestHandler;
 import com.openexchange.authentication.LoginException;
 import com.openexchange.authentication.LoginExceptionCodes;
+import com.openexchange.config.ConfigTools;
+import com.openexchange.config.ConfigurationService;
 import com.openexchange.configuration.ServerConfig;
 import com.openexchange.groupware.AbstractOXException;
 import com.openexchange.groupware.contexts.Context;
@@ -89,6 +94,7 @@ import com.openexchange.server.services.ServerServiceRegistry;
 import com.openexchange.session.Session;
 import com.openexchange.sessiond.SessiondService;
 import com.openexchange.sessiond.exception.SessiondException;
+import com.openexchange.sessiond.impl.IPRange;
 import com.openexchange.tools.servlet.AjaxException;
 import com.openexchange.tools.servlet.OXJSONException;
 import com.openexchange.tools.servlet.http.Tools;
@@ -96,7 +102,7 @@ import com.openexchange.tools.session.ServerSessionAdapter;
 
 /**
  * Servlet doing the login and logout stuff.
- *
+ * 
  * @author <a href="mailto:marcus.klein@open-xchange.com">Marcus Klein</a>
  */
 public class Login extends AJAXServlet {
@@ -107,13 +113,15 @@ public class Login extends AJAXServlet {
 
     private static final String PARAM_PASSWORD = "password";
 
-    private static final String REDIRECT_URL = "/index.html#id=";
+    private static final String PARAM_UI_WEB_PATH = "uiWebPath";
 
-    public static final String COOKIE_PREFIX = "open-xchange-session-";
+    public static final String SESSION_PREFIX = "open-xchange-session-";
+
+    public static final String SECRET_PREFIX = "open-xchange-secret-";
 
     private static final Log LOG = LogFactory.getLog(Login.class);
 
-    private boolean checkIP = true;
+    private String uiWebPath;
 
     public Login() {
         super();
@@ -122,7 +130,7 @@ public class Login extends AJAXServlet {
     @Override
     public void init(ServletConfig config) throws ServletException {
         super.init(config);
-        checkIP = Boolean.parseBoolean(config.getInitParameter(ServerConfig.Property.IP_CHECK.getPropertyName()));
+        uiWebPath = config.getInitParameter(ServerConfig.Property.UI_WEB_PATH.getPropertyName());
     }
 
     @Override
@@ -140,6 +148,16 @@ public class Login extends AJAXServlet {
                 logAndSendException(resp, e);
                 return;
             }
+        } else if (ACTION_STORE.equals(action)) {
+            try {
+                doStore(req, resp);
+            } catch (AbstractOXException e) {
+                logAndSendException(resp, e);
+                return;
+            } catch (JSONException e) {
+                log(RESPONSE_ERROR, e);
+                sendError(resp);
+            }
         } else if (ACTION_LOGOUT.equals(action)) {
             // The magic spell to disable caching
             Tools.disableCaching(resp);
@@ -148,42 +166,16 @@ public class Login extends AJAXServlet {
                 resp.sendError(HttpServletResponse.SC_BAD_REQUEST);
                 return;
             }
-            // Drop relevant cookies
-            String secret = null;
-            final Cookie[] cookies = req.getCookies();
-            if (cookies != null) {
-                final String cookieName = new StringBuilder(Login.COOKIE_PREFIX).append(sessionId).toString();
-                int stat = 0;
-                for (int a = 0; a < cookies.length && stat != 3; a++) {
-                    if (cookieName.equals(cookies[a].getName())) {
-                        secret = cookies[a].getValue();
-                        final Cookie respCookie = new Cookie(cookieName, secret);
-                        respCookie.setPath("/");
-                        respCookie.setMaxAge(0); // delete
-                        resp.addCookie(respCookie);
-                        stat |= 1;
-                    } else if (AJPv13RequestHandler.JSESSIONID_COOKIE.equals(cookies[a].getName())) {
-                        final Cookie jsessionIdCookie = new Cookie(AJPv13RequestHandler.JSESSIONID_COOKIE, cookies[a].getValue());
-                        jsessionIdCookie.setPath("/");
-                        jsessionIdCookie.setMaxAge(0); // delete
-                        resp.addCookie(jsessionIdCookie);
-                        stat |= 2;
-                    }
+            try {
+                Session session = LoginPerformer.getInstance().doLogout(sessionId);
+                if(session != null) {
+                    // Drop relevant cookies
+                    SessionServlet.removeOXCookies(session.getHash(), req, resp);
                 }
+            } catch (final LoginException e) {
+                LOG.error("Logout failed", e);
             }
-            if (secret == null) {
-                if (LOG.isDebugEnabled()) {
-                    LOG.debug("no session cookie found in request!");
-                }
-            } else {
-                // Do logout
-                try {
-                    LoginPerformer.getInstance().doLogout(sessionId);
-                } catch (final LoginException e) {
-                    LOG.error("Logout failed", e);
-                }
-            }
-        } else if (ACTION_REDIRECT.equals(action)) {
+        } else if (ACTION_REDIRECT.equals(action) || ACTION_REDEEM.equals(action)) {
             // The magic spell to disable caching
             Tools.disableCaching(resp);
             final String randomToken = req.getParameter(LoginFields.PARAM_RANDOM);
@@ -214,31 +206,118 @@ public class Login extends AJAXServlet {
                 final User user = UserStorage.getInstance().getUser(session.getUserId(), context);
                 if (!context.isEnabled() || !user.isMailEnabled()) {
                     resp.sendError(HttpServletResponse.SC_FORBIDDEN);
+                    return;
                 }
             } catch (final UndeclaredThrowableException e) {
                 resp.sendError(HttpServletResponse.SC_FORBIDDEN);
+                return;
             } catch (final ContextException e) {
                 resp.sendError(HttpServletResponse.SC_FORBIDDEN);
+                return;
             } catch (final LdapException e) {
                 resp.sendError(HttpServletResponse.SC_FORBIDDEN);
+                return;
+            }
+
+            session.setHash(HashCalculator.getHash(req));
+            
+            String oldIP = session.getLocalIp();
+            String newIP = req.getRemoteAddr();
+            if (!newIP.equals(oldIP)) {
+                LOG.info("Updating sessions IP address. authID: " + session.getAuthId() + ", sessionID" + session.getSessionID() + " old ip: " + oldIP + " new ip: " + newIP);
+                session.setLocalIp(newIP);
+            }
+            
+            writeSecretCookie(resp, session, req.isSecure());
+
+            if(ACTION_REDIRECT.equals(action)) {
+                String usedUIWebPath = req.getParameter(PARAM_UI_WEB_PATH);
+                if (null == usedUIWebPath) {
+                    usedUIWebPath = uiWebPath;
+                }
+                // Prevent HTTP response splitting.
+                usedUIWebPath = usedUIWebPath.replaceAll("[\n\r]", "");
+                usedUIWebPath = addFragmentParameter(usedUIWebPath, PARAMETER_SESSION, session.getSessionID());
+                String shouldStore = req.getParameter("store");
+                if(shouldStore != null) {
+                    usedUIWebPath = addFragmentParameter(usedUIWebPath, "store", shouldStore);
+                }
+                resp.sendRedirect(usedUIWebPath);
+            } else {
+                try {
+                    JSONObject json = new JSONObject();
+                    new LoginWriter().writeLogin(session, json);
+                    json.write(resp.getWriter());
+                } catch (JSONException e) {
+                    log(RESPONSE_ERROR, e);
+                    sendError(resp);
+                }
             }
-            writeCookie(resp, session);
-            resp.sendRedirect(REDIRECT_URL + session.getSessionID());
         } else if (ACTION_AUTOLOGIN.equals(action)) {
-            final Cookie[] cookies = req.getCookies();
             final Response response = new Response();
+            Session session = null;
             try {
+                if (!isAutologinEnabled()) {
+                    throw new AjaxException(AjaxException.Code.DisabledAction, "autologin");
+                }
+
+                final Cookie[] cookies = req.getCookies();
+                String hash = HashCalculator.getHash(req);
+
                 if (cookies == null) {
                     throw new OXJSONException(OXJSONException.Code.INVALID_COOKIE);
                 }
                 final SessiondService sessiondService = ServerServiceRegistry.getInstance().getService(SessiondService.class);
+
+                String secret = null;
+
+                String sessionCookieName = SESSION_PREFIX + hash;
+                String secretCookieName = SECRET_PREFIX + hash;
+
                 for (final Cookie cookie : cookies) {
                     final String cookieName = cookie.getName();
-                    if (cookieName.startsWith(COOKIE_PREFIX)) {
-                        final String sessionId = cookieName.substring(COOKIE_PREFIX.length(), cookieName.length());
+                    if (cookieName.startsWith(sessionCookieName)) {
+                        final String sessionId = cookie.getValue();
                         if (sessiondService.refreshSession(sessionId)) {
-                            final Session session = sessiondService.getSession(sessionId);
-                            SessionServlet.checkIP(checkIP, session, req.getRemoteAddr());
+                            session = sessiondService.getSession(sessionId);
+                            String oldIP = session.getLocalIp();
+                            String newIP = req.getRemoteAddr();
+                            if (!newIP.equals(oldIP)) {
+                                final ConfigurationService configurationService = ServerServiceRegistry.getInstance().getService(ConfigurationService.class);
+                                if (configurationService == null) {
+                                    LOG.fatal("No configuration service available, can not read whitelist");
+                                    LOG.info("Updating sessions IP address. authID: " + session.getAuthId() + ", sessionID: " + session.getSessionID() + " old ip: " + oldIP + " new ip: " + newIP);
+                                    session.setLocalIp(newIP);
+                                } else {
+                                    if (configurationService.getBoolProperty("com.openexchange.IPCheck", true)) { //IP-Check
+                                        final List<IPRange> ranges;
+                                        {
+                                            String text = configurationService.getText("noipcheck.cnf");
+                                            if (text == null) {
+                                                ranges = Collections.emptyList();
+                                            } else {
+                                                ranges = new ArrayList<IPRange>(5);
+                                                String[] lines = text.split("\n");
+                                                for (String line : lines) {
+                                                    line = line.replaceAll("\\s", "");
+                                                    if (!line.equals("") && !line.startsWith("#")) {
+                                                        ranges.add(IPRange.parseRange(line));
+                                                    }
+                                                }
+                                            }
+                                        }
+                                        final SessiondException exception = SessionServlet.checkIP(true, ranges, session, newIP);
+                                        if (null != exception) {
+                                            throw exception;
+                                        }
+                                        LOG.info("Updating sessions IP address. authID: " + session.getAuthId() + ", sessionID: " + session.getSessionID() + " old ip: " + oldIP + " new ip: " + newIP);
+                                        session.setLocalIp(newIP);
+                                    } else {
+                                        LOG.info("Updating sessions IP address. authID: " + session.getAuthId() + ", sessionID: " + session.getSessionID() + " old ip: " + oldIP + " new ip: " + newIP);
+                                        session.setLocalIp(newIP);
+                                    }
+                                }
+                            }
                             try {
                                 final Context ctx = ContextStorage.getInstance().getContext(session.getContextId());
                                 final User user = UserStorage.getInstance().getUser(session.getUserId(), ctx);
@@ -251,19 +330,31 @@ public class Login extends AJAXServlet {
                             JSONObject json = new JSONObject();
                             new LoginWriter().writeLogin(session, json);
                             response.setData(json);
-                            break;
                         }
-                        // Not found session. Delete old OX cookie.
-                        final Cookie respCookie = new Cookie(cookie.getName(), cookie.getValue());
-                        respCookie.setPath("/");
-                        respCookie.setMaxAge(0); // delete
-                        resp.addCookie(respCookie);
+                    } else if (cookieName.startsWith(secretCookieName)) {
+                        secret = cookie.getValue();
                     }
                 }
-                if (null == response.getData()) {
+                if (null == response.getData() || session == null || secret == null || !(session.getSecret().equals(secret))) {
+                    SessionServlet.removeOXCookies(hash, req, resp);
                     throw new OXJSONException(OXJSONException.Code.INVALID_COOKIE);
                 }
             } catch (final SessiondException e) {
+                LOG.debug(e.getMessage(), e);
+                if (null != session) {
+                    try {
+                        /*
+                         * Drop Open-Xchange cookies
+                         */
+                        final SessiondService sessiondService = ServerServiceRegistry.getInstance().getService(SessiondService.class);
+                        SessionServlet.removeOXCookies(session.getHash(), req, resp);
+                        sessiondService.removeSession(session.getSessionID());
+                    } catch (final Exception e2) {
+                        LOG.error("Cookies could not be removed.", e2);
+                    }
+                }
+                response.setException(e);
+            } catch (final AjaxException e) {
                 LOG.debug(e.getMessage(), e);
                 response.setException(e);
             } catch (final OXJSONException e) {
@@ -306,7 +397,56 @@ public class Login extends AJAXServlet {
         }
     }
 
-    private void logAndSendException(final HttpServletResponse resp, final AjaxException e) throws IOException {
+    protected String addFragmentParameter(String usedUIWebPath, String param, String value) {
+        int fragIndex = usedUIWebPath.indexOf('#');
+        
+        // First get rid of the query String, so we can reappend it later
+        int questionMarkIndex = usedUIWebPath.indexOf('?', fragIndex);
+        String query = "";
+        if(questionMarkIndex > 0) {
+            query = usedUIWebPath.substring(questionMarkIndex);
+            usedUIWebPath = usedUIWebPath.substring(0, questionMarkIndex);
+        }
+        // Now let's see, if this url already contains a fragment
+        if(!usedUIWebPath.contains("#")) {
+            // Apparently it didn't, so we can append our own
+            return usedUIWebPath+"#"+param+"="+value+query;
+        }
+        // Alright, we already have a fragment, let's append a new parameer
+        
+        return usedUIWebPath+"&"+param+"="+value+query;
+    }
+
+    private void doStore(HttpServletRequest req, HttpServletResponse resp) throws AbstractOXException, JSONException, IOException {
+        if (!isAutologinEnabled()) {
+            throw new AjaxException(AjaxException.Code.DisabledAction, "store");
+        }
+        SessiondService sessiond = ServerServiceRegistry.getInstance().getService(SessiondService.class);
+        if (null == sessiond) {
+            throw new ServiceException(ServiceException.Code.SERVICE_UNAVAILABLE, SessiondService.class.getName());
+        }
+
+        String sessionId = req.getParameter(PARAMETER_SESSION);
+        if (null == sessionId) {
+            throw new AjaxException(AjaxException.Code.MISSING_PARAMETER, PARAMETER_SESSION);
+        }
+
+        Session session = SessionServlet.getSession(req, sessionId, sessiond);
+
+        writeSessionCookie(resp, session, req.isSecure());
+
+        Response response = new Response();
+        response.setData("1");
+
+        ResponseWriter.write(response, resp.getWriter());
+    }
+
+    private boolean isAutologinEnabled() {
+        ConfigurationService configurationService = ServerServiceRegistry.getInstance().getService(ConfigurationService.class);
+        return configurationService.getBoolProperty("com.openexchange.sessiond.autologin", false);
+    }
+
+    private void logAndSendException(final HttpServletResponse resp, final AbstractOXException e) throws IOException {
         LOG.debug(e.getMessage(), e);
         final Response response = new Response();
         response.setException(e);
@@ -325,12 +465,33 @@ public class Login extends AJAXServlet {
      * @param resp The HTTP servlet response
      * @param session The session providing the secret cookie identifier
      */
-    protected static void writeCookie(final HttpServletResponse resp, final Session session) {
-        final Cookie cookie = new Cookie(COOKIE_PREFIX + session.getSessionID(), session.getSecret());
-        cookie.setPath("/");
+    protected static void writeSecretCookie(final HttpServletResponse resp, final Session session, boolean secure) {
+        final Cookie cookie = new Cookie(SECRET_PREFIX + session.getHash(), session.getSecret());
+        configureCookie(cookie, secure);
         resp.addCookie(cookie);
     }
 
+    protected static void writeSessionCookie(final HttpServletResponse resp, final Session session, boolean secure) {
+        final Cookie cookie = new Cookie(SESSION_PREFIX + session.getHash(), session.getSessionID());
+        configureCookie(cookie, secure);
+        resp.addCookie(cookie);
+    }
+
+    private static void configureCookie(Cookie cookie, boolean secure) {
+        cookie.setPath("/");
+        ConfigurationService configurationService = ServerServiceRegistry.getInstance().getService(ConfigurationService.class);
+        boolean autologin = configurationService.getBoolProperty("com.openexchange.sessiond.autologin", false);
+        if (!autologin) {
+            return;
+        }
+        String spanDef = configurationService.getProperty("com.openexchange.sessiond.cookie.ttl", "1W");
+        cookie.setMaxAge((int) (ConfigTools.parseTimespan(spanDef) / 1000));
+        boolean forceHTTPS = configurationService.getBoolProperty("com.openexchange.sessiond.cookie.forceHTTPS", false);
+        if (forceHTTPS || secure) {
+            cookie.setSecure(true);
+        }
+    }
+
     private void doLogin(HttpServletRequest req, HttpServletResponse resp) throws AjaxException, IOException {
         final LoginRequest request = parseLogin(req);
         // Perform the login
@@ -364,7 +525,8 @@ public class Login extends AJAXServlet {
                 final Session session = result.getSession();
                 // Store associated session
                 SessionServlet.rememberSession(req, new ServerSessionAdapter(session, result.getContext(), result.getUser()));
-                writeCookie(resp, session);
+                writeSecretCookie(resp, session, req.isSecure());
+                
                 // Login response is unfortunately not conform to default responses.
                 ((JSONObject) response.getData()).write(resp.getWriter());
             }
@@ -390,30 +552,52 @@ public class Login extends AJAXServlet {
         }
         final String authId = null == req.getParameter(LoginFields.AUTHID_PARAM) ? UUIDs.getUnformattedString(UUID.randomUUID()) : req.getParameter(LoginFields.AUTHID_PARAM);
         LoginRequest loginRequest = new LoginRequest() {
+
+            private String hash = null;
+
             public String getLogin() {
                 return login;
             }
+
             public String getPassword() {
                 return password;
             }
+
             public String getClientIP() {
                 return req.getRemoteAddr();
             }
+
             public String getUserAgent() {
                 return req.getHeader(Header.USER_AGENT);
             }
+
             public String getAuthId() {
                 return authId;
             }
+
             public String getClient() {
+                if (req.getParameter(LoginFields.CLIENT_PARAM) == null) {
+                    return "default";
+                }
                 return req.getParameter(LoginFields.CLIENT_PARAM);
             }
+
             public String getVersion() {
                 return req.getParameter(LoginFields.VERSION_PARAM);
             }
+
             public Interface getInterface() {
                 return HTTP_JSON;
             }
+
+            public String getHash() {
+                if (hash != null) {
+                    return hash;
+                }
+
+                return hash = HashCalculator.getHash(req);
+
+            }
         };
         return loginRequest;
     }
