@@ -49,10 +49,14 @@
 
 package com.openexchange.ajax;
 
+import static com.openexchange.java.Autoboxing.I;
 import java.io.IOException;
 import java.io.PrintWriter;
 import java.lang.reflect.UndeclaredThrowableException;
+import java.util.ArrayList;
+import java.util.Arrays;
 import java.util.Enumeration;
+import java.util.List;
 import javax.servlet.ServletConfig;
 import javax.servlet.ServletException;
 import javax.servlet.ServletRequest;
@@ -64,17 +68,21 @@ import org.apache.commons.logging.LogFactory;
 import org.json.JSONException;
 import com.openexchange.ajax.container.Response;
 import com.openexchange.ajax.writer.ResponseWriter;
+import com.openexchange.ajp13.AJPv13RequestHandler;
+import com.openexchange.config.ConfigurationService;
 import com.openexchange.configuration.ServerConfig;
 import com.openexchange.groupware.AbstractOXException;
+import com.openexchange.groupware.AbstractOXException.Category;
 import com.openexchange.groupware.EnumComponent;
 import com.openexchange.groupware.OXExceptionSource;
 import com.openexchange.groupware.OXThrows;
 import com.openexchange.groupware.OXThrowsMultiple;
-import com.openexchange.groupware.AbstractOXException.Category;
 import com.openexchange.groupware.contexts.Context;
 import com.openexchange.groupware.contexts.impl.ContextException;
 import com.openexchange.groupware.contexts.impl.ContextStorage;
+import com.openexchange.groupware.ldap.LdapException;
 import com.openexchange.groupware.ldap.User;
+import com.openexchange.groupware.ldap.UserException;
 import com.openexchange.groupware.ldap.UserStorage;
 import com.openexchange.server.ServiceException;
 import com.openexchange.server.services.ServerServiceRegistry;
@@ -83,13 +91,13 @@ import com.openexchange.sessiond.SessiondService;
 import com.openexchange.sessiond.exception.Classes;
 import com.openexchange.sessiond.exception.SessionExceptionFactory;
 import com.openexchange.sessiond.exception.SessiondException;
+import com.openexchange.sessiond.impl.IPRange;
 import com.openexchange.tools.servlet.http.Tools;
 import com.openexchange.tools.session.ServerSession;
 import com.openexchange.tools.session.ServerSessionAdapter;
 
 /**
- * Overridden service method that checks if a valid session can be found for the
- * request.
+ * Overridden service method that checks if a valid session can be found for the request.
  * 
  * @author <a href="mailto:sebastian.kauss@open-xchange.com">Sebastian Kauss</a>
  * @author <a href="mailto:marcus.klein@open-xchange.com">Marcus Klein</a>
@@ -97,36 +105,20 @@ import com.openexchange.tools.session.ServerSessionAdapter;
 @OXExceptionSource(classId = Classes.SESSION_SERVLET, component = EnumComponent.SESSION)
 public abstract class SessionServlet extends AJAXServlet {
 
-    /**
-     * Serial version UID for serialization
-     */
     private static final long serialVersionUID = -8308340875362868795L;
 
-    /**
-     * Logger.
-     */
     private static final Log LOG = LogFactory.getLog(SessionServlet.class);
 
-    /**
-     * Whether logger has debug level enabled for this class.
-     */
-    private static final boolean DEBUG = LOG.isDebugEnabled();
-
-    /**
-     * Factory for creating exceptions.
-     */
     private static final SessionExceptionFactory EXCEPTION = new SessionExceptionFactory(SessionServlet.class);
 
-    /**
-     * Name of the key to remember the session for the request.
-     */
     public static final String SESSION_KEY = "sessionObject";
 
+    private static final String SESSION_WHITELIST_FILE = "noipcheck.cnf";
+
     private boolean checkIP = true;
 
-    /**
-     * Default constructor.
-     */
+    private static List<IPRange> ranges = new ArrayList<IPRange>(5);
+    
     protected SessionServlet() {
         super();
     }
@@ -135,24 +127,42 @@ public abstract class SessionServlet extends AJAXServlet {
     public void init(final ServletConfig config) throws ServletException {
         super.init(config);
         checkIP = Boolean.parseBoolean(config.getInitParameter(ServerConfig.Property.IP_CHECK.getPropertyName()));
+        
+        if(checkIP) {
+            ConfigurationService configurationService = ServerServiceRegistry.getInstance().getService(ConfigurationService.class);
+            if(configurationService == null) {
+                LOG.fatal("No configuration service available, can not read whitelist");
+            } else {
+                String text = configurationService.getText(SESSION_WHITELIST_FILE);
+                if(text == null) {
+                    LOG.info("No exceptions from IP Check have been defined.");
+                } else {
+                    String[] lines = text.split("\n");
+                    for (String line : lines) {
+                        line = line.replaceAll("\\s", "");
+                        if(!line.equals("") && ! line.startsWith("#")) {
+                            ranges.add(IPRange.parseRange(line));
+                        }
+                    }
+                }
+            }
+        }
+    
     }
 
     /**
      * Checks the session ID supplied as a query parameter in the request URI.
-     * {@inheritDoc}
      */
     @Override
     @OXThrows(category = Category.TRY_AGAIN, desc = "", exceptionId = 4, msg = "Context is locked.")
-    protected void service(final HttpServletRequest req, final HttpServletResponse resp) throws ServletException,
-            IOException {
+    protected void service(final HttpServletRequest req, final HttpServletResponse resp) throws ServletException, IOException {
         Tools.disableCaching(resp);
         try {
             final SessiondService sessiondService = ServerServiceRegistry.getInstance().getService(SessiondService.class);
             if (sessiondService == null) {
-                throw new SessiondException(
-                    new ServiceException(ServiceException.Code.SERVICE_UNAVAILABLE, SessiondService.class.getName()));
+                throw new SessiondException(new ServiceException(ServiceException.Code.SERVICE_UNAVAILABLE, SessiondService.class.getName()));
             }
-            final Session session = getSession(req, resp, getSessionId(req), sessiondService);
+            final Session session = getSession(req, getSessionId(req), sessiondService);
             final String sessionId = session.getSessionID();
             final Context ctx = ContextStorage.getStorageContext(session.getContextId());
             if (!ctx.isEnabled()) {
@@ -160,13 +170,18 @@ public abstract class SessionServlet extends AJAXServlet {
                 sessiondCon.removeSession(sessionId);
                 throw EXCEPTION.create(4);
             }
-            checkIP(session, req.getRemoteAddr());
+            final SessiondException ipCheckExc = checkIP(session, req.getRemoteAddr());
+            if (null != ipCheckExc) {
+                final SessiondService sessiondCon = ServerServiceRegistry.getInstance().getService(SessiondService.class);
+                sessiondCon.removeSession(sessionId);
+                // Drop relevant cookies
+                SessionServlet.removeOXCookies(session.getHash(), req, resp);
+                throw ipCheckExc;
+            }
             rememberSession(req, new ServerSessionAdapter(session, ctx));
             super.service(req, resp);
         } catch (final SessiondException e) {
-            if (DEBUG) {
-                LOG.debug(e.getMessage(), e);
-            }
+            LOG.debug(e.getMessage(), e);
             final Response response = new Response();
             response.setException(e);
             resp.setContentType(CONTENTTYPE_JAVASCRIPT);
@@ -178,10 +193,8 @@ public abstract class SessionServlet extends AJAXServlet {
                 log(RESPONSE_ERROR, e1);
                 sendError(resp);
             }
-        } catch (final ContextException e) {
-            if (DEBUG) {
-                LOG.debug(e.getMessage(), e);
-            }
+        } catch (final AbstractOXException e) {
+            LOG.error(e.getMessage(), e);
             final Response response = new Response();
             response.setException(e);
             resp.setContentType(CONTENTTYPE_JAVASCRIPT);
@@ -196,8 +209,8 @@ public abstract class SessionServlet extends AJAXServlet {
         }
     }
 
-    private void checkIP(final Session session, final String actual) throws SessiondException {
-        checkIP(checkIP, session, actual);
+    private SessiondException checkIP(final Session session, final String actual) {
+        return checkIP(checkIP, ranges, session, actual);
     }
 
     /**
@@ -205,8 +218,7 @@ public abstract class SessionServlet extends AJAXServlet {
      * @param checkIP <code>true</code> to deny request with an exception.
      * @param session session object
      * @param actual IP address of the current request.
-     * @throws SessionException
-     *             if the IP addresses don't match.
+     * @return The error on wrong IP
      */
     @OXThrows(
         category = Category.PERMISSION,
@@ -214,13 +226,13 @@ public abstract class SessionServlet extends AJAXServlet {
         exceptionId = 5,
         msg = "Request to server was refused. Original client IP address changed. Please try again."
     )
-    public static void checkIP(final boolean checkIP, final Session session, final String actual) throws SessiondException {
-        if (null == actual || !actual.equals(session.getLocalIp())) {
+    public static SessiondException checkIP(final boolean checkIP, final List<IPRange> ranges, final Session session, final String actual) {
+        if (null == actual || (!isWhitelistedFromIPCheck(actual, ranges) && !actual.equals(session.getLocalIp()))) {
             if (checkIP) {
                 LOG.info("Request to server denied for session: " + session.getSessionID() + ". Client login IP changed from " + session.getLocalIp() + " to " + actual + ".");
-                throw EXCEPTION.create(5);
+                return EXCEPTION.create(5);
             }
-            if (DEBUG) {
+            if (LOG.isDebugEnabled()) {
                 final StringBuilder sb = new StringBuilder(64);
                 sb.append("Session ");
                 sb.append(session.getSessionID());
@@ -231,23 +243,35 @@ public abstract class SessionServlet extends AJAXServlet {
                 LOG.debug(sb.toString());
             }
         }
+        return null;
+    }
+
+    private static boolean isWhitelistedFromIPCheck(String actual, List<IPRange> ranges) {
+        for (IPRange range : ranges) {
+            if(range.contains(actual)) {
+                return true;
+            }
+        }
+        return false;
     }
 
     /**
      * Gets the cookie identifier from the request.
      * 
-     * @param req
-     *            servlet request.
+     * @param req servlet request.
      * @return the cookie identifier.
-     * @throws SessionException
-     *             if the cookie identifier can not be found.
+     * @throws SessionException if the cookie identifier can not be found.
      */
-    @OXThrows(category = Category.CODE_ERROR, desc = "Every AJAX request must contain a parameter named session "
-            + "that value contains the identifier of the session cookie.", exceptionId = 1, msg = "The session parameter is missing.")
+    @OXThrows(
+        category = Category.CODE_ERROR,
+        desc = "Every AJAX request must contain a parameter named session that value contains the identifier of the session cookie.",
+        exceptionId = 1,
+        msg = "The session parameter is missing."
+    )
     private static String getSessionId(final ServletRequest req) throws SessiondException {
         final String retval = req.getParameter(PARAMETER_SESSION);
         if (null == retval) {
-            if (DEBUG) {
+            if (LOG.isDebugEnabled()) {
                 final StringBuilder debug = new StringBuilder();
                 debug.append("Parameter session not found: ");
                 final Enumeration<?> enm = req.getParameterNames();
@@ -265,170 +289,96 @@ public abstract class SessionServlet extends AJAXServlet {
         return retval;
     }
 
-    /**
-     * Gets the session identifier from the cookies.
-     * @param req HTTP servlet request.
-     * @param cookieId cookie identifier from the session parameter.
-     * @return a found session identifier or <code>null</code> if the session
-     * identifier can not be found.
-     */
-    private static String getSecret(final HttpServletRequest req, final String cookieId) {
-        final Cookie[] cookies = req.getCookies();
-        String sessionId = null;
-        if (cookies != null) {
-            final String cookieName = new StringBuilder(Login.COOKIE_PREFIX).append(cookieId).toString();
-            for (final Cookie cookie : cookies) {
-                if (cookieName.equals(cookie.getName())) {
-                    sessionId = cookie.getValue();
-                    break;
-                }
-            }
-        }
-        return sessionId;
-    }
 
-    /**
-     * Gets the session identifier from the request.
-     * 
-     * @param req
-     *            HTTP servlet request.
-     * @param resp
-     *            HTTP servlet response
-     * @param sessionId
-     *            Identifier of the session.
-     * @param sessiondService
-     *            The SessionD service
-     * @return The appropriate session.
-     * @throws SessionException
-     *             if either the session identifier can not be found in a cookie
-     *             or the session is missing at all.
-     */
-    @OXThrows(category = Category.CODE_ERROR, desc = "Your browser does not send the cookie for identifying your "
-            + "session.", exceptionId = 2, msg = "The cookie with the session identifier is missing.")
-    private static Session getSession(final HttpServletRequest req, final HttpServletResponse resp,
-            final String sessionId, final SessiondService sessiondService)
-            throws SessiondException {
-        // Look for a local session
-        final String secret = getSecret(req, sessionId);
-        if (null == secret) {
-            // A cache miss: throw error
-            final Cookie[] cookies = req.getCookies();
-            if (DEBUG && cookies != null) {
-                final StringBuilder debug = new StringBuilder(256);
-                debug.append("No cookie for ID: ");
-                debug.append(sessionId);
-                debug.append(". Cookie names: ");
-                for (final Cookie cookie : cookies) {
-                    debug.append(cookie.getName());
-                    debug.append(',');
-                }
-                debug.setCharAt(debug.length() - 1, '.');
-                LOG.debug(debug.toString());
-            }
-            throw EXCEPTION.create(2);
-        }
-        try {
-            return getLocalSession(sessionId, secret, sessiondService);
-        } catch (final SessiondException e) {
-            if (DEBUG) {
-                LOG.debug("No appropriate local session found");
-            }
-            // Look for a cached session on second try
-            final Session session = getCachedSession(req, resp, sessionId, secret, sessiondService);
-            if (null != session) {
-                return session;
-            }
-            // Re-throw original exception to indicate session absence
-            throw e;
-        }
-    }
 
-    /**
-     * Finds appropriate cached session.
-     * 
-     * @param req
-     *            HTTP servlet request
-     * @param resp
-     *            HTTP servlet response
-     * @param sessionId
-     *            Identifier of the session
-     * @param sessiondService
-     *            The SessionD service
-     * @return The session if fetched from cache; otherwise <code>null</code>.
-     * @throws SessiondException 
-     */
-    @OXThrows(category = Category.TRY_AGAIN, desc = "", exceptionId = 7, msg = "Session secret is different. Given %1$s differs from %2$s in session.")
-    private static Session getCachedSession(final HttpServletRequest req, final HttpServletResponse resp,
-            final String sessionId, String secret, final SessiondService sessiondService) throws SessiondException {
-        final Session session = sessiondService.getCachedSession(sessionId, req.getRemoteAddr());
-        if (null != session) {
-            if (!session.getSecret().equals(secret)) {
-                throw EXCEPTION.create(7, secret, session.getSecret());
-            }
-            // Adapt cookie
-            Login.writeCookie(resp, session);
-            return session;
-        }
-        return null;
-    }
 
     /**
      * Finds appropriate local session.
      * 
-     * @param sessionId
-     *            identifier of the session.
-     * @param sessiondService
-     *            The SessionD service
+     * @param sessionId identifier of the session.
+     * @param sessiondService The SessionD service
      * @return the session.
-     * @throws SessionException
-     *             if the session can not be found.
+     * @throws SessionException if the session can not be found.
      */
     @OXThrowsMultiple(
         category = { Category.TRY_AGAIN, Category.TRY_AGAIN },
         desc = { "A session with the given identifier can not be found.", "" },
         exceptionId = { 3, 6 },
-        msg = { "Your session %s expired. Please start a new browser session.", "Session secret is different. Given %1$s differs from %2$s in session." })
-    private static Session getLocalSession(final String sessionId, String secret, final SessiondService sessiondService)
-            throws SessiondException {
-        final Session retval = sessiondService.getSession(sessionId);
-        if (null == retval) {
+        msg = { "Your session %s expired. Please start a new browser session.", "Session secret is different. Given %1$s differs from %2$s in session." }
+    )
+    public static Session getSession(final HttpServletRequest req, final String sessionId, final SessiondService sessiondService) throws SessiondException, ContextException, LdapException, UserException {
+        final Session session = sessiondService.getSession(sessionId);
+        if (null == session) {
             throw EXCEPTION.create(3, sessionId);
         }
-        if (!retval.getSecret().equals(secret)) {
-            throw EXCEPTION.create(6, secret, retval.getSecret());
+        String secret = extractSecret(session.getHash(), req.getCookies());
+        
+        if (secret == null || !session.getSecret().equals(secret)) {
+            throw EXCEPTION.create(6, secret, session.getSecret());
         }
         try {
-            final Context context = ContextStorage.getStorageContext(retval.getContextId());
-            final User user = UserStorage.getInstance().getUser(retval.getUserId(), context);
+            final Context context = ContextStorage.getStorageContext(session.getContextId());
+            final User user = UserStorage.getInstance().getUser(session.getUserId(), context);
             if (!user.isMailEnabled()) {
-                throw EXCEPTION.create(3, sessionId);
+                throw EXCEPTION.create(3, session.getSessionID());
             }
-        } catch (final UndeclaredThrowableException e) {
-            throw EXCEPTION.create(3, sessionId);
-        } catch (final AbstractOXException e) {
-            throw EXCEPTION.create(3, sessionId);
+        } catch (UndeclaredThrowableException e) {
+            throw new UserException(UserException.Code.USER_NOT_FOUND, e, I(session.getUserId()), I(session.getContextId()));
         }
-        return retval;
+        return session;
+    }
+    
+    public static String extractSecret(String hash, Cookie[] cookies) {
+        String cookieName = Login.SECRET_PREFIX+hash;
+        for (Cookie cookie : cookies) {
+            if(cookie.getName().equals(cookieName)) {
+                return cookie.getValue();
+            }
+        }
+        return null;
     }
 
     /**
-     * Convenience method to remember the session for a request in the servlet
-     * attributes.
+     * Convenience method to remember the session for a request in the servlet attributes.
      * 
-     * @param req
-     *            servlet request.
-     * @param session
-     *            session to remember.
+     * @param req servlet request.
+     * @param session session to remember.
      */
     public static void rememberSession(final ServletRequest req, final ServerSession session) {
         req.setAttribute(SESSION_KEY, session);
     }
+    
+    public static void removeOXCookies(String hash, HttpServletRequest req, HttpServletResponse resp) {
+        Cookie[] cookies = req.getCookies();
+        if (cookies == null) {
+            return;
+        }
+        List<String> cookieNames = Arrays.asList(Login.SESSION_PREFIX + hash, Login.SECRET_PREFIX + hash);
+        for (Cookie cookie : cookies) {
+            final String name = cookie.getName();
+            if (AJPv13RequestHandler.JSESSIONID_COOKIE.equals(name)) {
+                final Cookie respCookie = new Cookie(name, cookie.getValue());
+                respCookie.setPath("/");
+                respCookie.setMaxAge(0); // delete
+                resp.addCookie(respCookie);
+            } else {
+                for (String string : cookieNames) {
+                    if (name.startsWith(string)) {
+                        final Cookie respCookie = new Cookie(name, cookie.getValue());
+                        respCookie.setPath("/");
+                        respCookie.setMaxAge(0); // delete
+                        resp.addCookie(respCookie);
+                    }
+                }
+            }
+        }
+    }
+
 
     /**
      * Returns the remembered session.
      * 
-     * @param req
-     *            servlet request.
+     * @param req servlet request.
      * @return the remembered session.
      */
     protected static ServerSession getSessionObject(final ServletRequest req) {
