@@ -50,7 +50,10 @@
 package com.openexchange.ajax.helper;
 
 import java.util.Date;
+import java.util.Enumeration;
+import java.util.HashSet;
 import java.util.Map;
+import java.util.Set;
 import java.util.regex.Pattern;
 import javax.servlet.http.HttpServletRequest;
 import javax.servlet.http.HttpServletResponse;
@@ -164,7 +167,7 @@ public abstract class ParamContainer {
         }
     };
 
-    private static final ErrorInfo getErrorInfo(final EnumComponent component) {
+    static final ErrorInfo getErrorInfo(final EnumComponent component) {
         switch (component) {
         case FOLDER:
             return FOLDER_ERR_INFO;
@@ -195,6 +198,11 @@ public abstract class ParamContainer {
             errorInfo = getErrorInfo(component);
         }
 
+        @Override
+        public Set<String> getParameterNames() {
+            return map.keySet();
+        }
+
         @Override
         public Date checkDateParam(final String paramName) throws AbstractOXException {
             final String tmp = map.get(paramName);
@@ -443,6 +451,15 @@ public abstract class ParamContainer {
             errorInfo = getErrorInfo(component);
         }
 
+        @Override
+        public Set<String> getParameterNames() {
+            final Set<String> ret = new HashSet<String>();
+            for (final Enumeration<?> enumeration = req.getParameterNames(); enumeration.hasMoreElements();) {
+                ret.add((String) enumeration.nextElement());
+            }
+            return ret;
+        }
+
         @Override
         public Date checkDateParam(final String paramName) throws AbstractOXException {
             final String tmp = req.getParameter(paramName);
@@ -681,11 +698,17 @@ public abstract class ParamContainer {
          * @param component
          */
         public JSONParamContainer(final JSONObject jo, final EnumComponent component) {
+            super();
             this.jo = jo;
             this.component = component;
             errorInfo = getErrorInfo(component);
         }
 
+        @Override
+        public Set<String> getParameterNames() {
+            return jo.keySet();
+        }
+
         @Override
         public Date checkDateParam(final String paramName) throws AbstractOXException {
             if (!jo.has(paramName) || jo.isNull(paramName)) {
@@ -974,6 +997,13 @@ public abstract class ParamContainer {
      */
     public abstract String getStringParam(String paramName) throws AbstractOXException;
 
+    /**
+     * Gets the parameter names.
+     * 
+     * @return The parameter names
+     */
+    public abstract Set<String> getParameterNames();
+
     /**
      * Requires a parameter as <code>String</code>
      * 
