@@ -70,8 +70,9 @@ import com.openexchange.tools.servlet.OXJSONException.Code;
  */
 public abstract class DataParser {
 
-    protected boolean parseAll;
+    public static final int NO_INT = 0;
 
+    protected boolean parseAll;
     protected TimeZone timeZone;
 
     protected DataParser() {
@@ -131,20 +132,18 @@ public abstract class DataParser {
         return retval;
     }
 
-    public static int parseInt(final JSONObject jsonObj, final String name) throws JSONException, OXJSONException {
-        if (!jsonObj.has(name)) {
+    public static int parseInt(JSONObject json, String name) throws JSONException, OXJSONException {
+        if (!json.has(name)) {
+            return NO_INT;
+        }
+        String tmp = json.getString(name);
+        if (tmp == null || json.isNull(name) || tmp.length() == 0) {
             return 0;
         }
-
-        final String tmp = jsonObj.getString(name);
-        if (tmp == null || jsonObj.isNull(name) || tmp.length() == 0) {
-            return 0;
-        }
-
         try {
             return Integer.parseInt(tmp);
-        } catch (final NumberFormatException exc) {
-            throw new OXJSONException(Code.INVALID_VALUE, exc, name, tmp);
+        } catch (final NumberFormatException e) {
+            throw new OXJSONException(Code.NUMBER_PARSING, e, tmp, name);
         }
     }
 
@@ -218,10 +217,21 @@ public abstract class DataParser {
         }
 
         final int offset = timeZone.getOffset(d.getTime());
-        d.setTime(d.getTime()-offset);
+        d.setTime(d.getTime() - offset);
         return d;
     }
 
+    private int getOffSet(TimeZone timeZone, Date d) {
+        int offset = timeZone.getOffset(d.getTime());
+        Date test = new Date(d.getTime() - offset);
+        int clientOffset = timeZone.getOffset(test.getTime());
+        if (clientOffset != offset) {
+            // UI offset addition triggered DST, use not DST
+            offset = clientOffset;
+        }
+        return offset;
+    }
+
     public static Date parseDate(final JSONObject jsonObj, final String name) {
         if (!jsonObj.has(name)) {
             return null;
@@ -245,16 +255,15 @@ public abstract class DataParser {
         return tmp;
     }
 
-    public static int checkInt(final JSONObject jsonObj, final String name) throws OXJSONException, AjaxException {
-        final String tmp = checkString(jsonObj, name);
+    public static int checkInt(JSONObject json, String name) throws OXJSONException, AjaxException {
+        final String tmp = checkString(json, name);
         if (tmp == null || tmp.length() == 0) {
             throw new AjaxException(AjaxException.Code.MISSING_PARAMETER, name);
         }
-
         try {
             return Integer.parseInt(tmp);
-        } catch (final NumberFormatException exc) {
-            throw new OXJSONException(Code.INVALID_VALUE, exc, name, tmp);
+        } catch (NumberFormatException e) {
+            throw new OXJSONException(Code.NUMBER_PARSING, e, tmp, name);
         }
     }
 
