@@ -73,6 +73,7 @@ import com.openexchange.ajax.fields.AppointmentFields;
 import com.openexchange.ajax.fields.CalendarFields;
 import com.openexchange.ajax.fields.DataFields;
 import com.openexchange.ajax.fields.FolderChildFields;
+import com.openexchange.ajax.fields.OrderFields;
 import com.openexchange.ajax.fields.SearchFields;
 import com.openexchange.ajax.parser.AppointmentParser;
 import com.openexchange.ajax.parser.CalendarParser;
@@ -103,12 +104,14 @@ import com.openexchange.groupware.container.participants.ConfirmableParticipant;
 import com.openexchange.groupware.contexts.Context;
 import com.openexchange.groupware.ldap.User;
 import com.openexchange.groupware.search.AppointmentSearchObject;
+import com.openexchange.groupware.search.Order;
 import com.openexchange.server.services.ServerServiceRegistry;
 import com.openexchange.tools.StringCollection;
 import com.openexchange.tools.iterator.SearchIterator;
 import com.openexchange.tools.iterator.SearchIteratorException;
 import com.openexchange.tools.servlet.AjaxException;
 import com.openexchange.tools.servlet.OXJSONException;
+import com.openexchange.tools.servlet.OXJSONException.Code;
 import com.openexchange.tools.session.ServerSession;
 
 /**
@@ -134,7 +137,8 @@ public class AppointmentRequest {
         CalendarObject.START_DATE, CalendarObject.END_DATE, CalendarObject.NOTE, CalendarObject.RECURRENCE_TYPE,
         CalendarObject.RECURRENCE_CALCULATOR, CalendarObject.RECURRENCE_ID, CalendarObject.RECURRENCE_POSITION,
         CalendarObject.PARTICIPANTS, CalendarObject.USERS, Appointment.SHOWN_AS, Appointment.DELETE_EXCEPTIONS,
-        Appointment.CHANGE_EXCEPTIONS, Appointment.FULL_TIME, Appointment.COLOR_LABEL, Appointment.TIMEZONE, Appointment.ORGANIZER, Appointment.UID, Appointment.SEQUENCE, Appointment.CONFIRMATIONS, Appointment.LAST_MODIFIED_OF_NEWEST_ATTACHMENT };
+        Appointment.CHANGE_EXCEPTIONS, Appointment.FULL_TIME, Appointment.COLOR_LABEL, Appointment.TIMEZONE, Appointment.ORGANIZER, Appointment.UID, Appointment.SEQUENCE, Appointment.CONFIRMATIONS, Appointment.LAST_MODIFIED_OF_NEWEST_ATTACHMENT,
+        Appointment.NUMBER_OF_ATTACHMENTS};
 
     private final ServerSession session;
 
@@ -177,7 +181,6 @@ public class AppointmentRequest {
         if (!session.getUserConfiguration().hasCalendar()) {
             throw new OXPermissionException(OXPermissionException.Code.NoPermissionForModul, "calendar");
         }
-
         if (AJAXServlet.ACTION_CONFIRM.equalsIgnoreCase(action)) {
             return actionConfirm(jsonObject);
         } else if (AJAXServlet.ACTION_NEW.equalsIgnoreCase(action)) {
@@ -323,7 +326,7 @@ public class AppointmentRequest {
         final String ignore = DataParser.parseString(jsonObj, AJAXServlet.PARAMETER_IGNORE);
 
         final boolean bRecurrenceMaster = DataParser.parseBoolean(jsonObj, RECURRENCE_MASTER);
-
+        final boolean showPrivates = DataParser.parseBoolean(jsonObj, AJAXServlet.PARAMETER_SHOW_PRIVATE_APPOINTMENTS);
         final int folderId = DataParser.parseInt(jsonObj, AJAXServlet.PARAMETER_FOLDERID);
 
         boolean showAppointmentInAllFolders = false;
@@ -356,6 +359,7 @@ public class AppointmentRequest {
         final CalendarCollectionService recColl = ServerServiceRegistry.getInstance().getService(CalendarCollectionService.class);
         SearchIterator<Appointment> it = null;
         Date lastModified = null;
+        appointmentsql.setIncludePrivateAppointments(showPrivates);
         try {
             if (!bIgnoreModified) {
                 if (showAppointmentInAllFolders) {
@@ -366,18 +370,17 @@ public class AppointmentRequest {
                         _appointmentFields,
                         requestedTimestamp,
                         0,
-                        null);
+                        Order.NO_ORDER);
                 } else {
                     if (start == null || end == null) {
-                        it = appointmentsql.getModifiedAppointmentsInFolder(folderId, _appointmentFields, requestedTimestamp, true);
+                        it = appointmentsql.getModifiedAppointmentsInFolder(folderId, _appointmentFields, requestedTimestamp);
                     } else {
                         it = appointmentsql.getModifiedAppointmentsInFolder(
                             folderId,
                             start,
                             end,
                             _appointmentFields,
-                            requestedTimestamp,
-                            true);
+                            requestedTimestamp);
                     }
                 }
 
@@ -529,10 +532,16 @@ public class AppointmentRequest {
         }
 
         final boolean bRecurrenceMaster = DataParser.parseBoolean(jsonObj, RECURRENCE_MASTER);
-
+        
         final TIntIntHashMap objectIdMap = new TIntIntHashMap();
         for (int a = 0; a < jData.length(); a++) {
-            final JSONObject jObject = jData.getJSONObject(a);
+            JSONObject jObject = null;
+            try {
+                jObject = jData.getJSONObject(a);
+            } catch (JSONException e) {
+                throw new OXJSONException(Code.JSON_READ_ERROR, e, jData.toString());
+            }            
+            
             final int objectId = DataParser.checkInt(jObject, AJAXServlet.PARAMETER_ID);
             final int folderId = DataParser.checkInt(jObject, AJAXServlet.PARAMETER_FOLDERID);
 
@@ -573,7 +582,7 @@ public class AppointmentRequest {
 
         final AppointmentSQLInterface appointmentsql = appointmentFactory.createAppointmentSql(session);
         final CalendarCollectionService recColl = ServerServiceRegistry.getInstance().getService(CalendarCollectionService.class);
-        it = appointmentsql.getObjectsById(objectIdAndFolderId, _appointmentFields);
+        it = appointmentsql.getObjectsById(objectIdAndFolderId, _appointmentFields); 
         try {
             int counter = 0;
             final JSONArray jsonResponseArray = new JSONArray();
@@ -695,6 +704,7 @@ public class AppointmentRequest {
         final int folderId = DataParser.parseInt(jsonObj, AJAXServlet.PARAMETER_FOLDERID);
 
         final int orderBy = DataParser.parseInt(jsonObj, AJAXServlet.PARAMETER_SORT);
+        final boolean showPrivateAppointments = DataParser.parseBoolean(jsonObj, AJAXServlet.PARAMETER_SHOW_PRIVATE_APPOINTMENTS);
         final boolean listOrder;
         if (orderBy == CalendarObject.START_DATE || orderBy == CalendarObject.END_DATE) {
             listOrder = true;
@@ -704,7 +714,8 @@ public class AppointmentRequest {
 
         final List<DateOrderObject> objectList = new ArrayList<DateOrderObject>();
 
-        final String orderDir = DataParser.parseString(jsonObj, AJAXServlet.PARAMETER_ORDER);
+        final String orderDirString = DataParser.parseString(jsonObj, AJAXServlet.PARAMETER_ORDER);
+        final Order orderDir = OrderFields.parse(orderDirString);
 
         final boolean bRecurrenceMaster = DataParser.parseBoolean(jsonObj, RECURRENCE_MASTER);
 
@@ -730,7 +741,10 @@ public class AppointmentRequest {
             if (showAppointmentInAllFolders) {
                 it = appointmentsql.getAppointmentsBetween(user.getId(), start, end, _appointmentFields, orderBy, orderDir);
             } else {
+                boolean old = appointmentsql.getIncludePrivateAppointments();
+                appointmentsql.setIncludePrivateAppointments(showPrivateAppointments);
                 it = appointmentsql.getAppointmentsBetweenInFolder(folderId, _appointmentFields, start, end, orderBy, orderDir);
+                appointmentsql.setIncludePrivateAppointments(old);
             }
             Date lastModified = new Date(0);
             while (it.hasNext()) {
@@ -810,24 +824,15 @@ public class AppointmentRequest {
                 final DateOrderObject[] dateOrderObjectArray = objectList.toArray(new DateOrderObject[objectList.size()]);
                 Arrays.sort(dateOrderObjectArray);
 
-                boolean asc;
-
-                if (orderDir == null) {
-                    asc = true;
-                } else {
-                    if (orderDir.equalsIgnoreCase("desc")) {
-                        asc = false;
-                    } else {
-                        asc = true;
-                    }
-                }
-
-                if (asc) {
+                switch (orderDir) {
+                case ASCENDING:
+                case NO_ORDER:
                     for (int a = 0; a < dateOrderObjectArray.length; a++) {
                         final Appointment appointmentObj = (Appointment) dateOrderObjectArray[a].getObject();
                         appointmentwriter.writeArray(appointmentObj, columns, startUTC, endUTC, jsonResponseArray);
                     }
-                } else {
+                    break;
+                case DESCENDING:
                     for (int a = dateOrderObjectArray.length - 1; a >= 0; a--) {
                         final Appointment appointmentObj = (Appointment) dateOrderObjectArray[a].getObject();
                         appointmentwriter.writeArray(appointmentObj, columns, startUTC, endUTC, jsonResponseArray);
@@ -860,6 +865,9 @@ public class AppointmentRequest {
         final CalendarCollectionService recColl = ServerServiceRegistry.getInstance().getService(CalendarCollectionService.class);
         try {
             final Appointment appointmentobject = appointmentsql.getObjectById(id, inFolder);
+            if(appointmentobject.getPrivateFlag() && session.getUserId() != appointmentobject.getCreatedBy())
+                anonymize(appointmentobject);
+                
             final AppointmentWriter appointmentwriter = new AppointmentWriter(timeZone);
 
             final JSONObject jsonResponseObj = new JSONObject();
@@ -960,7 +968,8 @@ public class AppointmentRequest {
         }
 
         final int orderBy = DataParser.parseInt(jsonObj, AJAXServlet.PARAMETER_SORT);
-        final String orderDir = DataParser.parseString(jsonObj, AJAXServlet.PARAMETER_ORDER);
+        final String orderDirString = DataParser.parseString(jsonObj, AJAXServlet.PARAMETER_ORDER);
+        final Order orderDir = OrderFields.parse(orderDirString);
 
         int limit = 0;
         boolean hasLimit = false;
@@ -1170,10 +1179,11 @@ public class AppointmentRequest {
             orderBy = CalendarObject.START_DATE;
         }
 
-        String orderDir = DataParser.parseString(jsonObj, AJAXServlet.PARAMETER_ORDER);
-        if (orderDir == null) {
-            orderDir = "asc";
+        String orderDirString = DataParser.parseString(jsonObj, AJAXServlet.PARAMETER_ORDER);
+        if (orderDirString == null) {
+            orderDirString = "asc";
         }
+        final Order orderDir = OrderFields.parse(orderDirString);
 
         final int limit = DataParser.checkInt(jsonObj, "limit");
 
@@ -1408,4 +1418,20 @@ public class AppointmentRequest {
     private Date applyTimeZone2Date(final long utcTime) {
         return new Date(utcTime - timeZone.getOffset(utcTime));
     }
+    
+    private void anonymize(Appointment anonymized){
+        //TODO: Solve dependency problem and use AnonymizingIterator#anonymize instead
+        anonymized.setTitle("Private");
+        anonymized.removeAlarm();
+        anonymized.removeCategories();
+        anonymized.removeConfirm();
+        anonymized.removeConfirmMessage();
+        anonymized.removeLabel();
+        anonymized.removeLocation();
+        anonymized.removeNote();
+        anonymized.removeNotification();
+        anonymized.removeParticipants();
+        anonymized.removeShownAs();
+        anonymized.removeUsers();
+    }
 }
