@@ -64,6 +64,7 @@ import com.openexchange.ajax.AJAXServlet;
 import com.openexchange.ajax.fields.ContactFields;
 import com.openexchange.ajax.fields.DataFields;
 import com.openexchange.ajax.fields.FolderChildFields;
+import com.openexchange.ajax.fields.OrderFields;
 import com.openexchange.ajax.fields.SearchFields;
 import com.openexchange.ajax.parser.ContactParser;
 import com.openexchange.ajax.parser.DataParser;
@@ -92,6 +93,7 @@ import com.openexchange.groupware.contexts.impl.ContextException;
 import com.openexchange.groupware.ldap.User;
 import com.openexchange.groupware.links.Links;
 import com.openexchange.groupware.search.ContactSearchObject;
+import com.openexchange.groupware.search.Order;
 import com.openexchange.groupware.tx.TransactionException;
 import com.openexchange.groupware.userconfiguration.UserConfiguration;
 import com.openexchange.server.services.ServerServiceRegistry;
@@ -275,7 +277,7 @@ public class ContactRequest {
             while (it.hasNext()) {
                 final Contact contactObj = it.next();
                 final JSONArray jsonContactArray = new JSONArray();
-                contactWriter.writeArray(contactObj, columns, jsonContactArray);
+                contactWriter.writeArray(contactObj, columns, jsonContactArray, session);
                 jsonResponseArray.put(jsonContactArray);
 
                 if (timestamp.before(contactObj.getLastModified())) {
@@ -371,7 +373,7 @@ public class ContactRequest {
                     while (it.hasNext()) {
                         final Contact contactObj = it.next();
                         final JSONArray jsonContactArray = new JSONArray();
-                        contactwriter.writeArray(contactObj, columns, jsonContactArray);
+                        contactwriter.writeArray(contactObj, columns, jsonContactArray, session);
                         jsonResponseArray.put(jsonContactArray);
 
                         if (timestamp.before(contactObj.getLastModified())) {
@@ -393,7 +395,7 @@ public class ContactRequest {
                         while (it.hasNext()) {
                             final Contact contactObj = it.next();
                             final JSONArray jsonContactArray = new JSONArray();
-                            contactwriter.writeArray(contactObj, columns, jsonContactArray);
+                            contactwriter.writeArray(contactObj, columns, jsonContactArray, session);
                             jsonResponseArray.put(jsonContactArray);
 
                             lastModified = contactObj.getLastModified();
@@ -446,7 +448,7 @@ public class ContactRequest {
             for (int a = 0; a < userIdArray.length; a++) {
                 final Contact contactObj = contactInterface.getUserById(userIdArray[a]);
                 final JSONArray jsonContactArray = new JSONArray();
-                contactwriter.writeArray(contactObj, columns, jsonContactArray);
+                contactwriter.writeArray(contactObj, columns, jsonContactArray, session);
                 jsonResponseArray.put(jsonContactArray);
 
                 if (timestamp.before(contactObj.getLastModified())) {
@@ -466,7 +468,7 @@ public class ContactRequest {
         final int[] columnsToLoad = removeVirtual(columns);
         final int folderId = DataParser.checkInt(jsonObj, AJAXServlet.PARAMETER_FOLDERID);
         final int orderBy = DataParser.parseInt(jsonObj, AJAXServlet.PARAMETER_SORT);
-        final String orderDir = DataParser.parseString(jsonObj, AJAXServlet.PARAMETER_ORDER);
+        final Order order = OrderFields.parse(DataParser.parseString(jsonObj, AJAXServlet.PARAMETER_ORDER));
         final TimeZone timeZone;
         {
             final String timeZoneId = DataParser.parseString(jsonObj, AJAXServlet.PARAMETER_TIMEZONE);
@@ -493,12 +495,12 @@ public class ContactRequest {
                 session);
 
             final ContactWriter contactwriter = new ContactWriter(timeZone);
-            it = contactInterface.getContactsInFolder(folderId, leftHandLimit, rightHandLimit, orderBy, orderDir, internalColumns);
+            it = contactInterface.getContactsInFolder(folderId, leftHandLimit, rightHandLimit, orderBy, order, internalColumns);
 
             while (it.hasNext()) {
                 final Contact contactObj = it.next();
                 final JSONArray jsonContactArray = new JSONArray();
-                contactwriter.writeArray(contactObj, columns, jsonContactArray);
+                contactwriter.writeArray(contactObj, columns, jsonContactArray, session);
                 jsonResponseArray.put(jsonContactArray);
 
                 if (timestamp.before(contactObj.getLastModified())) {
@@ -543,7 +545,7 @@ public class ContactRequest {
         final ContactWriter contactwriter = new ContactWriter(timeZone);
 
         final JSONObject jsonResponseObject = new JSONObject();
-        contactwriter.writeContact(contactObj, jsonResponseObject);
+        contactwriter.writeContact(contactObj, jsonResponseObject, session);
 
         timestamp = contactObj.getLastModified();
 
@@ -569,7 +571,7 @@ public class ContactRequest {
         final ContactWriter contactwriter = new ContactWriter(timeZone);
 
         final JSONObject jsonResponseObject = new JSONObject();
-        contactwriter.writeContact(contactObj, jsonResponseObject);
+        contactwriter.writeContact(contactObj, jsonResponseObject, session);
 
         timestamp = contactObj.getLastModified();
 
@@ -613,7 +615,7 @@ public class ContactRequest {
         }
 
         final int orderBy = DataParser.parseInt(jsonObj, AJAXServlet.PARAMETER_SORT);
-        final String orderDir = DataParser.parseString(jsonObj, AJAXServlet.PARAMETER_ORDER);
+        final Order order = OrderFields.parse(DataParser.parseString(jsonObj, AJAXServlet.PARAMETER_ORDER));
 
         searchObj.setSurname(DataParser.parseString(jData, ContactFields.LAST_NAME));
         searchObj.setDisplayName(DataParser.parseString(jData, ContactFields.DISPLAY_NAME));
@@ -643,7 +645,7 @@ public class ContactRequest {
         final int[] internalColumns = checkLastModified(columnsToLoad);
 
         final ContactSearchMultiplexer multiplexer = new ContactSearchMultiplexer(ServerServiceRegistry.getInstance().getService(ContactInterfaceDiscoveryService.class));
-        final SearchIterator<Contact> it = multiplexer.extendedSearch(session, searchObj, orderBy, orderDir, internalColumns);
+        final SearchIterator<Contact> it = multiplexer.extendedSearch(session, searchObj, orderBy, order, internalColumns);
         
         final JSONArray jsonResponseArray = new JSONArray();
         try {
@@ -651,7 +653,7 @@ public class ContactRequest {
             while (it.hasNext()) {
                 final Contact contactObj = it.next();
                 final JSONArray jsonContactArray = new JSONArray();
-                contactwriter.writeArray(contactObj, columns, jsonContactArray);
+                contactwriter.writeArray(contactObj, columns, jsonContactArray, session);
                 jsonResponseArray.put(jsonContactArray);
 
                 if (timestamp.before(contactObj.getLastModified())) {
@@ -699,7 +701,7 @@ public class ContactRequest {
         /*
          * Check attachments
          */
-        copyAttachments(folderId, ctx, contactObj, origObjectId, origFolderId, user, uc);
+        copyAttachments(folderId, session, ctx, contactObj, origObjectId, origFolderId, user, uc);
         /*
          * Check links
          */
@@ -776,7 +778,7 @@ public class ContactRequest {
         }
     }
 
-    private static void copyAttachments(final int folderId, final Context ctx, final Contact contactObj, final int origObjectId, final int origFolderId, final User user, final UserConfiguration uc) throws OXException {
+    private static void copyAttachments(final int folderId, Session session, final Context ctx, final Contact contactObj, final int origObjectId, final int origFolderId, final User user, final UserConfiguration uc) throws OXException {
         /*
          * Copy attachments
          */
@@ -798,7 +800,7 @@ public class ContactRequest {
                         orig.getId(),
                         ctx,
                         user,
-                        uc), ctx, user, uc);
+                        uc), session, ctx, user, uc);
                 } while (iterator.hasNext());
                 attachmentBase.commit();
             } catch (final SearchIteratorException e) {
