@@ -28,7 +28,7 @@
  *    http://www.open-xchange.com/EN/developer/. The contributing author shall be
  *    given Attribution for the derivative code and a license granting use.
  *
- *     Copyright (C) 2004-2006 Open-Xchange, Inc.
+ *     Copyright (C) 2004-2010 Open-Xchange, Inc.
  *     Mail: info@open-xchange.com
  *
  *
@@ -49,14 +49,15 @@
 
 package com.openexchange.ajax.request;
 
+import gnu.trove.TIntArrayList;
+import gnu.trove.TIntHashSet;
+import gnu.trove.TIntIntHashMap;
 import java.io.IOException;
 import java.io.InputStream;
 import java.util.ArrayList;
 import java.util.Arrays;
-import java.util.HashMap;
 import java.util.HashSet;
 import java.util.List;
-import java.util.Map;
 import java.util.Set;
 import org.apache.commons.logging.Log;
 import org.apache.commons.logging.LogFactory;
@@ -211,7 +212,7 @@ public class InfostoreRequest extends CommonRequest {
                     return true;
                 }
                 final Object toDelete = req.getBody();
-                final Map<Integer, Integer> folderMapping = new HashMap<Integer, Integer>();
+                final TIntIntHashMap folderMapping = new TIntIntHashMap();
                 final int[] ids = parseIDList(toDelete, folderMapping);
                 final long timestamp = Long.parseLong(req.getParameter(AJAXServlet.PARAMETER_TIMESTAMP));
                 delete(ids, folderMapping, timestamp);
@@ -332,7 +333,7 @@ public class InfostoreRequest extends CommonRequest {
         }
     }
 
-    protected int[] parseIDList(final Object toDelete, final Map<Integer, Integer> folderMapping) throws JSONException {
+    protected int[] parseIDList(final Object toDelete, final TIntIntHashMap folderMapping) throws JSONException {
         if(JSONArray.class.isAssignableFrom(toDelete.getClass())) {
             final JSONArray array = (JSONArray) toDelete;
             final int[] ids = new int[array.length()];
@@ -352,7 +353,7 @@ public class InfostoreRequest extends CommonRequest {
                     } catch (final JSONException x) {
                         folder = Integer.parseInt("folder");
                     }
-                    folderMapping.put(Integer.valueOf(ids[i]), Integer.valueOf(folder));
+                    folderMapping.put(ids[i], folder);
                 }
             }
 
@@ -547,21 +548,20 @@ public class InfostoreRequest extends CommonRequest {
                 throw new OXConflictException();
             }
             iter = result.results();
-            final List<Integer> versions = new ArrayList<Integer>();
-            while (iter.hasNext()) {
-                final int version = (iter.next()).getVersion();
-                if (version == 0) {
-                    continue;
+            final TIntArrayList versions;
+            try {
+                versions = new TIntArrayList();
+                while (iter.hasNext()) {
+                    final int version = (iter.next()).getVersion();
+                    if (version == 0) {
+                        continue;
+                    }
+                    versions.add(version);
                 }
-                versions.add(Integer.valueOf(version));
+            } finally {
+                iter.close();
             }
-            iter.close();
-            final int[] versionsArray = new int[versions.size()];
-            int index = 0;
-            for (final int version : versions) {
-                versionsArray[index++] = version;
-            }
-            infostore.removeVersion(id, versionsArray, session);
+            infostore.removeVersion(id, versions.toNativeArray(), session);
             timestamp = infostore.getDocumentMetadata(id, InfostoreFacade.CURRENT_VERSION, ctx,
                     user, userConfiguration).getSequenceNumber();
             infostore.commit();
@@ -783,7 +783,7 @@ public class InfostoreRequest extends CommonRequest {
         }
     }
 
-    protected void delete(final int[] ids, final Map<Integer, Integer> folderMapping, final long timestamp) {
+    protected void delete(final int[] ids, final TIntIntHashMap folderMapping, final long timestamp) {
         final InfostoreFacade infostore = getInfostore();
         final SearchEngine searchEngine = getSearchEngine();
 
@@ -796,13 +796,13 @@ public class InfostoreRequest extends CommonRequest {
 
                 notDeleted = infostore.removeDocument(ids, timestamp, session);
 
-                final Set<Integer> notDeletedSet = new HashSet<Integer>();
+                final TIntHashSet notDeletedSet = new TIntHashSet();
                 for (final int nd : notDeleted) {
                     notDeletedSet.add(nd);
                 }
 
                 for (final int id : ids) {
-                    if (!notDeletedSet.contains(Integer.valueOf(id))) {
+                    if (!notDeletedSet.contains(id)) {
                         searchEngine.unIndex0r(id, ctx, user, userConfiguration);
                     }
                 }
