@@ -53,8 +53,6 @@ import static com.openexchange.tools.TimeZoneUtils.getTimeZone;
 import gnu.trove.TIntArrayList;
 import java.util.Date;
 import java.util.TimeZone;
-import org.apache.commons.logging.Log;
-import org.apache.commons.logging.LogFactory;
 import org.json.JSONArray;
 import org.json.JSONException;
 import org.json.JSONObject;
@@ -62,6 +60,7 @@ import org.json.JSONValue;
 import com.openexchange.ajax.AJAXServlet;
 import com.openexchange.ajax.fields.CalendarFields;
 import com.openexchange.ajax.fields.FolderChildFields;
+import com.openexchange.ajax.fields.OrderFields;
 import com.openexchange.ajax.fields.ResponseFields;
 import com.openexchange.ajax.fields.SearchFields;
 import com.openexchange.ajax.fields.TaskFields;
@@ -80,6 +79,7 @@ import com.openexchange.groupware.container.CommonObject;
 import com.openexchange.groupware.container.DataObject;
 import com.openexchange.groupware.container.FolderChildObject;
 import com.openexchange.groupware.container.Participants;
+import com.openexchange.groupware.search.Order;
 import com.openexchange.groupware.search.TaskSearchObject;
 import com.openexchange.groupware.tasks.Task;
 import com.openexchange.groupware.tasks.TasksSQLImpl;
@@ -130,51 +130,46 @@ public class TaskRequest {
 
     private Date timestamp;
 
-    private final TimeZone timeZone;
+    private TimeZone timeZone;
 
-    private static final Log LOG = LogFactory.getLog(TaskRequest.class);
-
-    public TaskRequest(final ServerSession session) {
+    public TaskRequest(ServerSession session) {
+        super();
         this.session = session;
-
-        final String sTimeZone = session.getUser().getTimeZone();
-
-        timeZone = TimeZoneUtils.getTimeZone(sTimeZone);
-        if (LOG.isDebugEnabled()) {
-            LOG.debug("use timezone string: " + sTimeZone);
-            LOG.debug("use user timezone: " + timeZone);
-        }
+        this.timeZone = TimeZoneUtils.getTimeZone(session.getUser().getTimeZone());
     }
 
     public Date getTimestamp() {
         return timestamp;
     }
 
-    public JSONValue action(final String action, final JSONObject jsonObject) throws OXMandatoryFieldException, JSONException, OXObjectNotFoundException, OXConflictException, OXPermissionException, OXFolderNotFoundException, SearchIteratorException, AjaxException, OXException, OXJSONException {
+    public JSONValue action(String action, JSONObject json) throws OXMandatoryFieldException, JSONException, OXObjectNotFoundException, OXConflictException, OXPermissionException, OXFolderNotFoundException, SearchIteratorException, AjaxException, OXException, OXJSONException {
         if (!session.getUserConfiguration().hasTask()) {
             throw new OXPermissionException(OXPermissionException.Code.NoPermissionForModul, "task");
         }
-
+        String sTimeZone = DataParser.parseString(json, AJAXServlet.PARAMETER_TIMEZONE);
+        if (null != sTimeZone) {
+            timeZone = getTimeZone(sTimeZone);
+        }
         if (action.equalsIgnoreCase(AJAXServlet.ACTION_CONFIRM)) {
-            return actionConfirm(jsonObject);
+            return actionConfirm(json);
         } else if (action.equalsIgnoreCase(AJAXServlet.ACTION_NEW)) {
-            return actionNew(jsonObject);
+            return actionNew(json);
         } else if (action.equalsIgnoreCase(AJAXServlet.ACTION_DELETE)) {
-            return actionDelete(jsonObject);
+            return actionDelete(json);
         } else if (action.equalsIgnoreCase(AJAXServlet.ACTION_UPDATE)) {
-            return actionUpdate(jsonObject);
+            return actionUpdate(json);
         } else if (action.equalsIgnoreCase(AJAXServlet.ACTION_UPDATES)) {
-            return actionUpdates(jsonObject);
+            return actionUpdates(json);
         } else if (action.equalsIgnoreCase(AJAXServlet.ACTION_LIST)) {
-            return actionList(jsonObject);
+            return actionList(json);
         } else if (action.equalsIgnoreCase(AJAXServlet.ACTION_ALL)) {
-            return actionAll(jsonObject);
+            return actionAll(json);
         } else if (action.equalsIgnoreCase(AJAXServlet.ACTION_GET)) {
-            return actionGet(jsonObject);
+            return actionGet(json);
         } else if (action.equalsIgnoreCase(AJAXServlet.ACTION_SEARCH)) {
-            return actionSearch(jsonObject);
+            return actionSearch(json);
         } else if (action.equalsIgnoreCase(AJAXServlet.ACTION_COPY)) {
-            return actionCopy(jsonObject);
+            return actionCopy(json);
         } else {
             throw new AjaxException(AjaxException.Code.UnknownAction, action);
         }
@@ -198,7 +193,7 @@ public class TaskRequest {
         return jsonResponseObject;
     }
 
-    public JSONObject actionUpdate(final JSONObject jsonObj) throws OXMandatoryFieldException, JSONException, OXException, OXJSONException, AjaxException {
+    public JSONObject actionUpdate(final JSONObject jsonObj) throws OXMandatoryFieldException, OXException, OXJSONException, AjaxException {
         final int id = DataParser.checkInt(jsonObj, AJAXServlet.PARAMETER_ID);
         final int inFolder = DataParser.checkInt(jsonObj, AJAXServlet.PARAMETER_INFOLDER);
         timestamp = DataParser.checkDate(jsonObj, AJAXServlet.PARAMETER_TIMESTAMP);
@@ -227,11 +222,6 @@ public class TaskRequest {
         timestamp = new Date(requestedTimestamp.getTime());
         final int folderId = DataParser.checkInt(jsonObj, AJAXServlet.PARAMETER_FOLDERID);
         String ignore = DataParser.parseString(jsonObj, AJAXServlet.PARAMETER_IGNORE);
-        final TimeZone timeZone;
-        {
-            final String timeZoneId = DataParser.parseString(jsonObj, AJAXServlet.PARAMETER_TIMEZONE);
-            timeZone = null == timeZoneId ? this.timeZone : getTimeZone(timeZoneId);
-        }
 
         if (ignore == null) {
             ignore = "deleted";
@@ -292,7 +282,7 @@ public class TaskRequest {
         }
     }
 
-    public JSONArray actionDelete(final JSONObject jsonObj) throws OXMandatoryFieldException, JSONException, OXPermissionException, OXConflictException, OXObjectNotFoundException, OXFolderNotFoundException, OXException, OXJSONException, AjaxException {
+    public JSONArray actionDelete(final JSONObject jsonObj) throws OXMandatoryFieldException, OXPermissionException, OXConflictException, OXObjectNotFoundException, OXFolderNotFoundException, OXException, OXJSONException, AjaxException {
         final JSONObject jsonobject = DataParser.checkJSONObject(jsonObj, ResponseFields.DATA);
         final int id = DataParser.checkInt(jsonobject, AJAXServlet.PARAMETER_ID);
         final int inFolder = DataParser.checkInt(jsonobject, AJAXServlet.PARAMETER_INFOLDER);
@@ -319,13 +309,6 @@ public class TaskRequest {
             objectIdAndFolderId[a][0] = DataParser.checkInt(jObject, AJAXServlet.PARAMETER_ID);
             objectIdAndFolderId[a][1] = DataParser.checkInt(jObject, AJAXServlet.PARAMETER_FOLDERID);
         }
-
-        final TimeZone timeZone;
-        {
-            final String timeZoneId = DataParser.parseString(jsonObj, AJAXServlet.PARAMETER_TIMEZONE);
-            timeZone = null == timeZoneId ? this.timeZone : getTimeZone(timeZoneId);
-        }
-
         final int[] internalColumns = new int[columnsToLoad.length+1];
         System.arraycopy(columnsToLoad, 0, internalColumns, 0, columnsToLoad.length);
         internalColumns[columnsToLoad.length] = DataObject.LAST_MODIFIED;
@@ -364,13 +347,7 @@ public class TaskRequest {
         final int[] columnsToLoad = removeVirtualColumns(columns);
         final int folderId = DataParser.checkInt(jsonObj, AJAXServlet.PARAMETER_FOLDERID);
         final int orderBy = DataParser.parseInt(jsonObj, AJAXServlet.PARAMETER_SORT);
-        final String orderDir = DataParser.parseString(jsonObj, AJAXServlet.PARAMETER_ORDER);
-        final TimeZone timeZone;
-        {
-            final String timeZoneId = DataParser.parseString(jsonObj, AJAXServlet.PARAMETER_TIMEZONE);
-            timeZone = null == timeZoneId ? this.timeZone : getTimeZone(timeZoneId);
-        }
-
+        final Order order = OrderFields.parse(DataParser.parseString(jsonObj, AJAXServlet.PARAMETER_ORDER));
         final int leftHandLimit = DataParser.parseInt(jsonObj, AJAXServlet.LEFT_HAND_LIMIT);
         final int rightHandLimit = DataParser.parseInt(jsonObj, AJAXServlet.RIGHT_HAND_LIMIT);
 
@@ -390,9 +367,9 @@ public class TaskRequest {
 
             final TasksSQLInterface taskssql = new TasksSQLImpl(session);
             if (leftHandLimit == 0) {
-                it = taskssql.getTaskList(folderId, leftHandLimit, -1, orderBy, orderDir, internalColumns);
+                it = taskssql.getTaskList(folderId, leftHandLimit, -1, orderBy, order, internalColumns);
             } else {
-                it = taskssql.getTaskList(folderId, leftHandLimit, rightHandLimit, orderBy, orderDir, internalColumns);
+                it = taskssql.getTaskList(folderId, leftHandLimit, rightHandLimit, orderBy, order, internalColumns);
             }
 
             while (it.hasNext()) {
@@ -417,12 +394,6 @@ public class TaskRequest {
     public JSONObject actionGet(final JSONObject jsonObj) throws OXMandatoryFieldException, JSONException, OXException, OXJSONException, AjaxException {
         final int id = DataParser.checkInt(jsonObj, AJAXServlet.PARAMETER_ID);
         final int inFolder = DataParser.checkInt(jsonObj, AJAXServlet.PARAMETER_INFOLDER);
-        final TimeZone timeZone;
-        {
-            final String timeZoneId = DataParser.parseString(jsonObj, AJAXServlet.PARAMETER_TIMEZONE);
-            timeZone = null == timeZoneId ? this.timeZone : getTimeZone(timeZoneId);
-        }
-
         timestamp = new Date(0);
 
         final TasksSQLInterface sqlinterface = new TasksSQLImpl(session);
@@ -444,7 +415,7 @@ public class TaskRequest {
         TasksSQLInterface taskSql = new TasksSQLImpl(session);
         int taskIdFromParameter = DataParser.parseInt(json, AJAXServlet.PARAMETER_ID);
         final int taskId;
-        if (0 == taskIdFromParameter) {
+        if (DataParser.NO_INT == taskIdFromParameter) {
             if (!task.containsObjectID()) {
                 throw new AjaxException(AjaxException.Code.MISSING_PARAMETER, AJAXServlet.PARAMETER_ID);
             }
@@ -461,12 +432,6 @@ public class TaskRequest {
         final int[] columns = StringCollection.convertStringArray2IntArray(sColumns);
         final int[] columnsToLoad = removeVirtualColumns(columns);
         timestamp = new Date(0);
-        final TimeZone timeZone;
-        {
-            final String timeZoneId = DataParser.parseString(jsonObj, AJAXServlet.PARAMETER_TIMEZONE);
-            timeZone = null == timeZoneId ? this.timeZone : getTimeZone(timeZoneId);
-        }
-
         Date lastModified = null;
 
         final JSONObject jData = DataParser.checkJSONObject(jsonObj, ResponseFields.DATA);
@@ -476,7 +441,7 @@ public class TaskRequest {
         }
 
         final int orderBy = DataParser.parseInt(jsonObj, AJAXServlet.PARAMETER_SORT);
-        final String orderDir = DataParser.parseString(jsonObj, AJAXServlet.PARAMETER_ORDER);
+        final Order order = OrderFields.parse(DataParser.parseString(jsonObj, AJAXServlet.PARAMETER_ORDER));
 
         if (jsonObj.has("limit")) {
             DataParser.checkInt(jsonObj, "limit");
@@ -525,7 +490,7 @@ public class TaskRequest {
             final TaskWriter taskWriter = new TaskWriter(timeZone);
 
             final TasksSQLInterface taskssql = new TasksSQLImpl(session);
-            it = taskssql.getTasksByExtendedSearch(searchObj, orderBy, orderDir, internalColumns);
+            it = taskssql.getTasksByExtendedSearch(searchObj, orderBy, order, internalColumns);
 
             while (it.hasNext()) {
                 final Task taskObj = it.next();
