@@ -28,7 +28,7 @@
  *    http://www.open-xchange.com/EN/developer/. The contributing author shall be
  *    given Attribution for the derivative code and a license granting use.
  *
- *     Copyright (C) 2004-2006 Open-Xchange, Inc.
+ *     Copyright (C) 2004-2010 Open-Xchange, Inc.
  *     Mail: info@open-xchange.com
  *
  *
@@ -53,6 +53,10 @@ import java.io.BufferedInputStream;
 import java.io.IOException;
 import java.io.InputStream;
 import java.util.concurrent.atomic.AtomicReferenceFieldUpdater;
+import com.openexchange.concurrent.Blockable;
+import com.openexchange.concurrent.Blocker;
+import com.openexchange.concurrent.ConcurrentBlocker;
+import com.openexchange.concurrent.NonBlockingBlocker;
 
 /**
  * {@link BlockableBufferedInputStream} - A blockable version of {@link BufferedInputStream}.
