@@ -28,7 +28,7 @@
  *    http://www.open-xchange.com/EN/developer/. The contributing author shall be
  *    given Attribution for the derivative code and a license granting use.
  *
- *     Copyright (C) 2004-2006 Open-Xchange, Inc.
+ *     Copyright (C) 2004-2010 Open-Xchange, Inc.
  *     Mail: info@open-xchange.com
  *
  *
@@ -52,6 +52,10 @@ package com.openexchange.ajp13;
 import java.io.BufferedOutputStream;
 import java.io.IOException;
 import java.io.OutputStream;
+import com.openexchange.concurrent.Blockable;
+import com.openexchange.concurrent.Blocker;
+import com.openexchange.concurrent.ConcurrentBlocker;
+import com.openexchange.concurrent.NonBlockingBlocker;
 
 /**
  * {@link BlockableBufferedOutputStream} - A blockable version of {@link BufferedOutputStream} which keeps track of last write access time
