@@ -53,11 +53,12 @@ import java.sql.Connection;
 import java.sql.SQLException;
 import java.util.Date;
 import com.openexchange.api.OXObjectNotFoundException;
-import com.openexchange.groupware.AbstractOXException;
 import com.openexchange.groupware.calendar.CalendarDataObject;
 import com.openexchange.groupware.container.Appointment;
 import com.openexchange.groupware.contexts.Context;
 import com.openexchange.groupware.search.AppointmentSearchObject;
+import com.openexchange.groupware.search.Order;
+import com.openexchange.session.Session;
 import com.openexchange.tools.iterator.SearchIterator;
 
 /**
@@ -67,6 +68,17 @@ import com.openexchange.tools.iterator.SearchIterator;
  */
 public interface AppointmentSQLInterface {
 
+    /**
+     * @param include TRUE if you want to include other people's private appointments when returning data, FALSE otherwise (default case)
+     * @return
+     */
+    void setIncludePrivateAppointments(boolean include);
+    
+    /**
+     * @return TRUE if relevant methods will include other people's private appointments when returning data, FALSE otherwise (default case)
+     */
+    boolean getIncludePrivateAppointments();
+    
     /**
      * Lists all appointment that match the given search.
      * 
@@ -77,7 +89,7 @@ public interface AppointmentSQLInterface {
      * @return A SearchIterator contains AppointmentObjects
      * @throws OXException, OXPermissionException, OXFolderObjectNotFoundException
      */
-    SearchIterator<Appointment> getAppointmentsBetweenInFolder(int folderId, int cols[], Date start, Date end, int orderBy, String orderDir) throws OXException, SQLException;
+    SearchIterator<Appointment> getAppointmentsBetweenInFolder(int folderId, int cols[], Date start, Date end, int orderBy, Order order) throws OXException, SQLException;
 
     /**
      * Lists all appointment that match the given search.
@@ -91,7 +103,7 @@ public interface AppointmentSQLInterface {
      * @return A SearchIterator contains AppointmentObjects
      * @throws OXException , OXPermissionException, OXFolderObjectNotFoundException
      */
-    SearchIterator<Appointment> getAppointmentsBetweenInFolder(int folderId, int cols[], Date start, Date end, int from, int to, int orderBy, String orderDir) throws OXException, SQLException;
+    SearchIterator<Appointment> getAppointmentsBetweenInFolder(int folderId, int cols[], Date start, Date end, int from, int to, int orderBy, Order orderDir) throws OXException, SQLException;
 
     /**
      * returns the days where the user has appointments
@@ -109,12 +121,10 @@ public interface AppointmentSQLInterface {
      * @param folderID The Folder ID
      * @param cols fields that will be added to the data object
      * @param since all modification >= since
-     * @param includePrivateFlag <code>true</code> to include private-flag information, meaning to exclude private appointments when
-     *            querying a shared folder; otherwise <code>false</code>
      * @return A SearchIterator contains AppointmentObject
      * @throws OXException, OXPermissionException, OXFolderObjectNotFoundException
      */
-    SearchIterator<Appointment> getModifiedAppointmentsInFolder(int fid, int[] cols, Date since, boolean includePrivateFlag) throws OXException;
+    SearchIterator<Appointment> getModifiedAppointmentsInFolder(int fid, int[] cols, Date since) throws OXException;
 
     /**
      * Lists all modified objects where the user is participant.
@@ -127,7 +137,7 @@ public interface AppointmentSQLInterface {
      * @return A SearchIterator contains AppointmentObject
      * @throws OXException, OXPermissionException, OXFolderObjectNotFoundException
      */
-    SearchIterator<Appointment> getModifiedAppointmentsBetween(int userId, Date start, Date end, int[] cols, Date since, int orderBy, String orderDir) throws OXException, SQLException;
+    SearchIterator<Appointment> getModifiedAppointmentsBetween(int userId, Date start, Date end, int[] cols, Date since, int orderBy, Order orderDir) throws OXException, SQLException;
 
     /**
      * Lists all modified objects in a folder.
@@ -142,7 +152,7 @@ public interface AppointmentSQLInterface {
      * @return A SearchIterator contains AppointmentObject
      * @throws OXException, OXPermissionException, OXFolderObjectNotFoundException
      */
-    SearchIterator<Appointment> getModifiedAppointmentsInFolder(int fid, Date start, Date end, int[] cols, Date since, boolean includePrivateFlag) throws OXException, SQLException;
+    SearchIterator<Appointment> getModifiedAppointmentsInFolder(int fid, Date start, Date end, int[] cols, Date since) throws OXException, SQLException;
 
     /**
      * Lists all deleted objects in a folder.
@@ -164,7 +174,7 @@ public interface AppointmentSQLInterface {
      * @return A SearchIterator contains AppointmentObjects
      * @throws OXException, OXPermissionException, OXFolderObjectNotFoundException
      */
-    public SearchIterator<Appointment> getAppointmentsByExtendedSearch(AppointmentSearchObject searchObject, int orderBy, String orderDir, int cols[]) throws OXException, SQLException;
+    public SearchIterator<Appointment> getAppointmentsByExtendedSearch(AppointmentSearchObject searchObject, int orderBy, Order orderDir, int cols[]) throws OXException, SQLException;
 
     /**
      * Lists all apointments where the titlematch the given searchpattern
@@ -177,7 +187,7 @@ public interface AppointmentSQLInterface {
      * @return A SearchIterator contains AppointmentObjects
      * @throws OXException, OXPermissionException, OXFolderObjectNotFoundException
      */
-    public SearchIterator<Appointment> searchAppointments(String searchpattern, int folderId, int orderBy, String orderDir, int[] cols) throws OXException;
+    public SearchIterator<Appointment> searchAppointments(String searchpattern, int folderId, int orderBy, Order orderDir, int[] cols) throws OXException;
 
     /**
      * Loads one appointment by the given ID
@@ -308,15 +318,19 @@ public interface AppointmentSQLInterface {
      * Method to attach or detach attachments
      * @param objectId
      * The object ID
+     * @param folderId
+     * The folder Id
      * @param userId
      * The user ID
+     * @param session
+     * The session
      * @param Context
      * The context
-     * @param action
-     * true = attach, false = detach
+     * @param numberOfAttachments
+     * Amount of attached attachments.
      * @throws OXException
      */
-    long attachmentAction(int objectId, int uid, Context c, boolean action) throws OXException;
+    long attachmentAction(int objectId, int uid, int folderId, Session session, Context c, int numberOfAttachments) throws OXException;
 
 
     /**
@@ -355,7 +369,7 @@ public interface AppointmentSQLInterface {
      * @throws OXException
      * @throws SQLException
      */
-    SearchIterator<Appointment> getAppointmentsBetween(int user_uid, Date start, Date end, int cols[], int orderBy, String orderDir) throws OXException, SQLException;
+    SearchIterator<Appointment> getAppointmentsBetween(int user_uid, Date start, Date end, int cols[], int orderBy, Order order) throws OXException, SQLException;
 
     /**
      * Resolves the given uid.
