@@ -50,8 +50,10 @@
 package com.openexchange.api2;
 
 import static com.openexchange.java.Autoboxing.I;
+import static com.openexchange.java.Autoboxing.b;
 import static com.openexchange.tools.StringCollection.prepareForSearch;
 import static com.openexchange.tools.sql.DBUtils.closeSQLStuff;
+import static com.openexchange.tools.sql.DBUtils.forSQLCommand;
 import gnu.trove.TIntArrayList;
 import java.sql.Connection;
 import java.sql.PreparedStatement;
@@ -80,13 +82,17 @@ import com.openexchange.groupware.Types;
 import com.openexchange.groupware.AbstractOXException.Category;
 import com.openexchange.groupware.attach.Attachments;
 import com.openexchange.groupware.contact.Classes;
+import com.openexchange.groupware.contact.ContactConfig;
 import com.openexchange.groupware.contact.ContactException;
 import com.openexchange.groupware.contact.ContactExceptionFactory;
+import com.openexchange.groupware.contact.ContactInterface;
 import com.openexchange.groupware.contact.ContactMySql;
 import com.openexchange.groupware.contact.ContactSql;
 import com.openexchange.groupware.contact.Contacts;
+import com.openexchange.groupware.contact.OverridingContactInterface;
 import com.openexchange.groupware.contact.Search;
-import com.openexchange.groupware.contact.Contacts.mapper;
+import com.openexchange.groupware.contact.ContactConfig.Property;
+import com.openexchange.groupware.contact.Contacts.Mapper;
 import com.openexchange.groupware.contact.helpers.ContactComparator;
 import com.openexchange.groupware.contact.helpers.UseCountComparator;
 import com.openexchange.groupware.container.Contact;
@@ -96,6 +102,7 @@ import com.openexchange.groupware.contexts.impl.ContextException;
 import com.openexchange.groupware.contexts.impl.ContextStorage;
 import com.openexchange.groupware.ldap.UserStorage;
 import com.openexchange.groupware.search.ContactSearchObject;
+import com.openexchange.groupware.search.Order;
 import com.openexchange.groupware.settings.SettingException;
 import com.openexchange.groupware.tx.SimpleDBProvider;
 import com.openexchange.groupware.userconfiguration.UserConfiguration;
@@ -116,7 +123,7 @@ import com.openexchange.tools.oxfolder.OXFolderAccess;
 import com.openexchange.tools.sql.DBUtils;
 
 @OXExceptionSource(classId = Classes.COM_OPENEXCHANGE_API2_DATABASEIMPL_RDBCONTACTSQLIMPL, component = EnumComponent.CONTACT)
-public class RdbContactSQLImpl implements ContactSQLInterface {
+public class RdbContactSQLImpl implements ContactSQLInterface, ContactInterface, OverridingContactInterface {
 
     private static final String ERR_UNABLE_TO_LOAD_OBJECTS_CONTEXT_1$D_USER_2$D = "Unable to load objects. Context %1$d User %2$d";
 
@@ -130,13 +137,13 @@ public class RdbContactSQLImpl implements ContactSQLInterface {
 
     private final UserConfiguration userConfiguration;
 
-    private static final ContactExceptionFactory EXCEPTIONS = new ContactExceptionFactory(RdbContactSQLImpl.class);
+    static final ContactExceptionFactory EXCEPTIONS = new ContactExceptionFactory(RdbContactSQLImpl.class);
 
     private static final Log LOG = LogFactory.getLog(RdbContactSQLImpl.class);
 
     public RdbContactSQLImpl(final Session session) throws ContextException {
-        final Context ctx = ContextStorage.getStorageContext(session);
-        this.ctx = ctx;
+        super();
+        this.ctx = ContextStorage.getStorageContext(session);
         this.userId = session.getUserId();
         this.memberInGroups = UserStorage.getStorageUser(session.getUserId(), ctx).getGroups();
         this.session = session;
@@ -144,23 +151,28 @@ public class RdbContactSQLImpl implements ContactSQLInterface {
     }
 
     public RdbContactSQLImpl(final Session session, final Context ctx) {
+        super();
+        this.ctx = ctx;
         this.userId = session.getUserId();
         this.memberInGroups = UserStorage.getStorageUser(session.getUserId(), ctx).getGroups();
-        this.ctx = ctx;
         this.session = session;
         userConfiguration = UserConfigurationStorage.getInstance().getUserConfigurationSafe(session.getUserId(), ctx);
     }
 
-    @OXThrows(category = Category.CODE_ERROR, desc = "0", exceptionId = 0, msg = ContactException.EVENT_QUEUE)
     public void insertContactObject(final Contact co) throws OXException {
+        insertContactObject(co, false);
+    }
+    
+    public void forceInsertContactObject(final Contact co) throws OXException {
+        insertContactObject(co, true);
+    }
+    
+    @OXThrows(category = Category.CODE_ERROR, desc = "0", exceptionId = 0, msg = ContactException.EVENT_QUEUE)
+    protected void insertContactObject(final Contact co, final boolean override) throws OXException {
         try {
-            Contacts.performContactStorageInsert(co, userId, session);
+            Contacts.performContactStorageInsert(co, userId, session, override);
             final EventClient ec = new EventClient(session);
             ec.create(co);
-            /*
-             * ContactObject coo = new ContactObject(); coo.setSurName("Hoeger"); ContactSQLInterface csql = new
-             * RdbContactSQLInterface(sessionobject); csql.insertContactObject(coo);
-             */
         } catch (final EventException ise) {
             throw EXCEPTIONS.create(0, ise);
         } catch (final ContextException ise) {
@@ -308,8 +320,8 @@ public class RdbContactSQLImpl implements ContactSQLInterface {
         "", "", "", "", "" }, exceptionId = { 7, 8, 9, 10, 12 }, msg = {
         ContactException.INIT_CONNECTION_FROM_DBPOOL, ContactException.NON_CONTACT_FOLDER_MSG, ContactException.NO_PERMISSION_MSG,
         ContactException.NO_PERMISSION_MSG, "An error occurred during the load of folder objects. Context %1$d Folder %2$d User %3$d" })
-    public SearchIterator<Contact> getContactsInFolder(final int folderId, final int from, final int to, final int order_field, final String orderMechanism, final int[] cols) throws OXException {
-        int[] extendedCols = cols;
+    public SearchIterator<Contact> getContactsInFolder(final int folderId, final int from, final int to, final int order_field, final Order orderMechanism, final int[] cols) throws OXException {
+        int[] extendedCols = checkColumns(cols);
         final ContactSql cs = new ContactMySql(session, ctx);
         cs.setFolder(folderId);
 
@@ -338,7 +350,7 @@ public class RdbContactSQLImpl implements ContactSQLInterface {
             final int realOrderField = order_field == Contact.USE_COUNT_GLOBAL_FIRST ? Contact.USE_COUNT : order_field;
             order.append(Contacts.mapping[realOrderField].getDBFieldName());
             order.append(' ');
-            final String realOrderMechanism = order_field == Contact.USE_COUNT_GLOBAL_FIRST ? "DESC" : orderMechanism;
+            final String realOrderMechanism = order_field == Contact.USE_COUNT_GLOBAL_FIRST ? "DESC" : forSQLCommand(orderMechanism);
             if (realOrderMechanism != null && realOrderMechanism.length() > 0) {
                 order.append(realOrderMechanism);
             } else {
@@ -401,29 +413,28 @@ public class RdbContactSQLImpl implements ContactSQLInterface {
         "An error occurred during the load of folder objects by an extended search. Context %1$d User %2$d",
         "An error occurred during the load of folder objects by an extended search. Context %1$d User %2$d",
         ContactException.INIT_CONNECTION_FROM_DBPOOL })
-    public SearchIterator<Contact> getContactsByExtendedSearch(final ContactSearchObject searchobject, final int order_field, final String orderMechanism, final int[] cols) throws OXException {
+    public SearchIterator<Contact> getContactsByExtendedSearch(final ContactSearchObject searchobject, final int order_field, final Order order, final int[] cols) throws OXException {
         int[] extendedCols = cols;
         final OXFolderAccess oxfs = new OXFolderAccess(ctx);
         final ContactSql cs = new ContactMySql(session, ctx);
         boolean considerUsersAliases = false;
-        if (searchobject.getEmailAutoComplete()) {
-            searchobject.addFolder(oxfs.getDefaultFolder(userId, FolderObject.CONTACT).getObjectID());
-            try {
-                final Integer contactCollectFolder = ServerUserSetting.getContactCollectionFolder(ctx.getContextId(), userId);
-                if (null != contactCollectFolder && oxfs.exists(contactCollectFolder.intValue())) {
-                    searchobject.addFolder(contactCollectFolder.intValue());
+        if (searchobject.isEmailAutoComplete()) {
+            boolean allFolders = b(ContactConfig.getInstance().getBoolean(Property.ALL_FOLDERS_FOR_AUTOCOMPLETE));
+            if (!searchobject.hasFolders() && !allFolders) {
+                searchobject.addFolder(oxfs.getDefaultFolder(userId, FolderObject.CONTACT).getObjectID());
+                try {
+                    final Integer contactCollectFolder = ServerUserSetting.getInstance().getContactCollectionFolder(ctx.getContextId(), userId);
+                    if (null != contactCollectFolder && oxfs.exists(contactCollectFolder.intValue())) {
+                        searchobject.addFolder(contactCollectFolder.intValue());
+                    }
+                } catch (final SettingException e) {
+                    LOG.error(e.getMessage(), e);
+                }
+                final EffectivePermission oclPerm = oxfs.getFolderPermission(FolderObject.SYSTEM_LDAP_FOLDER_ID, userId, userConfiguration);
+                if (oclPerm.isFolderVisible() && oclPerm.canReadAllObjects()) {
+                    searchobject.addFolder(FolderObject.SYSTEM_LDAP_FOLDER_ID);
+                    considerUsersAliases = true;
                 }
-            } catch (final SettingException e) {
-                LOG.error(e.getMessage(), e);
-            }
-            /*
-             * Append GAB only if enabled for requesting user
-             */
-            final int gabID = FolderObject.SYSTEM_LDAP_FOLDER_ID;
-            final EffectivePermission oclPerm = oxfs.getFolderPermission(gabID, userId, userConfiguration);
-            if (oclPerm.isFolderVisible() && oclPerm.canReadAllObjects()) {
-                searchobject.addFolder(gabID);
-                considerUsersAliases = true;
             }
         }
         if (searchobject.hasFolders()) {
@@ -451,28 +462,28 @@ public class RdbContactSQLImpl implements ContactSQLInterface {
             }
         }
         Search.checkPatternLength(searchobject);
-        final StringBuilder order = new StringBuilder();
+        final StringBuilder sqlQrder = new StringBuilder();
         final boolean specialSort;
-        if (order_field > 0 && order_field != Contact.SPECIAL_SORTING) {
+        if (order_field > 0 && order_field != Contact.SPECIAL_SORTING && !Order.NO_ORDER.equals(order)) {
             specialSort = false;
-            order.append(" ORDER BY co.");
+            sqlQrder.append(" ORDER BY co.");
             final int realOrderField = order_field == Contact.USE_COUNT_GLOBAL_FIRST ? Contact.USE_COUNT : order_field;
-            order.append(Contacts.mapping[realOrderField].getDBFieldName());
-            order.append(' ');
-            final String realOrderMechanism = order_field == Contact.USE_COUNT_GLOBAL_FIRST ? "DESC" : orderMechanism;
+            sqlQrder.append(Contacts.mapping[realOrderField].getDBFieldName());
+            sqlQrder.append(' ');
+            final String realOrderMechanism = order_field == Contact.USE_COUNT_GLOBAL_FIRST ? "DESC" : forSQLCommand(order);
             if (realOrderMechanism != null && realOrderMechanism.length() > 0) {
-                order.append(realOrderMechanism);
+                sqlQrder.append(realOrderMechanism);
             } else {
-                order.append("ASC");
+                sqlQrder.append("ASC");
             }
-            order.append(' ');
+            sqlQrder.append(' ');
         } else {
             extendedCols =
                 Arrays.addUniquely(extendedCols, new int[] {
                     Contact.SUR_NAME, Contact.DISPLAY_NAME, Contact.COMPANY, Contact.EMAIL1, Contact.EMAIL2, Contact.USE_COUNT });
             specialSort = true;
         }
-        cs.setOrder(order.toString());
+        cs.setOrder(sqlQrder.toString());
         cs.setContactSearchObject(searchobject);
         cs.setSelect(cs.iFgetColsString(extendedCols).toString());
         final Connection con;
@@ -569,14 +580,14 @@ public class RdbContactSQLImpl implements ContactSQLInterface {
         ContactException.NO_PERMISSION_MSG,
         "An error occurred during the load of folder objects by a simple search. Context %1$d Folder %2$d User %3$d",
         "An error occurred during the load of folder objects by a simple search. Context %1$d Folder %2$d User %3$d" })
-    public SearchIterator<Contact> searchContacts(final String searchpattern, final int folderId, final int order_field, final String orderMechanism, final int[] cols) throws OXException {
+    public SearchIterator<Contact> searchContacts(final String searchpattern, final int folderId, final int order_field, final Order order, final int[] cols) throws OXException {
         boolean error = false;
-        String orderDir = orderMechanism;
+        String orderDir = forSQLCommand(order);
         int orderBy = order_field;
         if (orderBy == 0) {
             orderBy = 502;
         }
-        if (orderDir == null || orderDir.length() < 1) {
+        if (" ".equals(orderDir)) {
             orderDir = " ASC ";
         }
         Connection readcon = null;
@@ -615,10 +626,10 @@ public class RdbContactSQLImpl implements ContactSQLInterface {
             final ContactSql cs = new ContactMySql(session, ctx);
             cs.setFolder(folderId);
             cs.setSearchHabit(" OR ");
-            final String order =
+            final String sqlOrder =
                 new StringBuilder(32).append(" ORDER BY co.").append(Contacts.mapping[orderBy].getDBFieldName()).append(' ').append(
                     orderDir).append(' ').toString();
-            cs.setOrder(order);
+            cs.setOrder(sqlOrder);
 
             final EffectivePermission oclPerm = folderAccess.getFolderPermission(folderId, userId, userConfiguration);
             if (oclPerm.getFolderPermission() <= OCLPermission.NO_PERMISSIONS) {
@@ -1297,7 +1308,7 @@ public class RdbContactSQLImpl implements ContactSQLInterface {
              */
             int cnt = 8;
             for (int a = 0; a < cols.length; a++) {
-                final mapper m = Contacts.mapping[cols[a]];
+                final Mapper m = Contacts.mapping[cols[a]];
                 if (m != null) {
                     m.addToContactObject(rs, cnt, co, con, userId, memberInGroups, ctx, userConfiguration);
                     cnt++;
@@ -1405,7 +1416,7 @@ public class RdbContactSQLImpl implements ContactSQLInterface {
 
         @OXThrowsMultiple(category = { Category.CODE_ERROR, Category.CODE_ERROR }, desc = { "56", "57" }, exceptionId = { 56, 57 }, msg = {
             "Unable to get next Object. Context %1$d User %2$d", "Unable to get next Object. Context %1$d User %2$d" })
-        public Contact next() throws OXException, SearchIteratorException {
+        public Contact next() throws OXException {
             try {
                 if (rs.next()) {
                     try {
@@ -1458,18 +1469,10 @@ public class RdbContactSQLImpl implements ContactSQLInterface {
     }
 
     public int getFolderId() {
-        // TODO Auto-generated method stub
         return 0;
     }
 
     public LdapServer getLdapServer() {
-        // TODO Auto-generated method stub
         return null;
     }
-
-    public void setSession(final Session s) {
-        // TODO Auto-generated method stub
-
-    }
-
 }
