@@ -694,7 +694,7 @@ public final class EventQueue {
             }
             if (null != ServerServiceRegistry.getInstance().getService(TimerService.class)) {
                 // TODO TimerService is gone. Maybe event queues must be processed without the task.
-                if (!ALL_EVENTS_PROCESSED.await(2 * delay, TimeUnit.SECONDS)) {
+                if (!ALL_EVENTS_PROCESSED.await(2 * delay, TimeUnit.MILLISECONDS)) {
                     LOG.warn("Task did not clean event queues on shutdown.");
                 }
             }
