@@ -76,6 +76,7 @@ import com.openexchange.folderstorage.internal.StorageParametersImpl;
 import com.openexchange.folderstorage.internal.performers.ClearPerformer;
 import com.openexchange.folderstorage.internal.performers.CreatePerformer;
 import com.openexchange.folderstorage.internal.performers.DeletePerformer;
+import com.openexchange.folderstorage.internal.performers.PathPerformer;
 import com.openexchange.folderstorage.internal.performers.UpdatePerformer;
 import com.openexchange.folderstorage.internal.performers.UpdatesPerformer;
 import com.openexchange.groupware.contexts.impl.ContextException;
@@ -175,6 +176,55 @@ public final class CacheFolderStorage implements FolderStorage {
         }
     }
 
+    public void checkConsistency(final String treeId, final StorageParameters storageParameters) throws FolderException {
+        for (final FolderStorage folderStorage : registry.getFolderStoragesForTreeID(treeId)) {
+            folderStorage.checkConsistency(treeId, storageParameters);
+        }
+    }
+
+    public void restore(final String treeId, final String folderId, final StorageParameters storageParameters) throws FolderException {
+        final FolderStorage storage = registry.getFolderStorage(treeId, folderId);
+        if (null == storage) {
+            throw FolderExceptionErrorMessage.NO_STORAGE_FOR_ID.create(treeId, folderId);
+        }
+        final boolean started = storage.startTransaction(storageParameters, false);
+        try {
+            storage.restore(treeId, folderId, storageParameters);
+            if (started) {
+                storage.commitTransaction(storageParameters);
+            }
+        } catch (final FolderException e) {
+            if (started) {
+                storage.rollback(storageParameters);
+            }
+            throw e;
+        } catch (final Exception e) {
+            if (started) {
+                storage.rollback(storageParameters);
+            }
+            throw FolderExceptionErrorMessage.UNEXPECTED_ERROR.create(e, e.getMessage());
+        } finally {
+            removeFromCache(
+                folderId,
+                treeId,
+                storageParameters.getUserId(),
+                storageParameters.getContextId(),
+                newPathPerformer(storageParameters));
+        }
+    }
+
+    private PathPerformer newPathPerformer(final StorageParameters storageParameters) throws FolderException {
+        final Session session = storageParameters.getSession();
+        if (null == session) {
+            return new PathPerformer(storageParameters.getUser(), storageParameters.getContext(), null, registry);
+        }
+        try {
+            return new PathPerformer(new ServerSessionAdapter(session), null, registry);
+        } catch (final ContextException e) {
+            throw new FolderException(e);
+        }
+    }
+
     public ContentType getDefaultContentType() {
         return null;
     }
@@ -213,7 +263,7 @@ public final class CacheFolderStorage implements FolderStorage {
         /*
          * Refresh parent
          */
-        removeFolder(folder.getParentID(), treeId, storageParameters);
+        removeSingleFromCache(folder.getParentID(), treeId, storageParameters.getUserId(), storageParameters.getContextId());
         final Folder parentFolder = loadFolder(treeId, folder.getParentID(), StorageType.WORKING, storageParameters);
         if (parentFolder.isCacheable()) {
             putFolder(parentFolder, treeId, storageParameters);
@@ -239,10 +289,62 @@ public final class CacheFolderStorage implements FolderStorage {
         }
     }
 
-    private void removeFolder(final String id, final String treeId, final StorageParameters storageParameters) throws FolderException {
+    /**
+     * Removes specified folder and all of its predecessor folders from cache.
+     * 
+     * @param id The folder identifier
+     * @param treeId The tree identifier
+     * @param singleOnly <code>true</code> if only specified folder should be removed; otherwise <code>false</code> for complete folder's
+     *            path to root folder
+     * @param session The session providing user information
+     * @throws FolderException If removal fails
+     */
+    public void removeFromCache(final String id, final String treeId, final boolean singleOnly, final Session session) throws FolderException {
+        if (singleOnly) {
+            removeSingleFromCache(id, treeId, session.getUserId(), session.getContextId());
+        } else {
+            try {
+                removeFromCache(id, treeId, session.getUserId(), session.getContextId(), new PathPerformer(
+                    new ServerSessionAdapter(session),
+                    null,
+                    registry));
+            } catch (final ContextException e) {
+                throw new FolderException(e);
+            }
+        }
+    }
+
+    private void removeFromCache(final String id, final String treeId, final int userId, final int contextId, final PathPerformer pathPerformer) throws FolderException {
+        try {
+            final List<String> ids;
+            {
+                final UserizedFolder[] path = pathPerformer.doPath(treeId, id, true);
+                ids = new ArrayList<String>(path.length);
+                for (final UserizedFolder userizedFolder : path) {
+                    ids.add(userizedFolder.getID());
+                }
+            }
+            if (FolderStorage.REAL_TREE_ID.equals(treeId)) {
+                for (final String folderId : ids) {
+                    globalCache.remove(newCacheKey(folderId, treeId, contextId));
+                    userCache.remove(newCacheKey(folderId, treeId, contextId, userId));
+                }
+            } else {
+                for (final String folderId : ids) {
+                    globalCache.remove(newCacheKey(folderId, treeId, contextId));
+                    userCache.remove(newCacheKey(folderId, treeId, contextId, userId));
+                    // Now for real tree, too
+                    globalCache.remove(newCacheKey(folderId, FolderStorage.REAL_TREE_ID, contextId));
+                    userCache.remove(newCacheKey(folderId, FolderStorage.REAL_TREE_ID, contextId, userId));
+                }
+            }
+        } catch (final CacheException e) {
+            throw new FolderException(e);
+        }
+    }
+
+    private void removeSingleFromCache(final String id, final String treeId, final int userId, final int contextId) throws FolderException {
         try {
-            final int contextId = storageParameters.getContextId();
-            final int userId = storageParameters.getUserId();
             globalCache.remove(newCacheKey(id, treeId, contextId));
             userCache.remove(newCacheKey(id, treeId, contextId, userId));
             if (!FolderStorage.REAL_TREE_ID.equals(treeId)) {
@@ -341,14 +443,23 @@ public final class CacheFolderStorage implements FolderStorage {
             }
         }
         /*
-         * Refresh parent
+         * Refresh
          */
         if (null != realParentId && !FolderStorage.ROOT_ID.equals(realParentId)) {
-            removeFolder(realParentId, treeId, storageParameters);
-            removeFolder(realParentId, FolderStorage.REAL_TREE_ID, storageParameters);
+            removeFromCache(
+                realParentId,
+                treeId,
+                storageParameters.getUserId(),
+                storageParameters.getContextId(),
+                newPathPerformer(storageParameters));
         }
         if (!FolderStorage.ROOT_ID.equals(parentId)) {
-            removeFolder(parentId, treeId, storageParameters);
+            removeFromCache(
+                parentId,
+                treeId,
+                storageParameters.getUserId(),
+                storageParameters.getContextId(),
+                newPathPerformer(storageParameters));
             final Folder parentFolder = loadFolder(treeId, parentId, StorageType.WORKING, storageParameters);
             if (parentFolder.isCacheable()) {
                 putFolder(parentFolder, treeId, storageParameters);
@@ -463,8 +574,12 @@ public final class CacheFolderStorage implements FolderStorage {
         /*
          * Invalidate cache entry
          */
-        removeFolder(folderId, treeId, storageParameters);
-        removeFolder(folderId, REAL_TREE_ID, storageParameters);
+        removeFromCache(
+            folderId,
+            treeId,
+            storageParameters.getUserId(),
+            storageParameters.getContextId(),
+            newPathPerformer(storageParameters));
     }
 
     public Folder getFolder(final String treeId, final String folderId, final StorageParameters storageParameters) throws FolderException {
@@ -655,15 +770,22 @@ public final class CacheFolderStorage implements FolderStorage {
         /*
          * Refresh/Invalidate folder
          */
-        removeFolder(folderId, treeId, storageParameters);
+        removeFromCache(
+            folderId,
+            treeId,
+            storageParameters.getUserId(),
+            storageParameters.getContextId(),
+            newPathPerformer(storageParameters));
         /*
-         * Refresh/invalidate parent(s)
+         * Old folder if needed
          */
-        if (!FolderStorage.ROOT_ID.equals(parentID)) {
-            removeFolder(parentID, treeId, storageParameters);
-        }
         if (null != oldParentId && !FolderStorage.ROOT_ID.equals(oldParentId)) {
-            removeFolder(oldParentId, treeId, storageParameters);
+            removeFromCache(
+                oldParentId,
+                treeId,
+                storageParameters.getUserId(),
+                storageParameters.getContextId(),
+                newPathPerformer(storageParameters));
         }
     }
 
