@@ -96,6 +96,7 @@ import com.openexchange.folderstorage.type.SharedType;
 import com.openexchange.groupware.container.FolderObject;
 import com.openexchange.groupware.contexts.Context;
 import com.openexchange.groupware.contexts.impl.ContextException;
+import com.openexchange.groupware.i18n.FolderStrings;
 import com.openexchange.groupware.ldap.User;
 import com.openexchange.groupware.userconfiguration.UserConfiguration;
 import com.openexchange.groupware.userconfiguration.UserConfigurationStorage;
@@ -130,6 +131,10 @@ public final class DatabaseFolderStorage implements FolderStorage {
         super();
     }
 
+    public void checkConsistency(final String treeId, final StorageParameters storageParameters) throws FolderException {
+        // Nothing to do
+    }
+
     private static OXFolderAccess getFolderAccess(final StorageParameters storageParameters, final FolderType folderType) {
         OXFolderAccess ret = (OXFolderAccess) storageParameters.getParameter(folderType, DatabaseParameterConstants.PARAM_ACCESS);
         if (null == ret) {
@@ -185,6 +190,31 @@ public final class DatabaseFolderStorage implements FolderStorage {
         }
     }
 
+    public void restore(final String treeId, final String folderIdentifier, final StorageParameters storageParameters) throws FolderException {
+        try {
+            final Connection con = getParameter(Connection.class, DatabaseParameterConstants.PARAM_CONNECTION, storageParameters);
+            final Session session = storageParameters.getSession();
+            if (null == session) {
+                throw FolderExceptionErrorMessage.MISSING_SESSION.create(new Object[0]);
+            }
+            final int folderId = Integer.parseInt(folderIdentifier);
+            final Context context = storageParameters.getContext();
+            FolderObject.loadFolderObjectFromDB(folderId, context, con, false, false, "del_oxfolder_tree", "del_oxfolder_permissions");
+            /*
+             * From backup to working table
+             */
+            OXFolderSQL.restore(folderId, context, null);
+        } catch (final NumberFormatException e) {
+            throw FolderExceptionErrorMessage.INVALID_FOLDER_ID.create(folderIdentifier);
+        } catch (final OXException e) {
+            throw new FolderException(e);
+        } catch (final DBPoolingException e) {
+            throw new FolderException(e);
+        } catch (final SQLException e) {
+            throw FolderExceptionErrorMessage.SQL_ERROR.create(e, e.getMessage());
+        }
+    }
+
     public void createFolder(final Folder folder, final StorageParameters storageParameters) throws FolderException {
         try {
             final Connection con = getParameter(Connection.class, DatabaseParameterConstants.PARAM_CONNECTION, storageParameters);
@@ -555,24 +585,65 @@ public final class DatabaseFolderStorage implements FolderStorage {
                              * Check for shared folder, that is folder is of type private and requesting user is different from folder's
                              * owner
                              */
-                            retval = new DatabaseFolder(fo);
+                            if (FolderObject.SYSTEM_PUBLIC_INFOSTORE_FOLDER_ID == folderId) {
+                                retval = new LocalizedDatabaseFolder(fo);
+                                retval.setName(FolderStrings.SYSTEM_PUBLIC_INFOSTORE_FOLDER_NAME);
+                            } else if (FolderObject.SYSTEM_USER_INFOSTORE_FOLDER_ID == folderId) {
+                                retval = new LocalizedDatabaseFolder(fo);
+                                retval.setName(FolderStrings.SYSTEM_USER_INFOSTORE_FOLDER_NAME);
+                            } else if (FolderObject.SYSTEM_LDAP_FOLDER_ID == folderId) {
+                                retval = new LocalizedDatabaseFolder(fo);
+                                retval.setName(FolderStrings.SYSTEM_LDAP_FOLDER_NAME);
+                                retval.setParentID(FolderStorage.PUBLIC_ID);
+                            } else if (FolderObject.SYSTEM_GLOBAL_FOLDER_ID == folderId) {
+                                retval = new LocalizedDatabaseFolder(fo);
+                                retval.setName(FolderStrings.SYSTEM_GLOBAL_FOLDER_NAME);
+                                retval.setParentID(FolderStorage.PUBLIC_ID);
+                            } else if (fo.isDefaultFolder()) {
+                                /*
+                                 * A default folder: set locale-sensitive name
+                                 */
+                                if (fo.getModule() == FolderObject.TASK) {
+                                    retval = new LocalizedDatabaseFolder(fo);
+                                    retval.setName(FolderStrings.DEFAULT_TASK_FOLDER_NAME);
+                                } else if (fo.getModule() == FolderObject.CONTACT) {
+                                    retval = new LocalizedDatabaseFolder(fo);
+                                    retval.setName(FolderStrings.DEFAULT_CONTACT_FOLDER_NAME);
+                                } else if (fo.getModule() == FolderObject.CALENDAR) {
+                                    retval = new LocalizedDatabaseFolder(fo);
+                                    retval.setName(FolderStrings.DEFAULT_CALENDAR_FOLDER_NAME);
+                                } else {
+                                    retval = new DatabaseFolder(fo);
+                                }
+                            } else {
+                                retval = new DatabaseFolder(fo);
+                            }
                             if (PrivateType.getInstance().equals(retval.getType()) && storageParameters.getUserId() != retval.getCreatedBy()) {
                                 retval.setType(SharedType.getInstance());
                                 /*
                                  * A shared folder has no subfolders in real tree
                                  */
-                                retval.setSubfolderIDs(null);
+                                retval.setSubfolderIDs(new String[0]);
+                                retval.setSubscribedSubfolders(false);
+                                retval.setCacheable(false);
+                                retval.setParentID(new StringBuilder(16).append(FolderObject.SHARED_PREFIX).append(retval.getCreatedBy()).toString());
                             } else if (FolderObject.SYSTEM_PRIVATE_FOLDER_ID != folderId) {
                                 /*
                                  * Set subfolders for non-private folder. For private folder FolderStorage.getSubfolders() is supposed to be
                                  * used.
                                  */
                                 final List<Integer> subfolderIds = FolderObject.getSubfolderIds(folderId, ctx, con);
-                                final List<String> subfolderIdentifies = new ArrayList<String>(subfolderIds.size());
-                                for (final Integer id : subfolderIds) {
-                                    subfolderIdentifies.add(id.toString());
+                                if (subfolderIds.isEmpty()) {
+                                    retval.setSubfolderIDs(new String[0]);
+                                    retval.setSubscribedSubfolders(false);
+                                } else {
+                                    final List<String> tmp = new ArrayList<String>(subfolderIds.size());
+                                    for (final Integer id : subfolderIds) {
+                                        tmp.add(id.toString());
+                                    }
+                                    retval.setSubfolderIDs(tmp.toArray(new String[tmp.size()]));
+                                    retval.setSubscribedSubfolders(true);
                                 }
-                                retval.setSubfolderIDs(subfolderIdentifies.toArray(new String[subfolderIdentifies.size()]));
                             }
                         }
                     }
@@ -1144,7 +1215,7 @@ public final class DatabaseFolderStorage implements FolderStorage {
             return collator.compare(o1.getFolderName(), o2.getFolderName());
         }
 
-        private int compareById(final int id1, final int id2) {
+        private static int compareById(final int id1, final int id2) {
             return (id1 < id2 ? -1 : (id1 == id2 ? 0 : 1));
         }
 
