@@ -173,13 +173,14 @@ public final class VirtualListFolder {
                 FolderObject.createVirtualFolderObject(
                     folderId,
                     FolderStrings.VIRTUAL_LIST_INFOSTORE_FOLDER_NAME,
-                    FolderObject.SYSTEM_MODULE,
+                    FolderObject.INFOSTORE,
                     true,
                     FolderObject.SYSTEM_TYPE);
             fo.setParentFolderID(FolderObject.SYSTEM_INFOSTORE_FOLDER_ID);
         }
         final DatabaseFolder retval = new LocalizedDatabaseFolder(fo);
         retval.setSubfolderIDs(null);
+        retval.setSubscribedSubfolders(true);
         retval.setGlobal(true);
         return retval;
     }
