@@ -204,7 +204,7 @@ public final class ListPerformer extends AbstractUserizedFolderPerformer {
                 } else {
                     parentPermission = CalculatePermission.calculate(parent, getSession(), getAllowedContentTypes());
                 }
-                if (parentPermission.getFolderPermission() <= Permission.NO_PERMISSIONS) {
+                if (!parentPermission.isVisible()) {
                     throw FolderExceptionErrorMessage.FOLDER_NOT_VISIBLE.create(
                         parentId,
                         getUser().getDisplayName(),
@@ -248,27 +248,36 @@ public final class ListPerformer extends AbstractUserizedFolderPerformer {
                             /*
                              * Check for access rights and subscribed status dependent on parameter "all"
                              */
-                            final Permission subfolderPermission;
-                            if (null == getSession()) {
-                                subfolderPermission =
-                                    CalculatePermission.calculate(subfolder, getUser(), getContext(), getAllowedContentTypes());
-                            } else {
-                                subfolderPermission = CalculatePermission.calculate(subfolder, getSession(), getAllowedContentTypes());
-                            }
-                            if (subfolderPermission.getFolderPermission() > Permission.NO_PERMISSIONS && (all ? true : subfolder.isSubscribed())) {
-                                final List<FolderStorage> openedStorages = new ArrayList<FolderStorage>(2);
-                                try {
-                                    final UserizedFolder userizedFolder =
-                                        getUserizedFolder(subfolder, subfolderPermission, treeId, all, true, newParameters, openedStorages);
-                                    subfolders[index] = userizedFolder;
-                                    for (final FolderStorage openedStorage : openedStorages) {
-                                        openedStorage.commitTransaction(newParameters);
+                            if ((all || (subfolder.isSubscribed() || subfolder.hasSubscribedSubfolders()))) {
+                                final Permission subfolderPermission;
+                                if (null == getSession()) {
+                                    subfolderPermission =
+                                        CalculatePermission.calculate(subfolder, getUser(), getContext(), getAllowedContentTypes());
+                                } else {
+                                    subfolderPermission = CalculatePermission.calculate(subfolder, getSession(), getAllowedContentTypes());
+                                }
+                                if (subfolderPermission.isVisible()) {
+                                    final List<FolderStorage> openedStorages = new ArrayList<FolderStorage>(2);
+                                    try {
+                                        final UserizedFolder userizedFolder =
+                                            getUserizedFolder(
+                                                subfolder,
+                                                subfolderPermission,
+                                                treeId,
+                                                all,
+                                                true,
+                                                newParameters,
+                                                openedStorages);
+                                        subfolders[index] = userizedFolder;
+                                        for (final FolderStorage openedStorage : openedStorages) {
+                                            openedStorage.commitTransaction(newParameters);
+                                        }
+                                    } catch (final Exception e) {
+                                        for (final FolderStorage openedStorage : openedStorages) {
+                                            openedStorage.rollback(newParameters);
+                                        }
+                                        throw e;
                                     }
-                                } catch (final Exception e) {
-                                    for (final FolderStorage openedStorage : openedStorages) {
-                                        openedStorage.rollback(newParameters);
-                                    }
-                                    throw e;
                                 }
                             }
                             return null;
@@ -422,7 +431,7 @@ public final class ListPerformer extends AbstractUserizedFolderPerformer {
                         /*
                          * Check for subscribed status dependent on parameter "all"
                          */
-                        if (all || subfolder.isSubscribed()) {
+                        if (all || (subfolder.isSubscribed() || subfolder.hasSubscribedSubfolders())) {
                             final Permission userPermission;
                             if (null == getSession()) {
                                 userPermission =
@@ -430,7 +439,7 @@ public final class ListPerformer extends AbstractUserizedFolderPerformer {
                             } else {
                                 userPermission = CalculatePermission.calculate(subfolder, getSession(), getAllowedContentTypes());
                             }
-                            if (userPermission.getFolderPermission() >= Permission.READ_FOLDER) {
+                            if (userPermission.isVisible()) {
                                 subfolders[index] =
                                     getUserizedFolder(subfolder, userPermission, treeId, all, true, newParameters, openedStorages);
                             }
@@ -451,6 +460,7 @@ public final class ListPerformer extends AbstractUserizedFolderPerformer {
                         throw FolderException.newUnexpectedException(e);
                     }
                 }
+
             });
         }
         /*
