@@ -60,6 +60,7 @@ import com.openexchange.folderstorage.FolderStorage;
 import com.openexchange.folderstorage.FolderStorageDiscoverer;
 import com.openexchange.folderstorage.Permission;
 import com.openexchange.folderstorage.UserizedFolder;
+import com.openexchange.folderstorage.type.PublicType;
 import com.openexchange.groupware.contexts.Context;
 import com.openexchange.groupware.ldap.User;
 import com.openexchange.tools.session.ServerSession;
@@ -159,11 +160,11 @@ public final class UpdatePerformer extends AbstractPerformer {
             }
             final boolean changePermissions;
             {
-                final Permission[] newPerms = folder.getPermissions();
+                final Permission[] newPerms = stripSystemPermissions(folder.getPermissions());
                 if (null == newPerms) {
                     changePermissions = false;
                 } else {
-                    final Permission[] oldPerms = storageFolder.getPermissions();
+                    final Permission[] oldPerms = stripSystemPermissions(storageFolder.getPermissions());
                     if (newPerms.length != oldPerms.length) {
                         changePermissions = true;
                     } else {
@@ -186,6 +187,10 @@ public final class UpdatePerformer extends AbstractPerformer {
                     }
                 }
             }
+            final boolean changeSubscription;
+            {
+                changeSubscription = (storageFolder.isSubscribed() != folder.isSubscribed());
+            }
             /*
              * Do move?
              */
@@ -215,6 +220,31 @@ public final class UpdatePerformer extends AbstractPerformer {
                 if (equallyNamedSibling(folder.getName(), treeId, newParentId, openedStorages)) {
                     throw FolderExceptionErrorMessage.EQUAL_NAME.create(folder.getName(), newParentId, treeId);
                 }
+                /*
+                 * Check for forbidden public mail folder
+                 */
+                {
+                    final boolean started = newRealParentStorage.startTransaction(storageParameters, false);
+                    try {
+                        final Folder newParent = newRealParentStorage.getFolder(FolderStorage.REAL_TREE_ID, newParentId, storageParameters);
+                        if ((FolderStorage.PUBLIC_ID.equals(newParent.getID()) || PublicType.getInstance().equals(newParent.getType())) && "mail".equals(storageFolder.getContentType().toString())) {
+                            throw FolderExceptionErrorMessage.NO_PUBLIC_MAIL_FOLDER.create();
+                        }
+                        if (started) {
+                            newRealParentStorage.commitTransaction(storageParameters);
+                        }
+                    } catch (final FolderException e) {
+                        if (started) {
+                            newRealParentStorage.rollback(storageParameters);
+                        }
+                        throw e;
+                    } catch (final Exception e) {
+                        if (started) {
+                            newRealParentStorage.rollback(storageParameters);
+                        }
+                        throw FolderExceptionErrorMessage.UNEXPECTED_ERROR.create(e, e.getMessage());
+                    }
+                }
 
                 /*
                  * Perform move either in real or in virtual storage
@@ -259,6 +289,25 @@ public final class UpdatePerformer extends AbstractPerformer {
                         storage.updateFolder(folder, storageParameters);
                     }
                 }
+            } else if (changeSubscription) {
+                /*
+                 * Change subscription either in real or in virtual storage
+                 */
+                if (FolderStorage.REAL_TREE_ID.equals(folder.getTreeID())) {
+                    storage.updateFolder(folder, storageParameters);
+                } else {
+                    final FolderStorage realStorage = folderStorageDiscoverer.getFolderStorage(FolderStorage.REAL_TREE_ID, folder.getID());
+                    if (null == realStorage) {
+                        throw FolderExceptionErrorMessage.NO_STORAGE_FOR_ID.create(FolderStorage.REAL_TREE_ID, folder.getID());
+                    }
+                    if (storage.equals(realStorage)) {
+                        storage.updateFolder(folder, storageParameters);
+                    } else {
+                        checkOpenedStorage(realStorage, openedStorages);
+                        realStorage.updateFolder(folder, storageParameters);
+                        storage.updateFolder(folder, storageParameters);
+                    }
+                }
             }
             /*
              * Commit
@@ -372,4 +421,19 @@ public final class UpdatePerformer extends AbstractPerformer {
         return nonExistingName;
     }
 
+    private static Permission[] stripSystemPermissions(final Permission[] permissions) {
+        if (null == permissions) {
+            return null;
+        }
+        final int len = permissions.length;
+        final List<Permission> list = new ArrayList<Permission>(len);
+        for (int i = 0; i < len; i++) {
+            final Permission permission = permissions[i];
+            if (0 == permission.getSystem()) {
+                list.add(permission);
+            }
+        }
+        return list.toArray(new Permission[list.size()]);
+    }
+
 }
