@@ -62,6 +62,7 @@ import java.util.Comparator;
 import java.util.Date;
 import java.util.HashMap;
 import java.util.HashSet;
+import java.util.Iterator;
 import java.util.List;
 import java.util.Locale;
 import java.util.Map;
@@ -78,6 +79,7 @@ import com.openexchange.folderstorage.SortableId;
 import com.openexchange.folderstorage.StorageParameters;
 import com.openexchange.folderstorage.StoragePriority;
 import com.openexchange.folderstorage.StorageType;
+import com.openexchange.folderstorage.Type;
 import com.openexchange.folderstorage.mail.contentType.DraftsContentType;
 import com.openexchange.folderstorage.mail.contentType.MailContentType;
 import com.openexchange.folderstorage.mail.contentType.SentContentType;
@@ -99,6 +101,7 @@ import com.openexchange.mail.api.IMailMessageStorage;
 import com.openexchange.mail.api.MailAccess;
 import com.openexchange.mail.api.MailProvider;
 import com.openexchange.mail.cache.MailMessageCache;
+import com.openexchange.mail.config.MailProperties;
 import com.openexchange.mail.dataobjects.MailFolder;
 import com.openexchange.mail.dataobjects.MailFolderDescription;
 import com.openexchange.mail.dataobjects.MailMessage;
@@ -109,6 +112,7 @@ import com.openexchange.mailaccount.MailAccount;
 import com.openexchange.mailaccount.MailAccountException;
 import com.openexchange.mailaccount.MailAccountStorageService;
 import com.openexchange.mailaccount.UnifiedINBOXManagement;
+import com.openexchange.mailaccount.internal.RdbMailAccountStorage;
 import com.openexchange.server.ServiceException;
 import com.openexchange.server.osgiservice.ServiceRegistry;
 import com.openexchange.session.Session;
@@ -133,6 +137,10 @@ public final class MailFolderStorage implements FolderStorage {
         super();
     }
 
+    public void checkConsistency(String treeId, StorageParameters storageParameters) throws FolderException {
+        // Nothing to do
+    }
+
     private MailAccess<?, ?> getMailAccessForAccount(final int accountId, final Session session, final TIntObjectHashMap<MailAccess<?, ?>> accesses) throws FolderException {
         MailAccess<?, ?> ma = accesses.get(accountId);
         if (null == ma) {
@@ -143,6 +151,7 @@ public final class MailFolderStorage implements FolderStorage {
             }
             final MailAccess<?, ?> prev = accesses.putIfAbsent(accountId, ma);
             if (null != prev) {
+                ma.close(true);
                 ma = prev;
             }
         }
@@ -193,6 +202,39 @@ public final class MailFolderStorage implements FolderStorage {
         }
     }
 
+    public SortableId[] getVisibleFolders(String treeId, ContentType contentType, Type type, StorageParameters storageParameters) throws FolderException {
+        throw new UnsupportedOperationException("VirtualFolderStorage.getVisibleSubfolders()");
+    }
+
+    public void restore(String treeId, String folderId, StorageParameters storageParameters) throws FolderException {
+        try {
+            @SuppressWarnings("unchecked") final TIntObjectHashMap<MailAccess<?, ?>> accesses =
+                (TIntObjectHashMap<MailAccess<?, ?>>) storageParameters.getParameter(
+                    MailFolderType.getInstance(),
+                    MailParameterConstants.PARAM_MAIL_ACCESS);
+            if (null == accesses) {
+                throw new FolderException(new MailException(MailException.Code.MISSING_PARAM, MailParameterConstants.PARAM_MAIL_ACCESS));
+            }
+            final FullnameArgument argument = prepareMailFolderParam(folderId);
+            final int accountId = argument.getAccountId();
+            final String fullname = argument.getFullname();
+            if (MailFolder.DEFAULT_FOLDER_ID.equals(fullname)) {
+                throw FolderExceptionErrorMessage.UNEXPECTED_ERROR.create();
+            }
+            final Session session = storageParameters.getSession();
+            final MailAccess<?, ?> mailAccess = getMailAccessForAccount(accountId, session, accesses);
+            openMailAccess(mailAccess);
+            /*
+             * Restore if absent
+             */
+            if (!mailAccess.getFolderStorage().exists(fullname)) {
+                recreateMailFolder(accountId, fullname, session, mailAccess);
+            }
+        } catch (final MailException e) {
+            throw new FolderException(e);
+        }
+    }
+
     public void createFolder(final Folder folder, final StorageParameters storageParameters) throws FolderException {
         try {
             final @SuppressWarnings("unchecked") TIntObjectHashMap<MailAccess<?, ?>> accesses =
@@ -440,7 +482,8 @@ public final class MailFolderStorage implements FolderStorage {
             final int accountId = argument.getAccountId();
             final String fullname = argument.getFullname();
 
-            final MailAccess<?, ?> mailAccess = getMailAccessForAccount(accountId, storageParameters.getSession(), accesses);
+            final Session session = storageParameters.getSession();
+            final MailAccess<?, ?> mailAccess = getMailAccessForAccount(accountId, session, accesses);
 
             final MailFolderImpl retval;
             final boolean hasSubfolders;
@@ -449,8 +492,8 @@ public final class MailFolderStorage implements FolderStorage {
                 retval =
                     new MailFolderImpl(
                         rootFolder,
-                        mailAccess.getAccountId(),
-                        mailAccess.getMailConfig().getCapabilities().getCapabilities(),
+                        accountId,
+                        mailAccess.getMailConfig(),
                         null);
                 /*
                  * Set proper name for non-primary account
@@ -476,12 +519,15 @@ public final class MailFolderStorage implements FolderStorage {
                 hasSubfolders = rootFolder.hasSubfolders();
             } else {
                 openMailAccess(mailAccess);
-                final MailFolder mailFolder = mailAccess.getFolderStorage().getFolder(fullname);
+                final MailFolder mailFolder = getMailFolder(treeId, accountId, fullname, true, session, mailAccess);
+                /*
+                 * Generate mail folder from loaded one
+                 */
                 retval =
                     new MailFolderImpl(
                         mailFolder,
-                        mailAccess.getAccountId(),
-                        mailAccess.getMailConfig().getCapabilities().getCapabilities(),
+                        accountId,
+                        mailAccess.getMailConfig(),
                         new MailAccessFullnameProvider(mailAccess));
                 hasSubfolders = mailFolder.hasSubfolders();
             }
@@ -493,7 +539,19 @@ public final class MailFolderStorage implements FolderStorage {
                 /*
                  * Denoted parent is not capable to hold default folders. Therefore output as it is.
                  */
-                final List<MailFolder> children = Arrays.asList(mailAccess.getFolderStorage().getSubfolders(fullname, true));
+                final List<MailFolder> children = new ArrayList<MailFolder>(Arrays.asList(mailAccess.getFolderStorage().getSubfolders(fullname, true)));
+                /*
+                 * Filter against possible POP3 storage folders
+                 */
+                if (MailAccount.DEFAULT_ID == accountId && MailProperties.getInstance().isHidePOP3StorageFolders()) {
+                    final Set<String> pop3StorageFolders = RdbMailAccountStorage.getPOP3StorageFolders(session);
+                    for (final Iterator<MailFolder> it = children.iterator(); it.hasNext();) {
+                        final MailFolder mf = it.next();
+                        if (pop3StorageFolders.contains(mf.getFullname())) {
+                            it.remove();
+                        }
+                    }            
+                }
                 Collections.sort(children, new SimpleMailFolderComparator(storageParameters.getUser().getLocale()));
                 final String[] subfolderIds = new String[children.size()];
                 int i = 0;
@@ -511,10 +569,22 @@ public final class MailFolderStorage implements FolderStorage {
                     /*
                      * Ensure default folders are at first positions
                      */
-                    final List<MailFolder> children = Arrays.asList(mailAccess.getFolderStorage().getSubfolders(fullname, true));
+                    final List<MailFolder> children = new ArrayList<MailFolder>(Arrays.asList(mailAccess.getFolderStorage().getSubfolders(fullname, true)));
+                    /*
+                     * Filter against possible POP3 storage folders
+                     */
+                    if (MailAccount.DEFAULT_ID == accountId && MailProperties.getInstance().isHidePOP3StorageFolders()) {
+                        final Set<String> pop3StorageFolders = RdbMailAccountStorage.getPOP3StorageFolders(session);
+                        for (final Iterator<MailFolder> it = children.iterator(); it.hasNext();) {
+                            final MailFolder mf = it.next();
+                            if (pop3StorageFolders.contains(mf.getFullname())) {
+                                it.remove();
+                            }
+                        }            
+                    }
                     final String[] names;
-                    if (isDefaultFoldersChecked(accountId, storageParameters.getSession())) {
-                        names = getSortedDefaultMailFolders(accountId, storageParameters.getSession());
+                    if (isDefaultFoldersChecked(accountId, session)) {
+                        names = getSortedDefaultMailFolders(accountId, session);
                     } else {
                         final List<String> tmp = new ArrayList<String>();
                         tmp.add("INBOX");
@@ -561,6 +631,61 @@ public final class MailFolderStorage implements FolderStorage {
         }
     }
 
+    private static MailFolder getMailFolder(final String treeId, final int accountId, final String fullname, final boolean createIfAbsent, final Session session, final MailAccess<?, ?> mailAccess) throws MailException {
+        try {
+            return mailAccess.getFolderStorage().getFolder(fullname);
+        } catch (final MailException e) {
+            if (!createIfAbsent) {
+                throw e;
+            }
+            if ((MIMEMailException.Code.FOLDER_NOT_FOUND.getNumber() != e.getDetailNumber()) || FolderStorage.REAL_TREE_ID.equals(treeId)) {
+                throw e;
+            }
+            return recreateMailFolder(accountId, fullname, session, mailAccess);
+        }
+    }
+
+    private static MailFolder recreateMailFolder(final int accountId, final String fullname, final Session session, final MailAccess<?, ?> mailAccess) throws MailException {
+        /*
+         * Recreate the mail folder
+         */
+        final MailFolderDescription mfd = new MailFolderDescription();
+        mfd.setExists(false);
+        mfd.setAccountId(accountId);
+        mfd.setParentAccountId(accountId);
+        /*
+         * Parent fullname & name
+         */
+        final char separator = mailAccess.getFolderStorage().getFolder("INBOX").getSeparator();
+        final String[] parentAndName = splitBySeperator(fullname, separator);
+        mfd.setParentFullname(parentAndName[0]);
+        mfd.setName(parentAndName[1]);
+        mfd.setSeparator(separator);
+        {
+            final MailPermission mailPerm = MailProviderRegistry.getMailProviderBySession(session, accountId).createNewMailPermission();
+            mailPerm.setEntity(session.getUserId());
+            mailPerm.setGroupPermission(false);
+            mailPerm.setFolderAdmin(true);
+            final int max = MailPermission.ADMIN_PERMISSION;
+            mailPerm.setAllPermission(max, max, max, max);
+            mfd.addPermission(mailPerm);
+        }
+        mfd.setSubscribed(true);
+        /*
+         * Create
+         */
+        final String id = mailAccess.getFolderStorage().createFolder(mfd);
+        return mailAccess.getFolderStorage().getFolder(id);
+    }
+
+    private static String[] splitBySeperator(final String fullname, final char sep) {
+        final int pos = fullname.lastIndexOf(sep);
+        if (pos < 0) {
+            return new String[] { MailFolder.DEFAULT_FOLDER_ID, fullname };
+        }
+        return new String[] { fullname.substring(0, pos), fullname.substring(pos + 1) };
+    }
+
     private boolean isDefaultFoldersChecked(final int accountId, final Session session) {
         final Boolean b =
             MailSessionCache.getInstance(session).getParameter(accountId, MailSessionParameterNames.getParamDefaultFolderChecked());
@@ -647,7 +772,19 @@ public final class MailFolderStorage implements FolderStorage {
             final MailAccess<?, ?> mailAccess = getMailAccessForAccount(accountId, storageParameters.getSession(), accesses);
             openMailAccess(mailAccess);
 
-            final List<MailFolder> children = Arrays.asList(mailAccess.getFolderStorage().getSubfolders(fullname, true));
+            final List<MailFolder> children = new ArrayList<MailFolder>(Arrays.asList(mailAccess.getFolderStorage().getSubfolders(fullname, true)));
+            /*
+             * Filter against possible POP3 storage folders
+             */
+            if (MailAccount.DEFAULT_ID == accountId && MailProperties.getInstance().isHidePOP3StorageFolders()) {
+                final Set<String> pop3StorageFolders = RdbMailAccountStorage.getPOP3StorageFolders(session);
+                for (final Iterator<MailFolder> it = children.iterator(); it.hasNext();) {
+                    final MailFolder mf = it.next();
+                    if (pop3StorageFolders.contains(mf.getFullname())) {
+                        it.remove();
+                    }
+                }            
+            }
             /*
              * Check if denoted parent can hold default folders like Trash, Sent, etc.
              */
@@ -801,7 +938,7 @@ public final class MailFolderStorage implements FolderStorage {
         final Set<ContentType> supported = new HashSet<ContentType>(Arrays.asList(getSupportedContentTypes()));
         for (final ContentType includeContentType : includeContentTypes) {
             if (supported.contains(includeContentType)) {
-                final SortableId[] subfolders = getSubfolders(FolderStorage.REAL_TREE_ID, PRIVATE_FOLDER_ID, storageParameters);
+                final SortableId[] subfolders = getSubfolders(treeId, PRIVATE_FOLDER_ID, storageParameters);
                 for (final SortableId sortableId : subfolders) {
                     ret.add(sortableId.getId());
                 }
