@@ -76,8 +76,8 @@ import com.openexchange.folderstorage.SortableId;
 import com.openexchange.folderstorage.StorageParameters;
 import com.openexchange.folderstorage.StoragePriority;
 import com.openexchange.folderstorage.StorageType;
+import com.openexchange.folderstorage.Type;
 import com.openexchange.folderstorage.mail.MailParameterConstants;
-import com.openexchange.folderstorage.mail.MailServiceRegistry;
 import com.openexchange.folderstorage.messaging.contentType.DraftsContentType;
 import com.openexchange.folderstorage.messaging.contentType.MessagingContentType;
 import com.openexchange.folderstorage.messaging.contentType.SentContentType;
@@ -92,9 +92,6 @@ import com.openexchange.mail.MailSessionParameterNames;
 import com.openexchange.mail.messaging.MailMessagingService;
 import com.openexchange.mail.utils.StorageUtility;
 import com.openexchange.mailaccount.MailAccount;
-import com.openexchange.mailaccount.MailAccountException;
-import com.openexchange.mailaccount.MailAccountStorageService;
-import com.openexchange.mailaccount.UnifiedINBOXManagement;
 import com.openexchange.messaging.DefaultMessagingFolder;
 import com.openexchange.messaging.DefaultMessagingPermission;
 import com.openexchange.messaging.MessagingAccount;
@@ -195,6 +192,18 @@ public final class MessagingFolderStorage implements FolderStorage {
         super();
     }
 
+    public void restore(String treeId, String folderId, StorageParameters storageParameters) throws FolderException {
+        // TODO:
+    }
+
+    public void checkConsistency(String treeId, StorageParameters storageParameters) throws FolderException {
+        // Nothing to do
+    }
+
+    public SortableId[] getVisibleFolders(String treeId, ContentType contentType, Type type, StorageParameters storageParameters) throws FolderException {
+        throw new UnsupportedOperationException("VirtualFolderStorage.getVisibleSubfolders()");
+    }
+
     private MessagingAccountAccess getMessagingAccessForAccount(final String serviceId, final int accountId, final Session session, final ConcurrentMap<Key, MessagingAccountAccess> accesses) throws FolderException {
         final Key key = Key.newInstance(accountId, serviceId);
         MessagingAccountAccess accountAccess = accesses.get(key);
@@ -525,25 +534,17 @@ public final class MessagingFolderStorage implements FolderStorage {
                 final MessagingFolder rootFolder = accountAccess.getFolderAccess().getRootFolder();
                 retval = new MessagingFolderImpl(rootFolder, accountId, serviceId, null);
                 /*
-                 * Set proper name for non-primary account
+                 * Set proper name
                  */
-                if (MailAccount.DEFAULT_ID != accountId) {
-                    /*
-                     * Set proper name
-                     */
-                    try {
-                        final MailAccountStorageService storageService =
-                            MailServiceRegistry.getServiceRegistry().getService(MailAccountStorageService.class, true);
-                        final MailAccount mailAccount =
-                            storageService.getMailAccount(accountId, storageParameters.getUserId(), storageParameters.getContextId());
-                        if (!UnifiedINBOXManagement.PROTOCOL_UNIFIED_INBOX.equals(mailAccount.getMailProtocol())) {
-                            retval.setName(mailAccount.getName());
-                        }
-                    } catch (final ServiceException e) {
-                        throw new FolderException(e);
-                    } catch (final MailAccountException e) {
-                        throw new FolderException(e);
-                    }
+                try {
+                    final MessagingServiceRegistry msr =
+                        MessagingFolderStorageServiceRegistry.getServiceRegistry().getService(MessagingServiceRegistry.class, true);
+                    final MessagingService messagingService = msr.getMessagingService(serviceId);
+                    final MessagingAccount messagingAccount =
+                        messagingService.getAccountManager().getAccount(accountId, storageParameters.getSession());
+                    retval.setName(messagingAccount.getDisplayName());
+                } catch (final ServiceException e) {
+                    throw new FolderException(e);
                 }
                 hasSubfolders = rootFolder.hasSubfolders();
             } else {
@@ -693,13 +694,19 @@ public final class MessagingFolderStorage implements FolderStorage {
                 if (accounts.isEmpty()) {
                     return new SortableId[0];
                 }
+                final int size = accounts.size();
+                if (size > 1) {
+                    /*
+                     * Sort by name
+                     */
+                    Collections.sort(accounts, new MessagingAccountComparator(session.getUser().getLocale()));
+                }
                 /*-
                  * TODO:
                  * 1. Check for messaging permission; e.g. session.getUserConfiguration().isMultipleMailAccounts()
                  *    Add primary only if not enabled
                  * 2. Strip Unified-Messaging account from obtained list
                  */
-                final int size = accounts.size();
                 final List<SortableId> list = new ArrayList<SortableId>(size);
                 for (int j = 0; j < size; j++) {
                     final MessagingAccount acc = accounts.get(j);
@@ -1131,8 +1138,6 @@ public final class MessagingFolderStorage implements FolderStorage {
             } else if (UnifiedINBOXManagement.PROTOCOL_UNIFIED_INBOX.equals(o2.getMailProtocol())) {
                 return 1;
             }
-             * 
-             */
             if (0 == o1.getId()) {
                 if (0 == o2.getId()) {
                     return 0;
@@ -1141,6 +1146,7 @@ public final class MessagingFolderStorage implements FolderStorage {
             } else if (0 == o2.getId()) {
                 return 1;
             }
+            */
             return collator.compare(o1.getDisplayName(), o2.getDisplayName());
         }
 
