@@ -86,6 +86,8 @@ public final class OutlookFolder implements Folder {
 
     private Boolean subscribed;
 
+    private Boolean subscribedSubfolders;
+
     private String newId;
 
     /**
@@ -181,8 +183,11 @@ public final class OutlookFolder implements Folder {
     }
 
     public String getLocalizedName(final Locale locale) {
+        if (null == name) {
+            return realFolder.getLocalizedName(locale);
+        }
         if (null == localizedName) {
-            localizedName = new StringHelper(locale).getString(getName());
+            localizedName = new StringHelper(locale).getString(name);
         }
         return localizedName;
     }
@@ -264,6 +269,21 @@ public final class OutlookFolder implements Folder {
         this.subscribed = Boolean.valueOf(subscribed);
     }
 
+    public boolean hasSubscribedSubfolders() {
+        return null == subscribedSubfolders ? realFolder.hasSubscribedSubfolders() : subscribedSubfolders.booleanValue();
+        /*-
+         * 
+        if (null == subscribedSubfolders) {
+            return null == subfolders || subfolders.length > 0;
+        }
+        return subscribedSubfolders.booleanValue();
+        */
+    }
+    
+    public void setSubscribedSubfolders(final boolean subscribedSubfolders) {
+        this.subscribedSubfolders = Boolean.valueOf(subscribedSubfolders);
+    }
+
     public boolean isVirtual() {
         return true;
     }
