@@ -82,23 +82,34 @@ import com.openexchange.folderstorage.database.DatabaseFolderType;
 import com.openexchange.folderstorage.database.DatabaseParameterConstants;
 import com.openexchange.folderstorage.internal.StorageParametersImpl;
 import com.openexchange.folderstorage.internal.Tools;
+import com.openexchange.folderstorage.mail.MailFolderType;
 import com.openexchange.folderstorage.mail.contentType.DraftsContentType;
+import com.openexchange.folderstorage.mail.contentType.MailContentType;
 import com.openexchange.folderstorage.mail.contentType.SentContentType;
 import com.openexchange.folderstorage.mail.contentType.SpamContentType;
 import com.openexchange.folderstorage.mail.contentType.TrashContentType;
+import com.openexchange.folderstorage.messaging.MessagingFolderIdentifier;
 import com.openexchange.folderstorage.outlook.sql.Delete;
 import com.openexchange.folderstorage.outlook.sql.Insert;
 import com.openexchange.folderstorage.outlook.sql.Select;
 import com.openexchange.folderstorage.outlook.sql.Update;
 import com.openexchange.folderstorage.outlook.sql.Utility;
 import com.openexchange.groupware.ldap.User;
+import com.openexchange.mail.FullnameArgument;
 import com.openexchange.mail.MailException;
 import com.openexchange.mail.dataobjects.MailFolder;
+import com.openexchange.mail.messaging.MailMessagingService;
+import com.openexchange.mail.mime.MIMEMailException;
 import com.openexchange.mail.utils.MailFolderUtility;
 import com.openexchange.mailaccount.MailAccount;
 import com.openexchange.mailaccount.MailAccountException;
 import com.openexchange.mailaccount.MailAccountStorageService;
 import com.openexchange.mailaccount.UnifiedINBOXManagement;
+import com.openexchange.messaging.MessagingAccount;
+import com.openexchange.messaging.MessagingException;
+import com.openexchange.messaging.MessagingFolder;
+import com.openexchange.messaging.MessagingService;
+import com.openexchange.messaging.registry.MessagingServiceRegistry;
 import com.openexchange.server.ServiceException;
 import com.openexchange.session.Session;
 import com.openexchange.threadpool.ThreadPoolCompletionService;
@@ -124,6 +135,11 @@ public final class OutlookFolderStorage implements FolderStorage {
      */
     static final String PREPARED_FULLNAME_INBOX = MailFolderUtility.prepareFullname(MailAccount.DEFAULT_ID, "INBOX");
 
+    /**
+     * The prepared fullname.
+     */
+    static final String PREPARED_FULLNAME_DEFAULT = MailFolderUtility.prepareFullname(MailAccount.DEFAULT_ID, MailFolder.DEFAULT_FOLDER_ID);
+
     private static final ThreadPools.ExpectedExceptionFactory<FolderException> FACTORY =
         new ThreadPools.ExpectedExceptionFactory<FolderException>() {
 
@@ -176,6 +192,37 @@ public final class OutlookFolderStorage implements FolderStorage {
         folderStorageRegistry = OutlookFolderStorageRegistry.getInstance();
     }
 
+    public void checkConsistency(final String treeId, final StorageParameters storageParameters) throws FolderException {
+        final List<String> folderIds =
+            Select.getFolders(storageParameters.getContextId(), Tools.getUnsignedInteger(treeId), storageParameters.getUserId());
+        for (final String folderId : folderIds) {
+            final FolderStorage folderStorage = folderStorageRegistry.getFolderStorage(realTreeId, folderId);
+            final boolean started = folderStorage.startTransaction(storageParameters, true);
+            try {
+                if (!folderStorage.containsFolder(realTreeId, folderId, storageParameters)) {
+                    folderStorage.restore(realTreeId, folderId, storageParameters);
+                }
+                if (started) {
+                    folderStorage.commitTransaction(storageParameters);
+                }
+            } catch (final FolderException e) {
+                if (started) {
+                    folderStorage.rollback(storageParameters);
+                }
+                LOG.warn("Checking consistency failed for tree " + treeId, e);
+            } catch (final Exception e) {
+                if (started) {
+                    folderStorage.rollback(storageParameters);
+                }
+                LOG.warn("Checking consistency failed for tree " + treeId, e);
+            }
+        }
+    }
+
+    public void restore(final String treeId, final String folderId, final StorageParameters storageParameters) throws FolderException {
+        // Nothing to restore, not a real storage
+    }
+
     public void clearFolder(final String treeId, final String folderId, final StorageParameters storageParameters) throws FolderException {
         /*
          * Delegate clear invocation to real storage
@@ -203,7 +250,7 @@ public final class OutlookFolderStorage implements FolderStorage {
         }
     }
 
-    public void commitTransaction(final StorageParameters params) throws FolderException {
+    public void commitTransaction(final StorageParameters params) {
         // Nothing to do
     }
 
@@ -212,6 +259,15 @@ public final class OutlookFolderStorage implements FolderStorage {
     }
 
     public boolean containsFolder(final String treeId, final String folderId, final StorageType storageType, final StorageParameters storageParameters) throws FolderException {
+        /*
+         * No primary mail account root folder in this tree
+         */
+        if (MailFolderUtility.prepareFullname(MailAccount.DEFAULT_ID, MailFolder.DEFAULT_FOLDER_ID).equals(folderId)) {
+            return false;
+        }
+        /*
+         * Check
+         */
         final FolderStorage dedicatedFolderStorage = folderStorageRegistry.getDedicatedFolderStorage(FolderStorage.REAL_TREE_ID, folderId);
         if (!dedicatedFolderStorage.containsFolder(FolderStorage.REAL_TREE_ID, folderId, storageType, storageParameters)) {
             return false;
@@ -332,7 +388,7 @@ public final class OutlookFolderStorage implements FolderStorage {
         }
     }
 
-    public String[] getDeletedFolderIDs(final String treeId, final Date timeStamp, final StorageParameters storageParameters) throws FolderException {
+    public String[] getDeletedFolderIDs(final String treeId, final Date timeStamp, final StorageParameters storageParameters) {
         return new String[0];
     }
 
@@ -374,7 +430,7 @@ public final class OutlookFolderStorage implements FolderStorage {
         }
         final boolean started = folderStorage.startTransaction(storageParameters, false);
         try {
-            final boolean isEmpty = folderStorage.isEmpty(treeId, folderId, storageParameters);
+            final boolean isEmpty = folderStorage.isEmpty(realTreeId, folderId, storageParameters);
             if (started) {
                 folderStorage.commitTransaction(storageParameters);
             }
@@ -443,6 +499,12 @@ public final class OutlookFolderStorage implements FolderStorage {
     }
 
     public Folder getFolder(final String treeId, final String folderId, final StorageType storageType, final StorageParameters storageParameters) throws FolderException {
+        /*
+         * Primary account's root folder does not exist in tis folder tree
+         */
+        if (MailFolderUtility.prepareFullname(MailAccount.DEFAULT_ID, MailFolder.DEFAULT_FOLDER_ID).equals(folderId)) {
+            throw FolderExceptionErrorMessage.NOT_FOUND.create(folderId, treeId);
+        }
         /*
          * Check for root folder
          */
@@ -578,37 +640,91 @@ public final class OutlookFolderStorage implements FolderStorage {
              * Set subfolders if empty
              */
             final String[] realSubfolderIDs = realFolder.getSubfolderIDs();
-            if (null != realSubfolderIDs && realSubfolderIDs.length == 0) {
+            if (null == realSubfolderIDs) {
                 /*
-                 * Folder indicates to hold no subfolders; verify against virtual tree
+                 * Subfolders available; set to null to indicate this condition since AbstractUserizedFolderPerformer#getUserizedFolder()
+                 * interprets null as if subfolders are present.
                  */
-                final boolean contains;
-                {
-                    final Connection con = checkReadConnection(storageParameters);
-                    if (null == con) {
-                        contains = Select.containsParent(contextId, tree, user.getId(), folderId, StorageType.WORKING);
+                outlookFolder.setSubfolderIDs(null);
+            } else {
+                if (0 == realSubfolderIDs.length) {
+                    /*
+                     * Folder indicates to hold no subfolders; verify against virtual tree
+                     */
+                    final boolean contains;
+                    {
+                        final Connection con = checkReadConnection(storageParameters);
+                        if (null == con) {
+                            contains = Select.containsParent(contextId, tree, user.getId(), folderId, StorageType.WORKING);
+                        } else {
+                            contains = Select.containsParent(contextId, tree, user.getId(), folderId, StorageType.WORKING, con);
+                        }
+                    }
+                    if (contains) {
+                        outlookFolder.setSubfolderIDs(null);
+                        outlookFolder.setSubscribedSubfolders(true);
                     } else {
-                        contains = Select.containsParent(contextId, tree, user.getId(), folderId, StorageType.WORKING, con);
+                        outlookFolder.setSubfolderIDs(realSubfolderIDs); // Zero-length array => No subfolders
+                    }
+                } else {
+                    if (realFolder.isDefault()) {
+                        /*
+                         * Remove the ones kept in virtual table
+                         */
+                        final boolean[] contained;
+                        {
+                            final Connection con = checkReadConnection(storageParameters);
+                            if (null == con) {
+                                contained =
+                                    Select.containsFolders(contextId, tree, storageParameters.getUserId(), realSubfolderIDs, StorageType.WORKING);
+                            } else {
+                                contained =
+                                    Select.containsFolders(contextId, tree, storageParameters.getUserId(), realSubfolderIDs, StorageType.WORKING, con);
+                            }
+                        }
+                        boolean found = false;
+                        for (int i = 0; !found && i < realSubfolderIDs.length; i++) {
+                            if (!contained[i]) {
+                                found = true;
+                            }
+                        }
+                        if (found) {
+                            outlookFolder.setSubfolderIDs(null);
+                            outlookFolder.setSubscribedSubfolders(true);
+                        } else {
+                            outlookFolder.setSubfolderIDs(new String[0]);
+                            outlookFolder.setSubscribedSubfolders(false);
+                        }
                     }
                 }
-                if (contains) {
-                    outlookFolder.setSubfolderIDs(null);
-                } else {
-                    outlookFolder.setSubfolderIDs(realSubfolderIDs); // Zero-length array => No subfolders
-                }
-            } else {
-                outlookFolder.setSubfolderIDs(null);
             }
         }
         /*
          * Load folder data from database
          */
+        final boolean presentInTable;
         {
             final Connection con = checkReadConnection(storageParameters);
             if (null == con) {
-                Select.fillFolder(contextId, tree, user.getId(), user.getLocale(), outlookFolder, storageType);
+                presentInTable = Select.fillFolder(contextId, tree, user.getId(), user.getLocale(), outlookFolder, storageType);
             } else {
-                Select.fillFolder(contextId, tree, user.getId(), user.getLocale(), outlookFolder, storageType, con);
+                presentInTable = Select.fillFolder(contextId, tree, user.getId(), user.getLocale(), outlookFolder, storageType, con);
+            }
+        }
+        //
+        if (!presentInTable) {
+            doModifications(outlookFolder);
+            if (PREPARED_FULLNAME_INBOX.equals(folderId)) {
+                /*
+                 * Special treatment for INBOX
+                 */
+                final SortableId[] inboxSubfolders =
+                    getINBOXSubfolders(treeId, folderId, storageParameters, user, user.getLocale(), contextId, tree);
+                final String[] subs = new String[inboxSubfolders.length];
+                for (int i = 0; i < subs.length; i++) {
+                    subs[i] = inboxSubfolders[i].getId();
+                }
+                outlookFolder.setSubfolderIDs(subs);
             }
         }
         return outlookFolder;
@@ -619,9 +735,100 @@ public final class OutlookFolderStorage implements FolderStorage {
     }
 
     public String[] getModifiedFolderIDs(final String treeId, final Date timeStamp, final ContentType[] includeContentTypes, final StorageParameters storageParameters) throws FolderException {
+        if (null == includeContentTypes || includeContentTypes.length == 0) {
+            return new String[0];
+        }
+        boolean containsMail = false;
+        for (final ContentType contentType : includeContentTypes) {
+            if (MailContentType.getInstance().equals(contentType)) {
+                containsMail = true;
+                break;
+            }
+        }
+        if (containsMail) {
+            final User user = storageParameters.getUser();
+            final Locale locale = user.getLocale();
+            final int contextId = storageParameters.getContextId();
+            final int tree = Tools.getUnsignedInteger(treeId);
+            final FolderNameComparator comparator = new FolderNameComparator(locale);
+            final List<TreeMap<String, List<String>>> maps = new ArrayList<TreeMap<String, List<String>>>(2);
+            /*
+             * From primary mail folder
+             */
+            maps.add(new MailFolderCallable(comparator, locale, user, contextId, tree, storageParameters).call());
+            /*
+             * Callable for the ones from virtual table
+             */
+            maps.add(new Callable<TreeMap<String, List<String>>>() {
+
+                public TreeMap<String, List<String>> call() throws FolderException {
+                    /*
+                     * Get the ones from virtual table
+                     */
+                    final List<String[]> l;
+                    {
+                        final Connection con = checkReadConnection(storageParameters);
+                        if (null == con) {
+                            l = Select.getSubfolderIds(contextId, tree, user.getId(), FolderStorage.PRIVATE_ID, StorageType.WORKING);
+                        } else {
+                            l = Select.getSubfolderIds(contextId, tree, user.getId(), FolderStorage.PRIVATE_ID, StorageType.WORKING, con);
+                        }
+                    }
+                    /*
+                     * Filter only mail folders
+                     */
+                    final TreeMap<String, List<String>> treeMap = new TreeMap<String, List<String>>(comparator);
+                    for (final String[] idAndName : l) {
+                        final String id = idAndName[0];
+                        if (MailFolderType.getInstance().servesFolderId(id)) {
+                            put2TreeMap(idAndName[1], id, treeMap);
+                        }
+                    }
+                    return treeMap;
+                }
+            }.call());
+            /*
+             * Merge
+             */
+            final TreeMap<String, List<String>> treeMap = new TreeMap<String, List<String>>(comparator);
+            for (final TreeMap<String, List<String>> tm : maps) {
+                for (final Entry<String, List<String>> entry : tm.entrySet()) {
+                    final String key = entry.getKey();
+                    final List<String> list = treeMap.get(key);
+                    if (null == list) {
+                        treeMap.put(key, entry.getValue());
+                    } else {
+                        list.addAll(entry.getValue());
+                    }
+                }
+            }
+            /*
+             * Return
+             */
+            final Collection<List<String>> values = treeMap.values();
+            final List<String> ret = new ArrayList<String>(values.size());
+            for (final List<String> list : values) {
+                for (final String id : list) {
+                    ret.add(id);
+                }
+            }
+            return ret.toArray(new String[ret.size()]);
+        }
+        /*
+         * Empty array
+         */
         return new String[0];
     }
 
+    protected static boolean supportsMail(final ContentType[] types) {
+        for (final ContentType contentType : types) {
+            if (MailContentType.getInstance().equals(contentType)) {
+                return true;
+            }
+        }
+        return false;
+    }
+
     public StoragePriority getStoragePriority() {
         return StoragePriority.NORMAL;
     }
@@ -650,7 +857,7 @@ public final class OutlookFolderStorage implements FolderStorage {
             return getPrivateFolderSubfolders(parentId, tree, storageParameters, user, locale, contextId);
         }
         /*
-         * Other folder than root or private
+         * Other folder than root, INBOX or private
          */
         final List<String[]> l;
         {
@@ -759,6 +966,9 @@ public final class OutlookFolderStorage implements FolderStorage {
                 defIds.add(folderStorage.getDefaultFolderID(user, treeId, SpamContentType.getInstance(), storageParameters));
             }
             final SortableId[] inboxSubfolders = folderStorage.getSubfolders(realTreeId, PREPARED_FULLNAME_INBOX, storageParameters);
+            /*
+             * Filter those mail folders which denote a virtual one
+             */
             final boolean[] contained;
             {
                 final Connection con = checkReadConnection(storageParameters);
@@ -779,6 +989,27 @@ public final class OutlookFolderStorage implements FolderStorage {
                     }
                 }
             }
+            /*
+             * Get virtual subfolders
+             */
+            final List<String[]> ids;
+            {
+                final Connection con = checkReadConnection(storageParameters);
+                if (null == con) {
+                    ids = Select.getSubfolderIds(contextId, tree, user.getId(), parentId, StorageType.WORKING);
+                } else {
+                    ids = Select.getSubfolderIds(contextId, tree, user.getId(), parentId, StorageType.WORKING, con);
+                }
+            }
+            /*
+             * Merge them into tree map
+             */
+            for (final String[] idAndName : ids) {
+                /*
+                 * Names loaded from DB have no locale-sensitive string
+                 */
+                put2TreeMap(idAndName[1], idAndName[0], treeMap);
+            }
             if (started) {
                 folderStorage.commitTransaction(storageParameters);
             }
@@ -925,103 +1156,7 @@ public final class OutlookFolderStorage implements FolderStorage {
         /*
          * Callable for primary mail folder
          */
-        completionService.submit(new Callable<TreeMap<String, List<String>>>() {
-
-            public TreeMap<String, List<String>> call() throws FolderException {
-                /*
-                 * Get real folder storage for primary mail folder
-                 */
-                final String fullname = MailFolderUtility.prepareFullname(MailAccount.DEFAULT_ID, MailFolder.DEFAULT_FOLDER_ID);
-                final FolderStorage folderStorage = folderStorageRegistry.getFolderStorage(realTreeId, fullname);
-                if (null == folderStorage) {
-                    throw FolderExceptionErrorMessage.NO_STORAGE_FOR_ID.create(realTreeId, fullname);
-                }
-                final StorageParameters storageParameters = newStorageParameters(parameters);
-                final boolean started = folderStorage.startTransaction(storageParameters, false);
-                try {
-                    /*
-                     * Get IDs
-                     */
-                    final SortableId[] mailIDs;
-                    try {
-                        mailIDs = folderStorage.getSubfolders(realTreeId, fullname, storageParameters);
-                    } catch (final FolderException e) {
-                        final Throwable cause = e.getCause();
-                        if (cause instanceof MailException) {
-                            final MailException me = (MailException) cause;
-                            if (MailException.Code.ACCOUNT_DOES_NOT_EXIST.getNumber() == me.getDetailNumber()) {
-                                if (LOG.isDebugEnabled()) {
-                                    LOG.debug(e.getMessage(), e);
-                                }
-                                /*
-                                 * Return empty map
-                                 */
-                                return new TreeMap<String, List<String>>(comparator);
-                            }
-                        }
-                        throw e;
-                    }
-                    final TreeMap<String, List<String>> treeMap = new TreeMap<String, List<String>>(comparator);
-                    for (final SortableId sortableId : mailIDs) {
-                        final String id = sortableId.getId();
-                        put2TreeMap(getLocalizedName(id, tree, locale, folderStorage, storageParameters), id, treeMap);
-                    }
-                    /*
-                     * Add default folders: Trash, Sent, Drafts, ...
-                     */
-                    final Set<String> defIds;
-                    {
-                        defIds = new HashSet<String>(6);
-                        final String treeId = String.valueOf(tree);
-                        defIds.add(folderStorage.getDefaultFolderID(user, treeId, TrashContentType.getInstance(), storageParameters));
-                        defIds.add(folderStorage.getDefaultFolderID(user, treeId, DraftsContentType.getInstance(), storageParameters));
-                        defIds.add(folderStorage.getDefaultFolderID(user, treeId, SentContentType.getInstance(), storageParameters));
-                        defIds.add(folderStorage.getDefaultFolderID(user, treeId, SpamContentType.getInstance(), storageParameters));
-                    }
-                    final SortableId[] inboxSubfolders =
-                        folderStorage.getSubfolders(realTreeId, PREPARED_FULLNAME_INBOX, storageParameters);
-                    final boolean[] contained;
-                    {
-                        final Connection con = checkReadConnection(storageParameters);
-                        if (null == con) {
-                            contained =
-                                Select.containsFolders(contextId, tree, storageParameters.getUserId(), inboxSubfolders, StorageType.WORKING);
-                        } else {
-                            contained =
-                                Select.containsFolders(
-                                    contextId,
-                                    tree,
-                                    storageParameters.getUserId(),
-                                    inboxSubfolders,
-                                    StorageType.WORKING,
-                                    con);
-                        }
-                    }
-                    for (int i = 0; i < inboxSubfolders.length; i++) {
-                        if (!contained[i]) {
-                            final String id = inboxSubfolders[i].getId();
-                            if (defIds.contains(id)) {
-                                put2TreeMap(getLocalizedName(id, tree, locale, folderStorage, storageParameters), id, treeMap);
-                            }
-                        }
-                    }
-                    if (started) {
-                        folderStorage.commitTransaction(storageParameters);
-                    }
-                    return treeMap;
-                } catch (final FolderException e) {
-                    if (started) {
-                        folderStorage.rollback(storageParameters);
-                    }
-                    throw e;
-                } catch (final Exception e) {
-                    if (started) {
-                        folderStorage.rollback(storageParameters);
-                    }
-                    throw FolderExceptionErrorMessage.UNEXPECTED_ERROR.create(e, e.getMessage());
-                }
-            }
-        });
+        completionService.submit(new MailFolderCallable(comparator, locale, user, contextId, tree, parameters));
         taskCount++;
         /*
          * Callable for the ones from virtual table
@@ -1136,10 +1271,71 @@ public final class OutlookFolderStorage implements FolderStorage {
                     accountSubfolderIDs = new ArrayList<String>(accounts.size());
                     for (final MailAccount mailAccount : accounts) {
                         if (!mailAccount.isDefaultAccount()) {
-                            accountSubfolderIDs.add(MailFolderUtility.prepareFullname(mailAccount.getId(), MailFolder.DEFAULT_FOLDER_ID));
+                            if (UnifiedINBOXManagement.PROTOCOL_UNIFIED_INBOX.equals(mailAccount.getMailProtocol())) {
+                                /*
+                                 * Ensure Unified INBOX is enabled; meaning at least one account is subscribed to Unified INBOX
+                                 */
+                                final UnifiedINBOXManagement uim =
+                                    OutlookServiceRegistry.getServiceRegistry().getService(UnifiedINBOXManagement.class);
+                                try {
+                                    if (null != uim && uim.isEnabled(user.getId(), contextId)) {
+                                        accountSubfolderIDs.add(MailFolderUtility.prepareFullname(
+                                            mailAccount.getId(),
+                                            MailFolder.DEFAULT_FOLDER_ID));
+                                    }
+                                } catch (final MailAccountException e) {
+                                    LOG.error(e.getMessage(), e);
+                                }
+                            } else {
+                                accountSubfolderIDs.add(MailFolderUtility.prepareFullname(mailAccount.getId(), MailFolder.DEFAULT_FOLDER_ID));
+                            }
                         }
                     }
-                    // TODO: No Unified INBOX if not enabled
+                }
+            }
+        }
+        /*
+         * Obtain external messaging accounts with running thread
+         */
+        final List<String> messagingSubfolderIDs;
+        {
+            /*
+             * Messaging accounts; except mail
+             */
+            final List<MessagingAccount> messagingAccounts = new ArrayList<MessagingAccount>();
+            {
+                final MessagingServiceRegistry msr = OutlookServiceRegistry.getServiceRegistry().getService(MessagingServiceRegistry.class);
+                if (null != msr) {
+                    try {
+                        final List<MessagingService> allServices = msr.getAllServices();
+                        for (final MessagingService messagingService : allServices) {
+                            if (!messagingService.getId().equals(MailMessagingService.ID)) {
+                                /*
+                                 * Only non-mail services
+                                 */
+                                try {
+                                    messagingAccounts.addAll(messagingService.getAccountManager().getAccounts(parameters.getSession()));
+                                } catch (final MessagingException e) {
+                                    LOG.error(e.getMessage(), e);
+                                }
+                            }
+                        }
+                    } catch (final MessagingException e) {
+                        LOG.error(e.getMessage(), e);
+                    }
+                }
+                if (!messagingAccounts.isEmpty()) {
+                    Collections.sort(messagingAccounts, new MessagingAccountComparator(locale));
+                    final int sz = messagingAccounts.size();
+                    messagingSubfolderIDs = new ArrayList<String>(sz);
+                    for (int i = 0; i < sz; i++) {
+                        final MessagingAccount ma = messagingAccounts.get(i);
+                        final MessagingFolderIdentifier mfi =
+                            new MessagingFolderIdentifier(ma.getMessagingService().getId(), ma.getId(), MessagingFolder.ROOT_FULLNAME);
+                        messagingSubfolderIDs.add(mfi.toString());
+                    }
+                } else {
+                    messagingSubfolderIDs = Collections.emptyList();
                 }
             }
         }
@@ -1176,6 +1372,10 @@ public final class OutlookFolderStorage implements FolderStorage {
          * Add external mail accounts
          */
         sortedIDs.addAll(accountSubfolderIDs);
+        /*
+         * Add external messaging accounts
+         */
+        sortedIDs.addAll(messagingSubfolderIDs);
         final int size = sortedIDs.size();
         final SortableId[] ret = new SortableId[size];
         for (int i = 0; i < size; i++) {
@@ -1212,7 +1412,7 @@ public final class OutlookFolderStorage implements FolderStorage {
         // Nothing to do
     }
 
-    public boolean startTransaction(final StorageParameters parameters, final boolean modify) throws FolderException {
+    public boolean startTransaction(final StorageParameters parameters, final boolean modify) {
         return false;
     }
 
@@ -1301,6 +1501,133 @@ public final class OutlookFolderStorage implements FolderStorage {
         }
     }
 
+    private final class MailFolderCallable implements Callable<TreeMap<String, List<String>>> {
+
+        private final FolderNameComparator comparator;
+
+        private final Locale locale;
+
+        private final User user;
+
+        private final int contextId;
+
+        private final int tree;
+
+        private final StorageParameters parameters;
+
+        public MailFolderCallable(final FolderNameComparator comparator, final Locale locale, final User user, final int contextId, final int tree, final StorageParameters parameters) {
+            this.comparator = comparator;
+            this.locale = locale;
+            this.user = user;
+            this.contextId = contextId;
+            this.tree = tree;
+            this.parameters = parameters;
+        }
+
+        public TreeMap<String, List<String>> call() throws FolderException {
+            /*
+             * Get real folder storage for primary mail folder
+             */
+            final String fullname = MailFolderUtility.prepareFullname(MailAccount.DEFAULT_ID, MailFolder.DEFAULT_FOLDER_ID);
+            final FolderStorage folderStorage = folderStorageRegistry.getFolderStorage(realTreeId, fullname);
+            if (null == folderStorage) {
+                throw FolderExceptionErrorMessage.NO_STORAGE_FOR_ID.create(realTreeId, fullname);
+            }
+            final StorageParameters storageParameters = newStorageParameters(parameters);
+            final boolean started = folderStorage.startTransaction(storageParameters, false);
+            try {
+                /*
+                 * Get IDs
+                 */
+                final SortableId[] mailIDs;
+                try {
+                    mailIDs = folderStorage.getSubfolders(realTreeId, fullname, storageParameters);
+                } catch (final FolderException e) {
+                    final Throwable cause = e.getCause();
+                    if (cause instanceof MailException) {
+                        final MailException me = (MailException) cause;
+                        final int number = me.getDetailNumber();
+                        if (MailException.Code.ACCOUNT_DOES_NOT_EXIST.getNumber() == number) {
+                            if (LOG.isDebugEnabled()) {
+                                LOG.debug(e.getMessage(), e);
+                            }
+                            /*
+                             * Return empty map
+                             */
+                            return new TreeMap<String, List<String>>(comparator);
+                        } else if (MIMEMailException.Code.INVALID_CREDENTIALS.getNumber() == number) {
+                            if (LOG.isDebugEnabled()) {
+                                LOG.debug(e.getMessage(), e);
+                            }
+                            /*
+                             * Return empty map
+                             */
+                            return new TreeMap<String, List<String>>(comparator);
+                        }
+                    }
+                    throw e;
+                }
+                final TreeMap<String, List<String>> treeMap = new TreeMap<String, List<String>>(comparator);
+                for (final SortableId sortableId : mailIDs) {
+                    final String id = sortableId.getId();
+                    put2TreeMap(getLocalizedName(id, tree, locale, folderStorage, storageParameters), id, treeMap);
+                }
+                /*
+                 * Add default folders: Trash, Sent, Drafts, ...
+                 */
+                final Set<String> defIds;
+                {
+                    defIds = new HashSet<String>(6);
+                    final String treeId = String.valueOf(tree);
+                    defIds.add(folderStorage.getDefaultFolderID(user, treeId, TrashContentType.getInstance(), storageParameters));
+                    defIds.add(folderStorage.getDefaultFolderID(user, treeId, DraftsContentType.getInstance(), storageParameters));
+                    defIds.add(folderStorage.getDefaultFolderID(user, treeId, SentContentType.getInstance(), storageParameters));
+                    defIds.add(folderStorage.getDefaultFolderID(user, treeId, SpamContentType.getInstance(), storageParameters));
+                }
+                final SortableId[] inboxSubfolders = folderStorage.getSubfolders(realTreeId, PREPARED_FULLNAME_INBOX, storageParameters);
+                final boolean[] contained;
+                {
+                    final Connection con = checkReadConnection(storageParameters);
+                    if (null == con) {
+                        contained =
+                            Select.containsFolders(contextId, tree, storageParameters.getUserId(), inboxSubfolders, StorageType.WORKING);
+                    } else {
+                        contained =
+                            Select.containsFolders(
+                                contextId,
+                                tree,
+                                storageParameters.getUserId(),
+                                inboxSubfolders,
+                                StorageType.WORKING,
+                                con);
+                    }
+                }
+                for (int i = 0; i < inboxSubfolders.length; i++) {
+                    if (!contained[i]) {
+                        final String id = inboxSubfolders[i].getId();
+                        if (defIds.contains(id)) {
+                            put2TreeMap(getLocalizedName(id, tree, locale, folderStorage, storageParameters), id, treeMap);
+                        }
+                    }
+                }
+                if (started) {
+                    folderStorage.commitTransaction(storageParameters);
+                }
+                return treeMap;
+            } catch (final FolderException e) {
+                if (started) {
+                    folderStorage.rollback(storageParameters);
+                }
+                throw e;
+            } catch (final Exception e) {
+                if (started) {
+                    folderStorage.rollback(storageParameters);
+                }
+                throw FolderExceptionErrorMessage.UNEXPECTED_ERROR.create(e, e.getMessage());
+            }
+        }
+    }
+
     private static final class MailAccountComparator implements Comparator<MailAccount> {
 
         private final Collator collator;
@@ -1333,6 +1660,22 @@ public final class OutlookFolderStorage implements FolderStorage {
 
     } // End of MailAccountComparator
 
+    private static final class MessagingAccountComparator implements Comparator<MessagingAccount> {
+
+        private final Collator collator;
+
+        public MessagingAccountComparator(final Locale locale) {
+            super();
+            collator = Collator.getInstance(locale);
+            collator.setStrength(Collator.SECONDARY);
+        }
+
+        public int compare(final MessagingAccount o1, final MessagingAccount o2) {
+            return collator.compare(o1.getDisplayName(), o2.getDisplayName());
+        }
+
+    } // End of MessagingAccountComparator
+
     private static final class FolderNameComparator implements Comparator<String> {
 
         private final Collator collator;
@@ -1407,4 +1750,40 @@ public final class OutlookFolderStorage implements FolderStorage {
         return null;
     }
 
+    private static void doModifications(final OutlookFolder folder) {
+        final String id = folder.getID();
+        if (FolderStorage.PUBLIC_ID.equals(id)) {
+            folder.setParentID(FolderStorage.PRIVATE_ID);
+        } else if (FolderStorage.SHARED_ID.equals(id)) {
+            folder.setParentID(FolderStorage.PRIVATE_ID);
+        } else if (isDefaultMailFolder(folder)) {
+            folder.setParentID(FolderStorage.PRIVATE_ID);
+        } else if (isNonPrimaryMailAccountFolder(folder)) {
+            folder.setParentID(FolderStorage.PRIVATE_ID);
+        } else if (PREPARED_FULLNAME_DEFAULT.equals(folder.getParentID())) {
+            folder.setParentID(FolderStorage.PRIVATE_ID);
+        }
+    }
+
+    private static final int MODULE_MAIL = MailContentType.getInstance().getModule();
+
+    private static boolean isDefaultMailFolder(final OutlookFolder folder) {
+        return folder.isDefault() && (MODULE_MAIL == folder.getContentType().getModule());
+    }
+
+    private static boolean isNonPrimaryMailAccountFolder(final OutlookFolder folder) {
+        final String id = folder.getID();
+        if (!id.startsWith(MailFolder.DEFAULT_FOLDER_ID)) {
+            return false;
+        }
+        try {
+            final FullnameArgument arg = MailFolderUtility.prepareMailFolderParam(id);
+            return MailFolder.DEFAULT_FOLDER_ID.equals(arg.getFullname()) && arg.getAccountId() != MailAccount.DEFAULT_ID;
+        } catch (final RuntimeException e) {
+            /*
+             * Parsing failed
+             */
+            return false;
+        }
+    }
 }
