@@ -61,6 +61,8 @@ import com.openexchange.database.DatabaseService;
 import com.openexchange.folderstorage.FolderStorage;
 import com.openexchange.folderstorage.outlook.OutlookFolderStorage;
 import com.openexchange.mailaccount.MailAccountStorageService;
+import com.openexchange.mailaccount.UnifiedINBOXManagement;
+import com.openexchange.messaging.registry.MessagingServiceRegistry;
 import com.openexchange.server.osgiservice.DeferredActivator;
 import com.openexchange.server.osgiservice.ServiceRegistry;
 import com.openexchange.threadpool.ThreadPoolService;
@@ -88,7 +90,7 @@ public class OutlookFolderStorageActivator extends DeferredActivator {
 
     @Override
     protected Class<?>[] getNeededServices() {
-        return new Class<?>[] { DatabaseService.class, MailAccountStorageService.class, ThreadPoolService.class };
+        return new Class<?>[] { DatabaseService.class, MailAccountStorageService.class, ThreadPoolService.class, MessagingServiceRegistry.class, UnifiedINBOXManagement.class };
     }
 
     @Override
@@ -133,7 +135,9 @@ public class OutlookFolderStorageActivator extends DeferredActivator {
             }
 
             // Register services
-            serviceRegistrations = new ArrayList<ServiceRegistration>(4);
+            serviceRegistrations = new ArrayList<ServiceRegistration>(2);
+            // DeleteListener was added statically
+            //serviceRegistrations.add(context.registerService(DeleteListener.class.getName(), new OutlookFolderDeleteListener(), null));
 
             final Dictionary<String, String> dictionary = new Hashtable<String, String>();
             dictionary.put("tree", OutlookFolderStorage.OUTLOOK_TREE_ID);
