@@ -61,6 +61,7 @@ import com.openexchange.folderstorage.SortableId;
 import com.openexchange.folderstorage.StorageParameters;
 import com.openexchange.folderstorage.StoragePriority;
 import com.openexchange.folderstorage.StorageType;
+import com.openexchange.folderstorage.Type;
 import com.openexchange.folderstorage.virtual.sql.Delete;
 import com.openexchange.folderstorage.virtual.sql.Insert;
 import com.openexchange.folderstorage.virtual.sql.Select;
@@ -84,6 +85,14 @@ public final class VirtualFolderStorage implements FolderStorage {
         folderType = new VirtualFolderType();
     }
 
+    public void checkConsistency(String treeId, StorageParameters storageParameters) throws FolderException {
+        // TODO: Implement it
+    }
+
+    public void restore(String treeId, String folderId, StorageParameters storageParameters) throws FolderException {
+        // No real storage
+    }
+
     public ContentType getDefaultContentType() {
         return null;
     }
@@ -348,4 +357,8 @@ public final class VirtualFolderStorage implements FolderStorage {
         return new String[0];
     }
 
+    public SortableId[] getVisibleFolders(String treeId, ContentType contentType, Type type, StorageParameters storageParameters) throws FolderException {
+        throw new UnsupportedOperationException("VirtualFolderStorage.getVisibleSubfolders()");
+    }
+
 }
