@@ -28,7 +28,7 @@
  *    http://www.open-xchange.com/EN/developer/. The contributing author shall be
  *    given Attribution for the derivative code and a license granting use.
  *
- *     Copyright (C) 2004-2006 Open-Xchange, Inc.
+ *     Copyright (C) 2004-2010 Open-Xchange, Inc.
  *     Mail: info@open-xchange.com
  *
  *
@@ -60,6 +60,8 @@ import java.util.HashMap;
 import java.util.Iterator;
 import java.util.List;
 import java.util.Map;
+import org.apache.commons.logging.Log;
+import org.apache.commons.logging.LogFactory;
 import com.openexchange.api2.OXException;
 import com.openexchange.database.DBPoolingException;
 import com.openexchange.databaseold.Database;
@@ -67,20 +69,18 @@ import com.openexchange.folderstorage.FolderException;
 import com.openexchange.folderstorage.FolderStorage;
 import com.openexchange.folderstorage.Permission;
 import com.openexchange.folderstorage.virtual.VirtualPermission;
+import com.openexchange.folderstorage.virtual.VirtualTreeCreateTableTask;
 import com.openexchange.folderstorage.virtual.sql.Insert;
 import com.openexchange.groupware.AbstractOXException;
-import com.openexchange.groupware.EnumComponent;
-import com.openexchange.groupware.OXExceptionSource;
-import com.openexchange.groupware.OXThrowsMultiple;
-import com.openexchange.groupware.AbstractOXException.Category;
 import com.openexchange.groupware.container.FolderObject;
 import com.openexchange.groupware.contexts.Context;
+import com.openexchange.groupware.contexts.impl.ContextException;
 import com.openexchange.groupware.contexts.impl.ContextImpl;
+import com.openexchange.groupware.update.PerformParameters;
 import com.openexchange.groupware.update.Schema;
-import com.openexchange.groupware.update.UpdateTask;
-import com.openexchange.groupware.update.exception.Classes;
-import com.openexchange.groupware.update.exception.UpdateException;
-import com.openexchange.groupware.update.exception.UpdateExceptionFactory;
+import com.openexchange.groupware.update.UpdateException;
+import com.openexchange.groupware.update.UpdateExceptionCodes;
+import com.openexchange.groupware.update.UpdateTaskAdapter;
 import com.openexchange.mail.utils.MailFolderUtility;
 import com.openexchange.mailaccount.MailAccount;
 import com.openexchange.server.impl.OCLPermission;
@@ -91,22 +91,19 @@ import com.openexchange.tools.oxfolder.OXFolderAccess;
  * 
  * @author <a href="mailto:thorben.betten@open-xchange.com">Thorben Betten</a>
  */
-@OXExceptionSource(classId = Classes.UPDATE_TASK, component = EnumComponent.UPDATE)
-public class VirtualTreeMigrationTask implements UpdateTask {
+public class VirtualTreeMigrationTask extends UpdateTaskAdapter {
 
-    private static final org.apache.commons.logging.Log LOG = org.apache.commons.logging.LogFactory.getLog(VirtualTreeMigrationTask.class);
+    private static final Log LOG = LogFactory.getLog(VirtualTreeMigrationTask.class);
 
-    private static final UpdateExceptionFactory EXCEPTION = new UpdateExceptionFactory(VirtualTreeMigrationTask.class);
+    private static final String[] DEPENDENCIES = { VirtualTreeCreateTableTask.class.getName() };
 
-    public int addedWithVersion() {
-        return 78;
+    public String[] getDependencies() {
+        return DEPENDENCIES;
     }
 
-    public int getPriority() {
-        return UpdateTaskPriority.HIGH.priority;
-    }
-
-    public void perform(final Schema schema, final int contextId) throws AbstractOXException {
+    public void perform(PerformParameters params) throws AbstractOXException {
+        int contextId = params.getContextId();
+        Schema schema = params.getSchema();
         final Map<Integer, List<Integer>> m = getAllUsers(contextId);
 
         final int size = m.size();
@@ -173,7 +170,7 @@ public class VirtualTreeMigrationTask implements UpdateTask {
             } while (rs.next());
             return m;
         } catch (final SQLException e) {
-            throw createSQLError(e);
+            throw UpdateExceptionCodes.SQL_PROBLEM.create(e, e.getMessage());
         } finally {
             closeSQLStuff(rs, stmt);
             Database.back(contextId, false, writeCon);
@@ -188,7 +185,7 @@ public class VirtualTreeMigrationTask implements UpdateTask {
         {
             final int mailAdmin = getMailAdmin(contextId);
             if (-1 == mailAdmin) {
-                throw missingAdminError(contextId);
+                throw new UpdateException(new ContextException(ContextException.Code.NO_MAILADMIN));
             }
             final ContextImpl ctxi = new ContextImpl(contextId);
             ctxi.setMailadmin(mailAdmin);
@@ -274,8 +271,7 @@ public class VirtualTreeMigrationTask implements UpdateTask {
             /*
              * Insert other mail default folders: Drafts, Sent, Spam, and Trash
              */
-            
-            
+
         } catch (final OXException e) {
             throw new UpdateException(e);
         } catch (final FolderException e) {
@@ -293,8 +289,6 @@ public class VirtualTreeMigrationTask implements UpdateTask {
             } catch (final DBPoolingException e) {
                 throw new UpdateException(e);
             }
-            final int mailAdmin = ctx.getMailadmin();
-            final long creatingTime = System.currentTimeMillis();
             try {
                 final Permission systemPermission = new VirtualPermission();
                 systemPermission.setEntity(OCLPermission.ALL_GROUPS_AND_USERS);
@@ -352,16 +346,6 @@ public class VirtualTreeMigrationTask implements UpdateTask {
         }
     }
 
-    @OXThrowsMultiple(category = { Category.CODE_ERROR }, desc = { "" }, exceptionId = { 1 }, msg = { "A SQL error occurred while performing task VirtualTreeMigrationTask: %1$s." })
-    private static UpdateException createSQLError(final SQLException e) {
-        return EXCEPTION.create(1, e, e.getMessage());
-    }
-
-    @OXThrowsMultiple(category = { Category.CODE_ERROR }, desc = { "" }, exceptionId = { 2 }, msg = { "Error while performing task VirtualTreeMigrationTask: No context admin exists for context %1$s." })
-    private static UpdateException missingAdminError(final int contextId) {
-        return EXCEPTION.create(2, Integer.valueOf(contextId));
-    }
-
     private static int getMailAdmin(final int contextId) throws UpdateException {
         final Connection con;
         try {
@@ -380,7 +364,7 @@ public class VirtualTreeMigrationTask implements UpdateTask {
             }
             return -1;
         } catch (final SQLException e) {
-            throw createSQLError(e);
+            throw UpdateExceptionCodes.SQL_PROBLEM.create(e, e.getMessage());
         } finally {
             closeSQLStuff(rs, stmt);
             Database.back(contextId, false, con);
@@ -404,7 +388,7 @@ public class VirtualTreeMigrationTask implements UpdateTask {
             rs = stmt.executeQuery();
             return rs.next();
         } catch (final SQLException e) {
-            throw createSQLError(e);
+            throw UpdateExceptionCodes.SQL_PROBLEM.create(e, e.getMessage());
         } finally {
             closeSQLStuff(rs, stmt);
             Database.back(ctx, false, con);
