@@ -79,10 +79,10 @@ public class FireDetachedEventAction extends AttachmentEventAction {
 	protected void undoAction() throws AbstractOXException {
 		final List<AttachmentMetadata> processed = new ArrayList<AttachmentMetadata>();
 		try {
-			fireAttached(getAttachments(), processed, getUser(), getUserConfiguration(), getContext(), getProvider());
+			fireAttached(getAttachments(), processed, getUser(), getUserConfiguration(), getSession(), getContext(), getProvider());
 		} catch (final AbstractOXException e) {
 			try {
-				fireDetached(processed, getUser(), getUserConfiguration(), getContext(), getProvider());
+				fireDetached(processed, getUser(), getUserConfiguration(), getSession(), getContext(), getProvider());
 			} catch (final Exception e1) {
 				throw EXCEPTIONS.create(0);
 			}
@@ -101,7 +101,7 @@ public class FireDetachedEventAction extends AttachmentEventAction {
 	)
 	public void perform() throws AbstractOXException {
 		try {
-			fireDetached(getAttachments(), getUser(), getUserConfiguration(), getContext(), getProvider());
+			fireDetached(getAttachments(), getUser(), getUserConfiguration(), getSession(), getContext(), getProvider());
 		} catch (final AbstractOXException e) {
 			throw e;
 		} catch (final Exception e) {
