@@ -101,7 +101,7 @@ public class OXCalendarException extends OXException {
         UPDATE_USER_SHARED_MISMATCH("Folder type \"SHARED\" is not allowed in this situation.", 10, AbstractOXException.Category.USER_INPUT),
         RECURRING_UNEXPECTED_DELETE_STATE("Unexpected state for deleting a virtual appointment (exception). uid:oid:position %d:%d:%d", 11, AbstractOXException.Category.INTERNAL_ERROR),
         ERROR_SESSIONOBJECT_IS_NULL("SessionObject not initialized", 12, AbstractOXException.Category.CODE_ERROR),
-        NO_PERMISSION("You do not have the necessary permissions", 13, AbstractOXException.Category.PERMISSION),
+        NO_PERMISSION("You do not have the necessary permissions for appointments in folder %1$d.", 13, AbstractOXException.Category.PERMISSION),
         INSERT_WITH_OBJECT_ID("Insert expected but the object id is already given. Aborting action...", 14, AbstractOXException.Category.CODE_ERROR),
         UPDATE_WITHOUT_OBJECT_ID("Update expected but no object id is given. Aborting action...", 15, AbstractOXException.Category.CODE_ERROR),
         FOLDER_DELETE_INVALID_REQUEST("Invalid request. Folder is shared!", 16, AbstractOXException.Category.CODE_ERROR),
@@ -111,7 +111,7 @@ public class OXCalendarException extends OXException {
         END_DATE_BEFORE_START_DATE("End date is before start date", 20, AbstractOXException.Category.USER_INPUT),
         UNSUPPORTED_LABEL("ERROR: Unsupported label value %d", 21, AbstractOXException.Category.USER_INPUT),
         PRIVATE_FLAG_IN_PRIVATE_FOLDER("ERROR: Private flag is only allowed inside of a private folder.", 22, AbstractOXException.Category.USER_INPUT),
-        PRIVATE_FLAG_AND_PARTICIPANTS("ERROR: Private flag and participants are not supported.", 23, AbstractOXException.Category.USER_INPUT),
+        PRIVATE_FLAG_AND_PARTICIPANTS("Error: Appointments marked as 'Private' can only be scheduled for the respective user (or owner of the calendar). Please remove additional participants or remove the \"Private\" mark.", 23, AbstractOXException.Category.USER_INPUT),
         UNSUPPORTED_PRIVATE_FLAG("ERROR: Unsupported private flag value %d", 24, AbstractOXException.Category.USER_INPUT),
         UNSUPPORTED_SHOWN_AS("ERROR:: Unsupported \"shown as\"  value %d", 25, AbstractOXException.Category.USER_INPUT),
         MANDATORY_FIELD_START_DATE("Required  value \"Start Date\" was not supplied.", 26, AbstractOXException.Category.USER_INPUT),
@@ -276,14 +276,16 @@ public class OXCalendarException extends OXException {
         UNABLE_TO_CALCULATE_POSITION("Unable to calculate given position. Seems to be a delete exception or outside range", 98, Category.USER_INPUT),
         CHANGE_EXCEPTION_TO_RECURRENCE("Changing an exception into a series is not supported.", 99, Category.USER_INPUT),
         UID_ALREDY_EXISTS("Can not insert appointment with this uid. Uid already exists.", 100, Category.USER_INPUT),
-        /** SQL Problem: "%s". */
-        SQL_ERROR("SQL Problem: \"%s\".", 101, Category.CODE_ERROR),
+        /** SQL Problem. */
+        SQL_ERROR("SQL Problem.", 101, Category.CODE_ERROR),
         /** Wrong number of rows changed. Expected %1$d but was %2$d. */
         WRONG_ROW_COUNT("Wrong number of rows changed. Expected %1$d but was %2$d.", 102, Category.CODE_ERROR),
         /**
          * Unable to find a participant for a specified object.
          */
-        COULD_NOT_FIND_PARTICIPANT("Could not find participant for this object.", 103, Category.USER_INPUT);
+        COULD_NOT_FIND_PARTICIPANT("Could not find participant for this object.", 103, Category.USER_INPUT),
+        /** Was not able to calculate next upcoming reminder for series appointment %2$d in context %1$d. */
+        NEXT_REMINDER_FAILED("Was not able to calculate next upcoming reminder for series appointment %2$d in context %1$d.", 104, Category.CODE_ERROR);
 
         /**
          * Message of the exception.
