@@ -57,6 +57,7 @@ import com.openexchange.api2.OXException;
 import com.openexchange.groupware.contact.helpers.DefaultContactComparator;
 import com.openexchange.groupware.container.Contact;
 import com.openexchange.groupware.search.ContactSearchObject;
+import com.openexchange.groupware.search.Order;
 import com.openexchange.tools.iterator.SearchIterator;
 import com.openexchange.tools.session.ServerSession;
 
@@ -74,7 +75,7 @@ public class ContactSearchMultiplexer {
         this.discoveryService = discoveryService;
     }
 
-    public SearchIterator<Contact> extendedSearch(ServerSession session, ContactSearchObject search, int orderBy, String orderDir, int[] cols) throws OXException {
+    public SearchIterator<Contact> extendedSearch(ServerSession session, ContactSearchObject search, int orderBy, Order order, int[] cols) throws OXException {
         
         int[] folders = search.getFolders();
         int contextId = session.getContextId();
@@ -85,7 +86,7 @@ public class ContactSearchMultiplexer {
                 if(discoveryService.hasSpecificContactInterface(folderId, contextId)) {
                     ContactInterface contactInterface = discoveryService.newContactInterface(folderId, session);
                     search.setFolders(folderId);
-                    SearchIterator<Contact> iterator = contactInterface.getContactsByExtendedSearch(search, orderBy, orderDir, cols);
+                    SearchIterator<Contact> iterator = contactInterface.getContactsByExtendedSearch(search, orderBy, order, cols);
                     searchIterators.add(iterator);
                 } else {
                     foldersForDefaultSearch.add(I(folderId));
@@ -94,7 +95,7 @@ public class ContactSearchMultiplexer {
             if(!foldersForDefaultSearch.isEmpty()) {
                 search.setFolders(foldersForDefaultSearch);
                 ContactInterface defaultContactInterface = discoveryService.newDefaultContactInterface(session);
-                SearchIterator<Contact> contactsByExtendedSearch = defaultContactInterface.getContactsByExtendedSearch(search, orderBy, orderDir, cols);
+                SearchIterator<Contact> contactsByExtendedSearch = defaultContactInterface.getContactsByExtendedSearch(search, orderBy, order, cols);
                 searchIterators.add(contactsByExtendedSearch);
             }
             
@@ -103,18 +104,18 @@ public class ContactSearchMultiplexer {
             for (ContactInterfaceProviderRegistration registration : registrations) {
                 ContactInterface contactInterface = registration.newContactInterface(session);
                 search.setFolders(registration.getFolderId());
-                SearchIterator<Contact> searchIterator = contactInterface.getContactsByExtendedSearch(search, orderBy, orderDir, cols);
+                SearchIterator<Contact> searchIterator = contactInterface.getContactsByExtendedSearch(search, orderBy, order, cols);
                 searchIterators.add(searchIterator);
             }
             search.clearFolders();
             ContactInterface defaultContactInterface = discoveryService.newDefaultContactInterface(session);
-            SearchIterator<Contact> contactsByExtendedSearch = defaultContactInterface.getContactsByExtendedSearch(search, orderBy, orderDir, cols);
+            SearchIterator<Contact> contactsByExtendedSearch = defaultContactInterface.getContactsByExtendedSearch(search, orderBy, order, cols);
             searchIterators.add(contactsByExtendedSearch);
         
         }
         if(searchIterators.size() == 1) {
             return searchIterators.get(0);
         }
-        return new ContactMergerator(new DefaultContactComparator(orderBy, orderDir), searchIterators);
+        return new ContactMergerator(new DefaultContactComparator(orderBy, order), searchIterators);
     }
 }
