@@ -661,6 +661,22 @@ public class FolderObject extends FolderChildObject implements Cloneable, Serial
         b_permissions = true;
     }
 
+    /**
+     * Adds given permission to this folder object.
+     * 
+     * @param permission The permission to add
+     */
+    public void addPermission(final OCLPermission permission) {
+        if (null == permission) {
+            return;
+        }
+        if (this.permissions == null) {
+            this.permissions = new ArrayList<OCLPermission>(4);
+        }
+        b_permissions = true;
+        this.permissions.add(permission.deepClone());
+    }
+
     /**
      * Removes the permissions from this folder
      */
@@ -1266,7 +1282,7 @@ public class FolderObject extends FolderChildObject implements Cloneable, Serial
      * @see java.lang.Object#clone()
      */
     @Override
-    public Object clone() {
+    public FolderObject clone() {
         try {
             final FolderObject clone = (FolderObject) super.clone();
             if (b_created_by) {
@@ -1481,7 +1497,7 @@ public class FolderObject extends FolderChildObject implements Cloneable, Serial
     }
 
     private static final String SQL_LOAD_F =
-        "SELECT parent, fname, module, type, creating_date, created_from," + " changing_date, changed_from, permission_flag, subfolder_flag, default_flag" + " FROM #TABLE# WHERE cid = ? AND fuid = ?";
+        "SELECT parent, fname, module, type, creating_date, created_from, changing_date, changed_from, permission_flag, subfolder_flag, default_flag" + " FROM #TABLE# WHERE cid = ? AND fuid = ?";
 
     private static final Pattern PAT_RPL_TABLE = Pattern.compile("#TABLE#");
 
@@ -1646,7 +1662,7 @@ public class FolderObject extends FolderChildObject implements Cloneable, Serial
         return getSubfolderIds(folderId, ctx, readConArg, TABLE_OT);
     }
 
-    private static final String SQL_SEL = "SELECT fuid FROM #TABLE# WHERE cid = ? AND parent = ?";
+    private static final String SQL_SEL = "SELECT fuid FROM #TABLE# WHERE cid = ? AND parent = ? ORDER BY default_flag DESC, fname";
 
     /**
      * Gets the subfolder IDs of specified folder.
