@@ -28,7 +28,7 @@
  *    http://www.open-xchange.com/EN/developer/. The contributing author shall be
  *    given Attribution for the derivative code and a license granting use.
  *
- *     Copyright (C) 2004-2006 Open-Xchange, Inc.
+ *     Copyright (C) 2004-2010 Open-Xchange, Inc.
  *     Mail: info@open-xchange.com
  *
  *
@@ -49,20 +49,19 @@
 
 package com.openexchange.groupware.contexts.impl;
 
+import static com.openexchange.java.Autoboxing.I;
 import java.io.Serializable;
 import java.util.List;
 import java.util.concurrent.locks.Lock;
 import java.util.concurrent.locks.ReentrantLock;
-
 import org.apache.commons.logging.Log;
 import org.apache.commons.logging.LogFactory;
-
 import com.openexchange.cache.dynamic.impl.OXObjectFactory;
 import com.openexchange.caching.Cache;
 import com.openexchange.caching.CacheException;
 import com.openexchange.caching.CacheService;
 import com.openexchange.groupware.AbstractOXException;
-import com.openexchange.groupware.contexts.impl.ContextException.Code;
+import com.openexchange.groupware.update.UpdateStatus;
 import com.openexchange.groupware.update.Updater;
 import com.openexchange.server.services.ServerServiceRegistry;
 
@@ -74,26 +73,14 @@ import com.openexchange.server.services.ServerServiceRegistry;
  */
 public class CachingContextStorage extends ContextStorage {
 
-    /**
-     * Logger.
-     */
     private static final Log LOG = LogFactory.getLog(CachingContextStorage.class);
-   
+
     private static final String REGION_NAME = "Context";
 
-    /**
-     * Boolean flag for started status
-     */
     private boolean started;
 
-    /**
-     * Lock for the cache.
-     */
     private final Lock cacheLock;
 
-    /**
-     * Implementation of the context storage that does persistent storing.
-     */
     private final ContextStorage persistantImpl;
 
     /**
@@ -123,12 +110,12 @@ public class CachingContextStorage extends ContextStorage {
                 if (LOG.isTraceEnabled()) {
                     LOG.trace("Cache MISS. Login info: " + loginInfo);
                 }
-                contextId = Integer.valueOf(persistantImpl.getContextId(loginInfo));
+                contextId = I(persistantImpl.getContextId(loginInfo));
                 if (NOT_FOUND != contextId.intValue()) {
                     try {
                         cache.put(loginInfo, contextId);
                     } catch (final CacheException e) {
-                        throw new ContextException(Code.CACHE_PUT, e);
+                        throw new ContextException(e);
                     }
                 }
             } else if (LOG.isTraceEnabled()) {
@@ -148,21 +135,20 @@ public class CachingContextStorage extends ContextStorage {
         final CacheService cacheService = ServerServiceRegistry.getInstance().getService(CacheService.class);
         final OXObjectFactory<ContextExtended> factory = new OXObjectFactory<ContextExtended>() {
             public Serializable getKey() {
-                return Integer.valueOf(contextId);
+                return I(contextId);
             }
             public ContextExtended load() throws AbstractOXException {
-                final ContextExtended retval = persistantImpl.loadContext(contextId);
+                final ContextExtended retval = getPersistantImpl().loadContext(contextId);
                 final Updater updater = Updater.getInstance();
-                if (updater.isLocked(retval)) {
-                    retval.setUpdating(true);
-                } else if (updater.toUpdate(retval)) {
+                UpdateStatus status = updater.getStatus(retval);
+                retval.setUpdating(status.blockingUpdatesRunning() || status.needsBlockingUpdates());
+                if ((status.needsBlockingUpdates() || status.needsBackgroundUpdates()) && !status.blockingUpdatesRunning() && !status.backgroundUpdatesRunning()) {
                     updater.startUpdate(retval);
-                    retval.setUpdating(true);
                 }
                 return retval;
             }
             public Lock getCacheLock() {
-                return cacheLock;
+                return CachingContextStorage.this.getCacheLock();
             }
         };
         try {
@@ -263,4 +249,13 @@ public class CachingContextStorage extends ContextStorage {
             throw new ContextException(e);
         }
     }
+
+    Lock getCacheLock() {
+        return cacheLock;
+    }
+
+    ContextStorage getPersistantImpl() {
+        return persistantImpl;
+    }
+
 }
