@@ -57,7 +57,8 @@ import com.openexchange.groupware.delete.DeleteFailedException;
 import com.openexchange.groupware.tx.DBProvider;
 import com.openexchange.groupware.tx.SimpleDBProvider;
 import com.openexchange.tools.file.FileStorage;
-import com.openexchange.tools.file.FileStorageException;
+import com.openexchange.tools.file.QuotaFileStorage;
+import com.openexchange.tools.file.external.FileStorageException;
 
 /**
  * This class implements a delete listener and removes the directories of the
@@ -94,6 +95,6 @@ public final class FileStorageRemover extends ContextDelete {
     }
 
     private FileStorage getFileStorage(final Context ctx, DBProvider dbProvider) throws FileStorageException, FilestoreException {
-        return FileStorage.getInstance(FilestoreStorage.createURI(ctx), ctx, dbProvider); 
+        return QuotaFileStorage.getInstance(FilestoreStorage.createURI(ctx), ctx); 
     }
 }
