@@ -28,7 +28,7 @@
  *    http://www.open-xchange.com/EN/developer/. The contributing author shall be
  *    given Attribution for the derivative code and a license granting use.
  *
- *     Copyright (C) 2004-2006 Open-Xchange, Inc.
+ *     Copyright (C) 2004-2010 Open-Xchange, Inc.
  *     Mail: info@open-xchange.com
  *
  *
@@ -440,6 +440,37 @@ public class Notifications implements LocalizableStrings {
         "\n" + 
         "\n" + 
         "==========================================";
+    
+    public static final String APPOINTMENT_CONFIRMATION_MAIL_EXT = 
+        "[changed_by] has [confirmation_action] this appointment.\n" +
+        "\n" + 
+        "Appointment\n" + 
+        "===========\n" + 
+        "Created by: [created_by]\n" + 
+        "Created at: [creation_datetime]\n" + 
+        "[title]\n" + 
+        "[location]" + 
+        "[folder_name]\n" + 
+        "\n" + 
+        "[start]\n" + 
+        "[end]\n" + 
+        "[series]" + 
+        "[delete_exceptions]" + 
+        "[change_exceptions]" + 
+        "\n" + 
+        "[description]" + 
+        "\n" + 
+        "Participants\n" + 
+        "============\n" + 
+        "[participants]" +
+        "\n" + 
+        "\n" + 
+        "Resources\n" + 
+        "=========\n" + 
+        "[resources]" +
+        "\n" + 
+        "\n" + 
+        "==========================================";
 
     public static final String TASK_CONFIRMATION_MAIL = 
         "[changed_by] has [confirmation_action] this task.\n" +
@@ -472,6 +503,36 @@ public class Notifications implements LocalizableStrings {
         "\n" + 
         "\n" + 
         "==========================================";
+    
+    public static final String TASK_CONFIRMATION_MAIL_EXT = 
+        "[changed_by] has [confirmation_action] this task.\n" +
+        "\n" + 
+        "Task\n" + 
+        "====\n" + 
+        "Created by: [created_by]\n" + 
+        "Created at: [creation_datetime]\n" + 
+        "[title]\n" + 
+        "[folder_name]\n" + 
+        "[priority]\n" +
+        "[task_status]\n" +
+        "\n" + 
+        "[start]\n" + 
+        "[end]\n" + 
+        "[series]" + 
+        "\n" + 
+        "[description]" + 
+        "\n" + 
+        "Participants\n" + 
+        "============\n" + 
+        "[participants]" +
+        "\n" + 
+        "\n" + 
+        "Resources\n" + 
+        "=========\n" + 
+        "[resources]" +
+        "\n" + 
+        "\n" + 
+        "==========================================";
 
     /*-
      * MESSAGE SUBJECT PREFIXES
