@@ -71,7 +71,7 @@ import com.openexchange.groupware.importexport.exceptions.ImportExportExceptionF
     category={ Category.TRUNCATED },
     desc={ "" },
     exceptionId={ 0 },
-    msg={ "The following field(s) are too long to be imported: %s" }
+    msg={ "The following field(s) were too long and needed to be truncated: %s" }
 )
 public abstract class AbstractImporter implements Importer {
 
@@ -82,26 +82,4 @@ public abstract class AbstractImporter implements Importer {
     }
 
     protected abstract String getNameForFieldInTruncationError(int id, OXException dataTruncation);
-
-    protected OXException handleDataTruncation(OXException oxEx){
-        OXException retval = oxEx;
-        if (oxEx.getCategory() == Category.TRUNCATED) {
-            final String separator = ", ";
-            final StringBuilder bob = new StringBuilder();
-            final ProblematicAttribute[] problematics = oxEx.getProblematics();
-            for (final ProblematicAttribute problematic : problematics) {
-                if (problematic instanceof Truncated) {
-                    final int id = ((Truncated) problematic).getId();
-                    bob.append(getNameForFieldInTruncationError(id, oxEx));
-                    bob.append(separator);
-                }
-            }
-            bob.setLength(bob.length() - separator.length());
-            retval = EXCEPTIONS.create(0, bob.toString());
-            for (final ProblematicAttribute problematic : problematics) {
-                retval.addProblematic(problematic);
-            }
-        }
-        return retval;
-    }
 }
