@@ -83,6 +83,7 @@ import com.openexchange.groupware.importexport.SizedInputStream;
 import com.openexchange.groupware.importexport.exceptions.ImportExportException;
 import com.openexchange.groupware.importexport.exceptions.ImportExportExceptionClasses;
 import com.openexchange.groupware.importexport.exceptions.ImportExportExceptionFactory;
+import com.openexchange.groupware.search.Order;
 import com.openexchange.groupware.userconfiguration.UserConfigurationStorage;
 import com.openexchange.server.impl.EffectivePermission;
 import com.openexchange.server.services.ServerServiceRegistry;
@@ -272,7 +273,7 @@ public class CSVContactExporter implements Exporter {
 		try {
 		    final ContactInterface contactInterface = ServerServiceRegistry.getInstance().getService(
                 ContactInterfaceDiscoveryService.class).newContactInterface(folderId, sessObj);
-			conIter = contactInterface.getContactsInFolder(folderId, 0, contactInterface.getNumberOfContacts(folderId), 0, "ASC", cols);
+			conIter = contactInterface.getContactsInFolder(folderId, 0, contactInterface.getNumberOfContacts(folderId), 0, Order.ASCENDING, cols);
 		} catch (final OXException e) {
 			throw EXCEPTIONS.create(2, e);
 		}
