@@ -61,7 +61,6 @@ import java.util.EnumSet;
 import java.util.GregorianCalendar;
 import java.util.HashMap;
 import java.util.HashSet;
-import java.util.LinkedList;
 import java.util.List;
 import java.util.Locale;
 import java.util.Map;
@@ -81,14 +80,12 @@ import com.openexchange.api2.OXException;
 import com.openexchange.data.conversion.ical.ConversionError;
 import com.openexchange.data.conversion.ical.ConversionWarning;
 import com.openexchange.data.conversion.ical.ICalEmitter;
-import com.openexchange.data.conversion.ical.ICalItem;
 import com.openexchange.data.conversion.ical.ICalSession;
 import com.openexchange.data.conversion.ical.ITipContainer;
 import com.openexchange.data.conversion.ical.ITipMethod;
 import com.openexchange.database.DBPoolingException;
 import com.openexchange.event.impl.AppointmentEventInterface2;
 import com.openexchange.event.impl.TaskEventInterface2;
-import com.openexchange.folderstorage.internal.CalculatePermission;
 import com.openexchange.group.Group;
 import com.openexchange.group.GroupStorage;
 import com.openexchange.groupware.AbstractOXException;
@@ -115,7 +112,6 @@ import com.openexchange.groupware.ldap.UserException;
 import com.openexchange.groupware.ldap.UserStorage;
 import com.openexchange.groupware.notify.NotificationConfig.NotificationProperty;
 import com.openexchange.groupware.notify.State.Type;
-import com.openexchange.groupware.tasks.ExternalParticipant;
 import com.openexchange.groupware.tasks.Task;
 import com.openexchange.groupware.userconfiguration.RdbUserConfigurationStorage;
 import com.openexchange.groupware.userconfiguration.UserConfiguration;
@@ -145,13 +141,13 @@ import com.openexchange.i18n.tools.replacement.TaskPriorityReplacement;
 import com.openexchange.i18n.tools.replacement.TaskStatusReplacement;
 import com.openexchange.mail.MailException;
 import com.openexchange.mail.mime.MessageHeaders;
-import com.openexchange.mail.mime.datasource.FileDataSource;
 import com.openexchange.mail.mime.datasource.MessageDataSource;
 import com.openexchange.mail.mime.utils.MIMEMessageUtility;
 import com.openexchange.mail.usersetting.UserSettingMail;
 import com.openexchange.mail.usersetting.UserSettingMailStorage;
 import com.openexchange.resource.Resource;
 import com.openexchange.resource.storage.ResourceStorage;
+import com.openexchange.server.ServiceException;
 import com.openexchange.server.impl.EffectivePermission;
 import com.openexchange.server.services.ServerServiceRegistry;
 import com.openexchange.session.Session;
@@ -212,7 +208,28 @@ public class ParticipantNotify implements AppointmentEventInterface2, TaskEventI
         }
         String type = (msg.overrideType != null) ? msg.overrideType.toString() : state.getType().toString();
         final MailObject mail = new MailObject(session, obj.getObjectID(), fuid, state.getModule(), type);
-        mail.setFromAddr(UserStorage.getStorageUser(session.getUserId(), session.getContext()).getMail());
+                
+        String fromAddr;
+        String senderSource = NotificationConfig.getProperty(NotificationProperty.FROM_SOURCE, "primaryMail");
+        if (senderSource.equals("defaultSenderAddress")) {          
+            try {
+                fromAddr = getUserSettingMail(session.getUserId(), session.getContext()).getSendAddr();
+            } catch (OXException e) {
+                LOG.error(e.getMessage(), e);
+                fromAddr = UserStorage.getStorageUser(session.getUserId(), session.getContext()).getMail();
+            }
+        } else {
+            fromAddr = UserStorage.getStorageUser(session.getUserId(), session.getContext()).getMail();
+        }   
+        
+        User sender = UserStorage.getStorageUser(session.getUserId(), session.getContext());
+        
+        if (sender != null) {
+            mail.setFromAddr("\"" + sender.getDisplayName() + "\"" + " <" + fromAddr + ">");
+        } else {
+            mail.setFromAddr(fromAddr);
+        }
+
         mail.setToAddrs(msg.addresses.toArray(new String[msg.addresses.size()]));
         mail.setText(msg.message);
         mail.setSubject(msg.title);
@@ -491,9 +508,28 @@ public class ParticipantNotify implements AppointmentEventInterface2, TaskEventI
         if (Types.APPOINTMENT == state.getModule()) {
             final Appointment newApp = (Appointment) newObj;
             final Appointment oldApp = oldObj == null ? null : ((Appointment) oldObj);
+            
             if (!newApp.containsFullTime() && oldApp != null && oldApp.containsFullTime()) {
                 newApp.setFullTime(oldApp.getFullTime());
             }
+            
+            // Set correct recurrence information if CalendarObject is an Appointment
+            if (newApp.getRecurrenceType() != Appointment.NO_RECURRENCE) {
+                try {
+                    ServerServiceRegistry.getInstance().getService(CalendarCollectionService.class, true).fillDAO(
+                        (CalendarDataObject) newApp);
+                    if (oldObj != null) {
+                        ServerServiceRegistry.getInstance().getService(CalendarCollectionService.class, true).fillDAO(
+                            (CalendarDataObject) oldApp);
+                    }
+                } catch (Exception e) {
+                    if (e instanceof ServiceException || e instanceof OXException) {
+                        final StringBuilder builder = new StringBuilder(256).append("Could not set correct recurrence information in notification for appointment").append(title).append(" (").append(
+                            newObj.getObjectID()).append("). Cause:\n");
+                        LOG.error(builder.toString() + e.getMessage(), e);
+                    }                    
+                }
+            }            
         }
 
         /*
@@ -586,6 +622,7 @@ public class ParticipantNotify implements AppointmentEventInterface2, TaskEventI
                     }
                 } else {
                     sendMail = !p.ignoreNotification && (!newObj.containsNotification() || newObj.getNotification()) || (newObj.getModifiedBy() != p.id && forceNotifyOthers);
+                    sendMail = sendMail && (!EnumSet.of(State.Type.ACCEPTED, State.Type.DECLINED, State.Type.TENTATIVELY_ACCEPTED).contains(state.getType()) || p.email.equals(newObj.getOrganizer()));
                     if (p.timeZone != null) {
                         tz = p.timeZone;
                     }
@@ -751,6 +788,7 @@ public class ParticipantNotify implements AppointmentEventInterface2, TaskEventI
         final MailMessage msg = new MailMessage();
         final Template createTemplate = state.getTemplate();
         final StringHelper strings = new StringHelper(locale);
+
         b.setLength(0);
         actionRepl.setLocale(locale);
         msg.title = b.append(actionRepl.getReplacement()).append(": ").append(title).toString();
@@ -838,7 +876,7 @@ public class ParticipantNotify implements AppointmentEventInterface2, TaskEventI
                 if (p.type == Participant.USER && !NotificationConfig.getPropertyAsBoolean(NotificationProperty.INTERNAL_IMIP, false)) {
                     msg.message = textMessage;
                 } else {
-                    msg.message = generateMessageMultipart(session, cal, textMessage, state.getModule(), state.getType(), ITipMethod.REQUEST);
+                    msg.message = generateMessageMultipart(session, cal, textMessage, state.getModule(), state.getType(), ITipMethod.REQUEST, p, strings, b);
                 }
             } else if (EnumSet.of(State.Type.ACCEPTED, State.Type.DECLINED, State.Type.TENTATIVELY_ACCEPTED).contains(state.getType())) {
                 String textMessage = "";
@@ -850,7 +888,7 @@ public class ParticipantNotify implements AppointmentEventInterface2, TaskEventI
                 }
                 // Attach IMIP Magic only for external users on secondary events, to tell them the state of the appointment, but don't bother with internal users.
                 if(p.type == Participant.EXTERNAL_USER) {
-                    msg.message = generateMessageMultipart(session, cal, textMessage, state.getModule(), state.getType(), ITipMethod.REPLY);
+                    msg.message = generateMessageMultipart(session, cal, textMessage, state.getModule(), state.getType(), ITipMethod.REPLY, p, strings, b);
                 } else {
                     msg.message = textMessage;
                 }
@@ -858,19 +896,30 @@ public class ParticipantNotify implements AppointmentEventInterface2, TaskEventI
                 if (p.type == Participant.USER && !NotificationConfig.getPropertyAsBoolean(NotificationProperty.INTERNAL_IMIP, false)) {
                     msg.message = createTemplate.render(p.getLocale(), renderMap);
                 } else {
-                    msg.message = generateMessageMultipart(session, cal, createTemplate.render(p.getLocale(), renderMap), state.getModule(), state.getType(), ITipMethod.CANCEL);
+                    msg.message = generateMessageMultipart(session, cal, createTemplate.render(p.getLocale(), renderMap), state.getModule(), state.getType(), ITipMethod.CANCEL, p, strings, b);
                 }
             } else {
                 msg.message = createTemplate.render(p.getLocale(), renderMap);
             }
         }
         if (Participant.RESOURCE == p.type) {
+            /*-
+             * Special prefixes for resource participant receivers.
+             * 
+             * Prefix already applied to multipart/* content, therefore only check for text/plain content
+             */
+            final Object content = msg.message;
+            if (content instanceof String) {
+                /*
+                 * Prepend prefix to text content
+                 */
+                msg.message = b.append(String.format(strings.getString(Notifications.RESOURCE_PREFIX), p.displayName)).append(": ").append(
+                    content).toString();
+                b.setLength(0);
+            }
             /*
-             * Special prefixes for resource participant receivers
+             * Prefix title
              */
-            msg.message = b.append(String.format(strings.getString(Notifications.RESOURCE_PREFIX), p.displayName)).append(": ").append(
-                msg.message).toString();
-            b.setLength(0);
             msg.title = b.append('[').append(strings.getString(Notifications.RESOURCE_TITLE_PREFIX)).append("] ").append(msg.title).toString();
             b.setLength(0);
         }
@@ -881,69 +930,94 @@ public class ParticipantNotify implements AppointmentEventInterface2, TaskEventI
     }
 
     /**
-     * 
-     * @param session
-     * @param cal
-     * @param text
-     * @param module 
-     * @param type
-     * @param method
-     * @return
+     * Builds a multipart object containing the text/plain and iCal part
+     * @return The multipart object or given text if building failed
      */
-    private static Object generateMessageMultipart(ServerSession session, CalendarObject cal, String text, int module, State.Type type, ITipMethod method) {
+    private static Object generateMessageMultipart(ServerSession session, CalendarObject cal, String text, int module, State.Type type, ITipMethod method, EmailableParticipant p, final StringHelper strings, final StringBuilder b) {
         if (module == Types.TASK) {
             return text;
         }
-        
-        Appointment app = (Appointment) cal;
-        
-        ITipContainer iTip = new ITipContainer(method, type, session.getUserId());
-        ICalEmitter emitter = ServerServiceRegistry.getInstance().getService(ICalEmitter.class);
-        Multipart mp = new MimeMultipart("alternative");
-        
+        /*
+         * Generate iCal for appointment
+         */
         try {
-            BodyPart textPart = new MimeBodyPart();
-            textPart.setContent(text, "text/plain; charset=UTF-8");
-            
-            ICalSession icalSession = emitter.createSession();
+            final Multipart mp = new MimeMultipart("alternative");
+            /*
+             * Compose text part
+             */
+            final BodyPart textPart = new MimeBodyPart();
+            if (Participant.RESOURCE == p.type) {
+                /*
+                 * Prepend resource prefix to first text/plain body part
+                 */
+                textPart.setContent(
+                    b.append(String.format(strings.getString(Notifications.RESOURCE_PREFIX), p.displayName)).append(": ").append(text).toString(),
+                    "text/plain; charset=UTF-8");
+                b.setLength(0);
+            } else {
+                /*
+                 * Apply text as given
+                 */
+                textPart.setContent(text, "text/plain; charset=UTF-8");
+            }
+            /*
+             * Compose iCal part
+             */
+            final Appointment app = (Appointment) cal;
+            final ICalEmitter emitter = ServerServiceRegistry.getInstance().getService(ICalEmitter.class);
+            final ICalSession icalSession = emitter.createSession();
             Date until = null;
             if (Appointment.NO_RECURRENCE != app.getRecurrenceType()) {
                 until = app.getEndDate();
                 app.setEndDate(computeFirstOccurrenceEnd(app));
             }
-            boolean hasAlarm = app.containsAlarm();
-            int alarm = app.getAlarm();
+            final boolean hasAlarm = app.containsAlarm();
+            final int alarm = app.getAlarm();
             app.removeAlarm();
-            emitter.writeAppointment(icalSession, app, session.getContext(), iTip, new ArrayList<ConversionError>(), new ArrayList<ConversionWarning>());
+            final ITipContainer iTip = new ITipContainer(method, type, session.getUserId());
+            emitter.writeAppointment(
+                icalSession,
+                app,
+                session.getContext(),
+                iTip,
+                new ArrayList<ConversionError>(),
+                new ArrayList<ConversionWarning>());
             if (null != until) {
                 app.setEndDate(until);
             }
             if (hasAlarm) {
                 app.setAlarm(alarm);
             }
-            UnsynchronizedByteArrayOutputStream byteArrayOutputStream = new UnsynchronizedByteArrayOutputStream();
+            final UnsynchronizedByteArrayOutputStream byteArrayOutputStream = new UnsynchronizedByteArrayOutputStream();
             emitter.writeSession(icalSession, byteArrayOutputStream);
-            InputStream icalFile = new UnsynchronizedByteArrayInputStream(byteArrayOutputStream.toByteArray());
-            
-            BodyPart iCalPart = new MimeBodyPart();
-            
-            String contentType = "text/calendar; " + method.getMethod();
+            final InputStream icalFile = new UnsynchronizedByteArrayInputStream(byteArrayOutputStream.toByteArray());
+
+            final BodyPart iCalPart = new MimeBodyPart();
+
+            final String contentType = b.append("text/calendar; ").append(method.getMethod()).toString();
+            b.setLength(0);
             iCalPart.setDataHandler(new DataHandler(new MessageDataSource(icalFile, contentType)));
             iCalPart.setHeader(MessageHeaders.HDR_CONTENT_TYPE, MIMEMessageUtility.foldContentType(contentType));
             iCalPart.setHeader(MessageHeaders.HDR_CONTENT_TRANSFER_ENC, "base64");
-            
+            /*
+             * Add the parts to parental multipart & return
+             */
             mp.addBodyPart(textPart);
             mp.addBodyPart(iCalPart);
-        } catch (MessagingException e) {
+            return mp;
+        } catch (final MessagingException e) {
             LOG.error("Unable to compose message", e);
-        } catch (ConversionError e) {
+        } catch (final ConversionError e) {
             LOG.error("Unable to compose message", e);
-        } catch (IOException e) {
+        } catch (final IOException e) {
             LOG.error("Unable to compose message", e);
-        } catch (OXException e) {
+        } catch (final OXException e) {
             LOG.error("Unable to compose message", e);
-        } 
-        return mp;
+        }
+        /*
+         * Failed to create multipart
+         */
+        return text;
     }
 
     private static String getTaskCreateMessage(final EmailableParticipant p, final boolean canRead) {
@@ -1295,8 +1369,9 @@ public class ParticipantNotify implements AppointmentEventInterface2, TaskEventI
             }
         }
         
-        if (organizer != null)
+        if (organizer != null) {
             addSingleParticipant(getExternalParticipant(new ExternalUserParticipant(organizer), session), participantSet, resourceSet, receivers, all, false);
+        }
     }
 
     private void sortNewExternalParticipantsAndResources(final Participant[] newParticipants, final Set<EmailableParticipant> participantSet, final Set<EmailableParticipant> resourceSet, final Map<Locale, List<EmailableParticipant>> receivers, final ServerSession session, final Map<String, EmailableParticipant> all, final Participant[] oldParticipants) {
@@ -1881,22 +1956,6 @@ public class ParticipantNotify implements AppointmentEventInterface2, TaskEventI
                     }
                 }
             }
-            {
-                // Do not send notification mails for appointments whose
-                // start date is more than 30 minutes in the past
-                final Date startDate = calendarObj.getStartDate();
-                if (startDate != null) {
-                    if (Types.APPOINTMENT == module && (now - startDate.getTime()) > THIRTY_MINUTES) {
-                        if (DEBUG) {
-                            LOG.debug(new StringBuilder().append("Ignoring notification(s) for single appointment object ").append(
-                                calendarObj.getObjectID()).append(" since its start date is more than 30 minutes in the past").toString());
-                        }
-                        return false;
-                    }
-                    // Ignore Start Date for Tasks
-                    // See Bug 13086
-                }
-            }
         } else {
             final Date untilDate = calendarObj.getUntil();
             if (null != untilDate) {
