@@ -51,40 +51,30 @@ package com.openexchange.groupware.notify.hostname;
 
 /**
  * {@link HostnameService} - A simple interface providing the host name part in
- * generated links to internal objects:
- * 
+ * generated links to internal objects, e.g. for notifications:
  * <pre>
  * http://[hostname]/#m=[module]&amp;i=[object]&amp;f=[folder]
  * </pre>
- * 
  * @author <a href="mailto:thorben.betten@open-xchange.com">Thorben Betten</a>
- * 
  */
 public interface HostnameService {
 
-	/**
-	 * Returns the host name part used in generated links to internal objects;
-	 * meaning the replacement for &quot;[hostname]&quot; in URL template
-	 * defined by property &quot;object_link&quot; in properties file
-	 * &quot;notification.properties&quot;.
-	 * <p>
-	 * By default the template looks like:
-	 * 
-	 * <pre>
-	 * http://[hostname]/#m=[module]&amp;i=[object]&amp;f=[folder]
-	 * </pre>
-	 * 
-	 * @param userId
-	 *            The user ID or a value less than/equal to zero if not
-	 *            available
-	 * @param contextId
-	 *            The context ID or a value less than/equal to zero if not
-	 *            available
-	 * 
-	 * @return The host name part used in generated links to internal objects or
-	 *         <code>null</code> (if user ID and/or context ID could not be
-	 *         resolved or any error occurred).
-	 */
-	public String getHostname(final int userId, final int contextId);
+    /**
+     * Returns the host name part used in generated links to internal objects; meaning the replacement for &quot;[hostname]&quot; in URL
+     * template defined by property &quot;object_link&quot; in properties file &quot;notification.properties&quot;. Additionally this
+     * service may be used for the hostname when generating direct links into the UI.
+     * 
+     * @param userId
+     *            The user ID or a value less than/equal to zero if not
+     *            available
+     * @param contextId
+     *            The context ID or a value less than/equal to zero if not
+     *            available
+     * 
+     * @return The host name part used in generated links to internal objects or
+     *         <code>null</code> (if user ID and/or context ID could not be
+     *         resolved or any error occurred).
+     */
+    String getHostname(int userId, int contextId);
 
 }
