@@ -28,7 +28,7 @@
  *    http://www.open-xchange.com/EN/developer/. The contributing author shall be
  *    given Attribution for the derivative code and a license granting use.
  *
- *     Copyright (C) 2004-2006 Open-Xchange, Inc.
+ *     Copyright (C) 2004-2010 Open-Xchange, Inc.
  *     Mail: info@open-xchange.com
  *
  *
@@ -195,7 +195,7 @@ public class RdbSettingStorage extends SettingStorage {
         if (setting.isShared()) {
             final IValueHandler value = ConfigTree.getSharedValue(setting);
             if (null != value && value.isWritable()) {
-                value.writeValue(ctx, user, setting);
+                value.writeValue(session, ctx, user, setting);
             } else {
                 final SettingException e = new SettingException(Code.NO_WRITE,
                     setting.getName());
