@@ -57,7 +57,6 @@ import com.openexchange.groupware.settings.IValueHandler;
 import com.openexchange.groupware.settings.PreferencesItemService;
 import com.openexchange.groupware.settings.ReadOnlyValue;
 import com.openexchange.groupware.settings.Setting;
-import com.openexchange.groupware.settings.SettingException;
 import com.openexchange.groupware.userconfiguration.UserConfiguration;
 import com.openexchange.session.Session;
 
@@ -81,7 +80,7 @@ public class CharacterSearch implements PreferencesItemService {
                 return userConfig.hasContact();
             }
 
-            public void getValue(final Session session, Context ctx, User user, UserConfiguration userConfig, Setting setting) throws SettingException {
+            public void getValue(final Session session, Context ctx, User user, UserConfiguration userConfig, Setting setting) {
                 setting.setSingleValue(ContactConfig.getInstance().getBoolean(Property.CHARACTER_SEARCH));
             }
         };
