@@ -150,7 +150,7 @@ public final class ConfirmTask {
             con.commit();
         } catch (final SQLException e) {
             rollback(con);
-            throw new TaskException(Code.SQL_ERROR, e, e.getMessage());
+            throw new TaskException(Code.SQL_ERROR, e);
         } finally {
             autocommit(con);
             DBPool.closeWriterSilent(ctx, con);
@@ -158,23 +158,26 @@ public final class ConfirmTask {
     }
 
     void sentEvent(final Session session) throws TaskException {
-		try {
-			final EventClient eventClient = new EventClient(session);
-			final int confirm = changedParticipant.getConfirm();
-			if (CalendarObject.ACCEPT == confirm) {
-				eventClient.accept(changedTask);
-			} else if (CalendarObject.DECLINE == confirm) {
-				eventClient.declined(changedTask);
-			} else if (CalendarObject.TENTATIVE == confirm) {
-				eventClient.tentative(changedTask);
-			}
-		} catch (final EventException e) {
-			throw new TaskException(Code.EVENT, e);
-		} catch (final OXException e) {
-			throw new TaskException(e);
-		} catch (final ContextException e) {
-			throw new TaskException(e);
-		}
+        try {
+            final EventClient eventClient = new EventClient(session);
+            switch (changedParticipant.getConfirm()) {
+            case CalendarObject.ACCEPT:
+                eventClient.accept(changedTask);
+                break;
+            case CalendarObject.DECLINE:
+                eventClient.declined(changedTask);
+                break;
+            case CalendarObject.TENTATIVE:
+                eventClient.tentative(changedTask);
+                break;
+            }
+        } catch (final EventException e) {
+            throw new TaskException(Code.EVENT, e);
+        } catch (final OXException e) {
+            throw new TaskException(e);
+        } catch (final ContextException e) {
+            throw new TaskException(e);
+        }
     }
 
     /**
