@@ -50,6 +50,7 @@
 package com.openexchange.groupware.tasks;
 
 import static com.openexchange.groupware.tasks.StorageType.ACTIVE;
+import static com.openexchange.java.Autoboxing.I;
 import static com.openexchange.tools.sql.DBUtils.closeSQLStuff;
 import java.sql.Connection;
 import java.sql.DataTruncation;
@@ -65,6 +66,7 @@ import org.apache.commons.logging.Log;
 import org.apache.commons.logging.LogFactory;
 import com.openexchange.database.DBPoolingException;
 import com.openexchange.groupware.contexts.Context;
+import com.openexchange.groupware.search.Order;
 import com.openexchange.groupware.search.TaskSearchObject;
 import com.openexchange.groupware.tasks.TaskException.Code;
 import com.openexchange.groupware.tasks.TaskIterator2.StatementSetter;
@@ -81,10 +83,7 @@ import com.openexchange.tools.sql.DBUtils;
  */
 public class RdbTaskStorage extends TaskStorage {
 
-    /**
-     * Logger.
-     */
-    private static final Log LOG = LogFactory.getLog(RdbTaskStorage.class);
+    static final Log LOG = LogFactory.getLog(RdbTaskStorage.class);
 
     /**
      * This SQL statement counts the tasks in a folder. TODO Move to {@link SQL} class.
@@ -159,7 +158,7 @@ public class RdbTaskStorage extends TaskStorage {
                 throw new TaskException(Code.MODIFIED);
             }
         } catch (final SQLException e) {
-            throw new TaskException(Code.SQL_ERROR, e, e.getMessage());
+            throw new TaskException(Code.SQL_ERROR, e);
         } finally {
             closeSQLStuff(null, stmt);
         }
@@ -179,7 +178,7 @@ public class RdbTaskStorage extends TaskStorage {
      * {@inheritDoc}
      */
     @Override
-    TaskIterator list(final Context ctx, final int folderId, final int from, final int to, final int orderBy, final String orderDir, final int[] columns, final boolean onlyOwn, final int userId, final boolean noPrivate) throws TaskException {
+    TaskIterator list(final Context ctx, final int folderId, final int from, final int to, final int orderBy, final Order order, final int[] columns, final boolean onlyOwn, final int userId, final boolean noPrivate) throws TaskException {
         final StringBuilder sql = new StringBuilder();
         sql.append("SELECT ");
         sql.append(SQL.getFields(columns, false));
@@ -191,7 +190,7 @@ public class RdbTaskStorage extends TaskStorage {
         if (noPrivate) {
             sql.append(NO_PRIVATE);
         }
-        sql.append(SQL.getOrder(orderBy, orderDir));
+        sql.append(SQL.getOrder(orderBy, order));
         sql.append(SQL.getLimit(from, to));
         return new TaskIterator2(ctx, userId, sql.toString(), new StatementSetter() {
 
@@ -210,7 +209,7 @@ public class RdbTaskStorage extends TaskStorage {
      * {@inheritDoc}
      */
     @Override
-    TaskIterator search(final Context ctx, final int userId, final TaskSearchObject search, final int orderBy, final String orderDir, final int[] columns, final List<Integer> all, final List<Integer> own, final List<Integer> shared) throws TaskException {
+    TaskIterator search(final Context ctx, final int userId, final TaskSearchObject search, final int orderBy, final Order order, final int[] columns, final List<Integer> all, final List<Integer> own, final List<Integer> shared) throws TaskException {
         final StringBuilder sql = new StringBuilder();
         sql.append("SELECT ");
         sql.append(SQL.getFields(columns, true));
@@ -228,7 +227,7 @@ public class RdbTaskStorage extends TaskStorage {
             sql.append(patternCondition);
         }
         sql.append(" GROUP BY task.id");
-        sql.append(SQL.getOrder(orderBy, orderDir));
+        sql.append(SQL.getOrder(orderBy, order));
         return new TaskIterator2(ctx, userId, sql.toString(), new StatementSetter() {
 
             public void perform(final PreparedStatement stmt) throws SQLException {
@@ -303,7 +302,7 @@ public class RdbTaskStorage extends TaskStorage {
             result.close();
             stmt.close();
         } catch (final SQLException e) {
-            throw new TaskException(Code.SQL_ERROR, e, e.getMessage());
+            throw new TaskException(Code.SQL_ERROR, e);
         } finally {
             DBPool.closeReaderSilent(ctx, con);
         }
@@ -347,7 +346,7 @@ public class RdbTaskStorage extends TaskStorage {
         } catch (final DataTruncation e) {
             throw parseTruncated(con, e, task, type);
         } catch (final SQLException e) {
-            throw new TaskException(Code.SQL_ERROR, e, e.getMessage());
+            throw new TaskException(Code.SQL_ERROR, e);
         } finally {
             closeSQLStuff(null, stmt);
         }
@@ -378,7 +377,7 @@ public class RdbTaskStorage extends TaskStorage {
                 exists = false;
             }
         } catch (final SQLException e) {
-            throw new TaskException(Code.SQL_ERROR, e, e.getMessage());
+            throw new TaskException(Code.SQL_ERROR, e);
         } finally {
             closeSQLStuff(result, stmt);
         }
@@ -413,12 +412,12 @@ public class RdbTaskStorage extends TaskStorage {
                 task.setObjectID(taskId);
             }
         } catch (final SQLException e) {
-            throw new TaskException(Code.SQL_ERROR, e, e.getMessage());
+            throw new TaskException(Code.SQL_ERROR, e);
         } finally {
             closeSQLStuff(result, stmt);
         }
         if (null == task) {
-            throw new TaskException(Code.TASK_NOT_FOUND, Integer.valueOf(taskId), Integer.valueOf(ctx.getContextId()));
+            throw new TaskException(Code.TASK_NOT_FOUND, I(taskId), I(ctx.getContextId()));
         }
         return task;
     }
@@ -466,7 +465,7 @@ public class RdbTaskStorage extends TaskStorage {
         } catch (final DataTruncation e) {
             throw parseTruncated(con, e, task, type);
         } catch (final SQLException e) {
-            throw new TaskException(Code.SQL_ERROR, e, e.getMessage());
+            throw new TaskException(Code.SQL_ERROR, e);
         } finally {
             closeSQLStuff(null, stmt);
         }
@@ -558,7 +557,7 @@ public class RdbTaskStorage extends TaskStorage {
             result.close();
             stmt.close();
         } catch (final SQLException e) {
-            throw new TaskException(Code.SQL_ERROR, e, e.getMessage());
+            throw new TaskException(Code.SQL_ERROR, e);
         }
         return retval;
     }
