@@ -50,11 +50,13 @@
 package com.openexchange.groupware.tasks;
 
 import static com.openexchange.java.Autoboxing.I;
+import static com.openexchange.tools.sql.DBUtils.forSQLCommand;
 import java.util.ArrayList;
 import java.util.Date;
 import java.util.EnumMap;
 import java.util.List;
 import java.util.Map;
+import com.openexchange.groupware.search.Order;
 import com.openexchange.groupware.search.TaskSearchObject;
 import com.openexchange.groupware.tasks.TaskException.Code;
 
@@ -352,17 +354,16 @@ public final class SQL {
 
     /**
      * @param orderBy attribute identifier that should be used for sorting.
-     * @param orderDir string defining the order direction. <code>"ASC"</code>
-     * or <code>"DESC"</code>.
+     * @param order defining the order direction.
      * @return SQL order by expression.
      */
-    static String getOrder(final int orderBy, final String orderDir) {
+    static String getOrder(final int orderBy, final Order order) {
         final StringBuilder sql = new StringBuilder();
-        if (0 != orderBy) {
+        if (0 != orderBy && !Order.NO_ORDER.equals(order)) {
             sql.append(" ORDER BY ");
             sql.append(Mapping.getMapping(orderBy).getDBColumnName());
             sql.append(' ');
-            sql.append(orderDir);
+            sql.append(forSQLCommand(order));
         }
         return sql.toString();
     }
