@@ -28,7 +28,7 @@
  *    http://www.open-xchange.com/EN/developer/. The contributing author shall be
  *    given Attribution for the derivative code and a license granting use.
  *
- *     Copyright (C) 2004-2006 Open-Xchange, Inc.
+ *     Copyright (C) 2004-2010 Open-Xchange, Inc.
  *     Mail: info@open-xchange.com
  *
  *
@@ -49,9 +49,7 @@
 
 package com.openexchange.groupware.tasks;
 
-import static com.openexchange.java.Autoboxing.F;
 import static com.openexchange.java.Autoboxing.I;
-import static com.openexchange.java.Autoboxing.L;
 import java.util.ArrayList;
 import java.util.Collection;
 import java.util.Date;
@@ -141,19 +139,19 @@ public class Task extends CalendarObject {
 
     private int projectId = 0;
 
-    private float targetCosts = 0;
+    private Float targetCosts;
 
-    private float actualCosts = 0;
+    private Float actualCosts;
 
     /**
      * The duration is measured by outlook in minutes. We do here the same.
      */
-    private long targetDuration = 0;
+    private Long targetDuration;
 
     /**
      * The duration is measured by outlook in minutes. We do here the same.
      */
-    private long actualDuration = 0;
+    private Long actualDuration;
 
     private int priority = 0;
 
@@ -214,25 +212,25 @@ public class Task extends CalendarObject {
         return projectId;
     }
 
-    public float getTargetCosts() {
+    public Float getTargetCosts() {
         return targetCosts;
     }
 
-    public float getActualCosts() {
+    public Float getActualCosts() {
         return actualCosts;
     }
 
     /**
      * @return the target duration
      */
-    public long getTargetDuration() {
+    public Long getTargetDuration() {
         return targetDuration;
     }
 
     /**
      * @return the actual duration
      */
-    public long getActualDuration() {
+    public Long getActualDuration() {
         return actualDuration;
     }
 
@@ -282,12 +280,12 @@ public class Task extends CalendarObject {
         projectIdSet = true;
     }
 
-    public void setTargetCosts(final float target_costs) {
+    public void setTargetCosts(Float target_costs) {
         this.targetCosts = target_costs;
         targetCostsSet = true;
     }
 
-    public void setActualCosts(final float actual_costs) {
+    public void setActualCosts(Float actual_costs) {
         this.actualCosts = actual_costs;
         actualCostsSet = true;
     }
@@ -295,7 +293,7 @@ public class Task extends CalendarObject {
     /**
      * @param targetDuration the target duration to set
      */
-    public void setTargetDuration(final long targetDuration) {
+    public void setTargetDuration(Long targetDuration) {
         this.targetDuration = targetDuration;
         targetDurationSet = true;
     }
@@ -303,7 +301,7 @@ public class Task extends CalendarObject {
     /**
      * @param actualDuration the actual duration to set
      */
-    public void setActualDuration(final long actualDuration) {
+    public void setActualDuration(Long actualDuration) {
         this.actualDuration = actualDuration;
         actualDurationSet = true;
     }
@@ -365,22 +363,22 @@ public class Task extends CalendarObject {
     }
 
     public void removeTargetCosts() {
-        targetCosts = 0;
+        targetCosts = null;
         targetCostsSet = false;
     }
 
     public void removeActualCosts() {
-        actualCosts = 0;
+        actualCosts = null;
         actualCostsSet = false;
     }
 
     public void removeTargetDuration() {
-        targetDuration = 0;
+        targetDuration = null;
         targetDurationSet = false;
     }
 
     public void removeActualDuration() {
-        actualDuration = 0;
+        actualDuration = null;
         actualDurationSet = false;
     }
 
@@ -500,12 +498,12 @@ public class Task extends CalendarObject {
         super.reset();
 
         projectId = 0;
-        targetCosts = 0;
-        actualCosts = 0;
+        targetCosts = null;
+        actualCosts = null;
 
-        targetDuration = 0;
+        targetDuration = null;
 
-        actualDuration = 0;
+        actualDuration = null;
 
         priority = 0;
         percentComplete = 0;
@@ -581,13 +579,13 @@ public class Task extends CalendarObject {
             setStatus(((Integer) value).intValue());
             break;
         case TARGET_DURATION:
-            setTargetDuration(((Long) value).longValue());
+            setTargetDuration((Long) value);
             break;
         case DATE_COMPLETED:
             setDateCompleted((Date) value);
             break;
         case TARGET_COSTS:
-            setTargetCosts(((Float) value).floatValue());
+            setTargetCosts((Float) value);
             break;
         case PRIORITY:
             setPriority(((Integer) value).intValue());
@@ -608,7 +606,7 @@ public class Task extends CalendarObject {
             setCurrency((String) value);
             break;
         case ACTUAL_COSTS:
-            setActualCosts(((Float) value).floatValue());
+            setActualCosts((Float) value);
             break;
         case PROJECT_ID:
             setProjectID(((Integer) value).intValue());
@@ -617,7 +615,7 @@ public class Task extends CalendarObject {
             setTripMeter((String) value);
             break;
         case ACTUAL_DURATION:
-            setActualDuration(((Long) value).longValue());
+            setActualDuration((Long) value);
             break;
         default:
             super.set(field, value);
@@ -630,11 +628,11 @@ public class Task extends CalendarObject {
         case STATUS:
             return I(getStatus());
         case TARGET_DURATION:
-            return L(getTargetDuration());
+            return getTargetDuration();
         case DATE_COMPLETED:
             return getDateCompleted();
         case TARGET_COSTS:
-            return F(getTargetCosts());
+            return getTargetCosts();
         case PRIORITY:
             return I(getPriority());
         case BILLING_INFORMATION:
@@ -648,13 +646,13 @@ public class Task extends CalendarObject {
         case CURRENCY:
             return getCurrency();
         case ACTUAL_COSTS:
-            return F(getActualCosts());
+            return getActualCosts();
         case PROJECT_ID:
             return I(getProjectID());
         case TRIP_METER:
             return getTripMeter();
         case ACTUAL_DURATION:
-            return L(getActualDuration());
+            return getActualDuration();
         default:
             return super.get(field);
         }
