@@ -203,9 +203,9 @@ public class TaskException extends AbstractOXException {
         UNIMPLEMENTED("This method is not implemented.",
             Category.CODE_ERROR, Detail.OTHER, 4),
         /**
-         * SQL Problem: "%s".
+         * SQL Problem.
          */
-        SQL_ERROR("SQL Problem: \"%s\".", Category.CODE_ERROR,
+        SQL_ERROR("SQL Problem.", Category.CODE_ERROR,
             Detail.OTHER, 5),
         /**
          * Folder %1$s (%2$d) is not a task folder.
@@ -438,7 +438,11 @@ public class TaskException extends AbstractOXException {
         /**
          * In order to accomplish the search, %1$d or more characters are required.
          */
-        PATTERN_TOO_SHORT("In order to accomplish the search, %1$d or more characters are required.", Category.USER_INPUT, Detail.OTHER, 51);
+        PATTERN_TOO_SHORT("In order to accomplish the search, %1$d or more characters are required.", Category.USER_INPUT, Detail.OTHER, 51),
+        /**
+         * 
+         */
+        GROUP_IS_EMPTY("Group %1$d is empty. You can't add an empty group to a task.", Category.USER_INPUT, Detail.OTHER, 52);
 
         /**
          * Message of the exception.
