@@ -63,6 +63,7 @@ import com.openexchange.groupware.container.FolderObject;
 import com.openexchange.groupware.contexts.Context;
 import com.openexchange.groupware.contexts.impl.ContextException;
 import com.openexchange.groupware.ldap.User;
+import com.openexchange.groupware.search.Order;
 import com.openexchange.groupware.search.TaskSearchObject;
 import com.openexchange.groupware.tasks.TaskException.Code;
 import com.openexchange.groupware.userconfiguration.UserConfiguration;
@@ -93,7 +94,7 @@ public class TasksSQLImpl implements TasksSQLInterface {
      * TODO eliminate duplicate columns
      */
     public SearchIterator<Task> getTaskList(final int folderId, final int from,
-        final int until, final int orderBy, final String orderDir,
+        final int until, final int orderBy, final Order order,
         final int[] columns) throws OXException {
         boolean onlyOwn;
         final Context ctx;
@@ -117,7 +118,7 @@ public class TasksSQLImpl implements TasksSQLInterface {
         final boolean noPrivate = Tools.isFolderShared(folder, user);
         try {
             return TaskStorage.getInstance().list(ctx, folderId, from, until,
-                orderBy, orderDir, columns, onlyOwn, userId, noPrivate);
+                orderBy, order, columns, onlyOwn, userId, noPrivate);
         } catch (final TaskException e) {
             throw Tools.convert(e);
         }
@@ -203,6 +204,7 @@ public class TasksSQLImpl implements TasksSQLInterface {
     public void insertTaskObject(final Task task) throws OXException {
         final Context ctx;
         final Set<TaskParticipant> parts;
+        final FolderObject folder;
         try {
             ctx = Tools.getContext(session.getContextId());
             final int userId = session.getUserId();
@@ -212,7 +214,7 @@ public class TasksSQLImpl implements TasksSQLInterface {
             TaskLogic.checkNewTask(task, userId, userConfig, parts);
             // Check access rights
             final int folderId = task.getParentFolderID();
-            final FolderObject folder = Tools.getFolder(ctx, folderId);
+            folder = Tools.getFolder(ctx, folderId);
             Permission.checkCreate(ctx, user, userConfig, folder);
             if (task.getPrivateFlag() && (Tools.isFolderPublic(folder)
                 || Tools.isFolderShared(folder, user))) {
@@ -223,8 +225,7 @@ public class TasksSQLImpl implements TasksSQLInterface {
             // Create folder mappings
             Set<Folder> folders;
             if (Tools.isFolderPublic(folder)) {
-                folders = TaskLogic.createFolderMapping(folderId, task
-                    .getCreatedBy(), InternalParticipant.EMPTY);
+                folders = TaskLogic.createFolderMapping(folderId, task.getCreatedBy(), InternalParticipant.EMPTY_INTERNAL);
             } else {
                 Tools.fillStandardFolders(ctx, ParticipantStorage
                     .extractInternal(parts));
@@ -246,11 +247,9 @@ public class TasksSQLImpl implements TasksSQLInterface {
         // Prepare for event
         task.setUsers(TaskLogic.createUserParticipants(parts));
         try {
-            new EventClient(session).create(task);
+            new EventClient(session).create(task, folder);
         } catch (final EventException e) {
             throw Tools.convert(new TaskException(Code.EVENT, e));
-        } catch (final ContextException e) {
-            throw Tools.convert(new TaskException(Code.EVENT, e));
         }
     }
 
@@ -366,7 +365,7 @@ public class TasksSQLImpl implements TasksSQLInterface {
         return new ArrayIterator<Task>(tasks.toArray(new Task[tasks.size()]));
     }
 
-    public SearchIterator<Task> getTasksByExtendedSearch(TaskSearchObject searchData, int orderBy, String orderDir, int[] columns) throws OXException {
+    public SearchIterator<Task> getTasksByExtendedSearch(TaskSearchObject searchData, int orderBy, Order order, int[] columns) throws OXException {
         final Context ctx;
         final User user;
         final UserConfiguration config;
@@ -375,7 +374,7 @@ public class TasksSQLImpl implements TasksSQLInterface {
             ctx = Tools.getContext(session.getContextId());
             user = Tools.getUser(ctx, userId);
             config = Tools.getUserConfiguration(ctx, userId);
-            final Search search = new Search(ctx, user, config, searchData, orderBy, orderDir, columns);
+            final Search search = new Search(ctx, user, config, searchData, orderBy, order, columns);
             return search.perform();
         } catch (TaskException e) {
             throw Tools.convert(e);
