@@ -321,7 +321,25 @@ public final class InternalList {
         new com.openexchange.groupware.update.tasks.ExtendCalendarForIMIPHandlingTask(),
 
         // Enables the bit for the contact collector feature for every user because that bit was not checked before 6.16.
-        new com.openexchange.groupware.update.tasks.ContactCollectorReEnabler()
+        new com.openexchange.groupware.update.tasks.ContactCollectorReEnabler(),
+
+        // +++++++++++++++++++++++++++++++++ Version 6.18 starts here. +++++++++++++++++++++++++++++++++
+
+        // Adds a column to the table user_setting_server named folderTree to store the selected folder tree.
+        new com.openexchange.groupware.update.tasks.FolderTreeSelectionTask(),
+        
+        // Repairs appointments where the number of attachments does not match the real amount of attachments.
+        new com.openexchange.groupware.update.tasks.AttachmentCountUpdateTask(),
+
+        // Creates an initial empty filestore usage entry for every context that currently did not uploaded anything.
+        new com.openexchange.groupware.update.tasks.AddInitialFilestoreUsage(),
+
+        // Currently users contacts are created with the display name attribute filed. Outlook primarily uses the fileAs attribute. This
+        // task copies the display name to fileAs if that is empty.
+        new com.openexchange.groupware.update.tasks.AddFileAsForUserContacts(),
+        
+        // Extend field "reason" for participants.
+        new com.openexchange.groupware.update.tasks.ParticipantCommentFieldLength()
 
         // TODO: Enable virtual folder tree update task when needed
         // Migrates existing folder data to new outlook-like folder tree structure
