@@ -76,7 +76,7 @@ import com.openexchange.groupware.update.Schema;
 import com.openexchange.groupware.update.UpdateTask;
 import com.openexchange.groupware.update.exception.Classes;
 import com.openexchange.groupware.update.exception.UpdateExceptionFactory;
-import com.openexchange.tools.file.FileStorageException;
+import com.openexchange.tools.file.external.FileStorageException;
 import com.openexchange.tools.oxfolder.OXFolderAccess;
 import com.openexchange.tools.sql.DBUtils;
 import com.openexchange.tools.update.Tools;
@@ -319,7 +319,7 @@ public class ContactsRepairLinksAttachments implements UpdateTask {
     private final void deleteAttachments(final int cid, final Connection con, final int id, final String filename) throws SQLException {
         LOG.info("Deleting orphaned attachment " + id + " in context " + cid + ".");
         try {
-            Tools.removeFile(cid, filename, con);
+            Tools.removeFile(cid, filename);
         } catch (final ContextException e) {
             LOG.info("Context is already removed. Assuming its files are removed, too.");
         } catch (final FilestoreException e) {
