@@ -143,6 +143,8 @@ public final class MailProperties implements IMailProperties {
 
     private boolean ignoreSubscription;
 
+    private boolean hidePOP3StorageFolders;
+
     private char defaultSeparator;
 
     private int maxNumOfConnections;
@@ -171,6 +173,13 @@ public final class MailProperties implements IMailProperties {
 
     private int mailAccessCacheIdleSeconds;
 
+    private boolean rateLimitPrimaryOnly;
+
+    private int rateLimit;
+
+    private int maxToCcBcc;
+
+
     /**
      * Initializes a new {@link MailProperties}
      */
@@ -241,6 +250,7 @@ public final class MailProperties implements IMailProperties {
         allowNestedDefaultFolderOnAltNamespace = false;
         defaultMimeCharset = null;
         ignoreSubscription = false;
+        hidePOP3StorageFolders = false;
         defaultSeparator = '/';
         maxNumOfConnections = 0;
         quoteLineColors = null;
@@ -254,6 +264,10 @@ public final class MailProperties implements IMailProperties {
         adminMailLoginEnabled = false;
         mailAccessCacheShrinkerSeconds = 0;
         mailAccessCacheIdleSeconds = 0;
+        rateLimitPrimaryOnly = true;
+        rateLimit = 0;
+        maxToCcBcc = 0;
+
     }
 
     private void loadProperties0() throws MailConfigException {
@@ -439,6 +453,12 @@ public final class MailProperties implements IMailProperties {
             logBuilder.append("\tIgnore Folder Subscription: ").append(ignoreSubscription).append('\n');
         }
 
+        {
+            final String tmp = configuration.getProperty("com.openexchange.mail.hidePOP3StorageFolders", "false").trim();
+            hidePOP3StorageFolders = Boolean.parseBoolean(tmp);
+            logBuilder.append("\tHide POP3 Storage Folders: ").append(hidePOP3StorageFolders).append('\n');
+        }
+
         {
             final String supSubsStr = configuration.getProperty("com.openexchange.mail.supportSubscription", "true").trim();
             supportSubscription = Boolean.parseBoolean(supSubsStr);
@@ -547,6 +567,38 @@ public final class MailProperties implements IMailProperties {
             }
         }
 
+        {
+            final String rateLimitPrimaryOnlyStr = configuration.getProperty("com.openexchange.mail.rateLimitPrimaryOnly", "true").trim();
+            rateLimitPrimaryOnly = Boolean.parseBoolean(rateLimitPrimaryOnlyStr);
+            logBuilder.append("\tRate limit primary only: ").append(rateLimitPrimaryOnly).append('\n');
+        }
+        
+        {
+            final String rateLimitStr = configuration.getProperty("com.openexchange.mail.rateLimit", "0").trim();
+            try {
+                rateLimit = Integer.parseInt(rateLimitStr);
+                logBuilder.append("\tSent Rate limit: ").append(rateLimit).append('\n');
+            } catch (final NumberFormatException e) {
+                rateLimit = 0;
+                logBuilder.append("\tSent Rate limit: Invalid value \"").append(rateLimitStr).append("\". Setting to fallback ").append(
+                    rateLimit).append('\n');
+                
+            }
+        }
+
+        {
+            final String maxToCcBccStr = configuration.getProperty("com.openexchange.mail.maxToCcBcc", "0").trim();
+            try {
+                maxToCcBcc = Integer.parseInt(maxToCcBccStr);
+                logBuilder.append("\tmaxToCcBcc: ").append(maxToCcBcc).append('\n');
+            } catch (final NumberFormatException e) {
+                maxToCcBcc = 0;
+                logBuilder.append("\tmaxToCcBcc: Invalid value \"").append(maxToCcBccStr).append("\". Setting to fallback ").append(
+                    maxToCcBcc).append('\n');
+                
+            }
+        }
+        
         {
             String javaMailPropertiesStr = configuration.getProperty("com.openexchange.mail.JavaMailProperties");
             if (null != javaMailPropertiesStr) {
@@ -649,6 +701,10 @@ public final class MailProperties implements IMailProperties {
         return ignoreSubscription;
     }
 
+    public boolean isHidePOP3StorageFolders() {
+        return hidePOP3StorageFolders;
+    }
+
     public boolean isSupportSubscription() {
         return supportSubscription;
     }
@@ -724,6 +780,15 @@ public final class MailProperties implements IMailProperties {
         return maxNumOfConnections;
     }
 
+    /**
+     * Gets the sent mail rate limit (how many mails can be sent in 
+     * 
+     * @return
+     */
+    public int getMaxToCcBcc() {
+        return maxToCcBcc;
+    }
+
     /**
      * Gets the quote line colors.
      * 
@@ -733,6 +798,25 @@ public final class MailProperties implements IMailProperties {
         return quoteLineColors;
     }
 
+    /**
+     * Gets the sent mail rate limit (how many mails can be sent in 
+     * 
+     * @return
+     */
+    public int getRateLimit() {
+        return rateLimit;
+    }
+
+    /**
+     * Gets the setting if the rate limit should only affect the primary
+     * account or all accounts 
+     * 
+     * @return
+     */
+    public boolean getRateLimitPrimaryOnly() {
+        return rateLimitPrimaryOnly;
+    }
+    
     /**
      * Gets the global transport server
      * 
