@@ -55,9 +55,11 @@ import java.util.Arrays;
 import java.util.Date;
 import java.util.HashSet;
 import java.util.Iterator;
+import java.util.LinkedHashSet;
 import java.util.List;
 import javax.mail.internet.AddressException;
 import javax.mail.internet.InternetAddress;
+import javax.mail.internet.MailDateFormat;
 import com.openexchange.mail.MailException;
 import com.openexchange.mail.MailPath;
 import com.openexchange.mail.mime.HeaderName;
@@ -66,7 +68,7 @@ import com.openexchange.mail.mime.PlainTextAddress;
 import com.openexchange.mail.mime.QuotedInternetAddress;
 import com.openexchange.mail.mime.converters.MIMEMessageConverter;
 import com.openexchange.mail.mime.utils.MIMEMessageUtility;
-import com.openexchange.mail.utils.DateUtils;
+import com.openexchange.tools.TimeZoneUtils;
 
 /**
  * {@link MailMessage} - Abstract super class for all {@link MailMessage} subclasses.
@@ -443,7 +445,7 @@ public abstract class MailMessage extends MailPart {
             b_from = true;
             return;
         } else if (null == from) {
-            from = new HashSet<InternetAddress>();
+            from = new LinkedHashSet<InternetAddress>();
             b_from = true;
         }
         from.add(addr);
@@ -459,7 +461,7 @@ public abstract class MailMessage extends MailPart {
             b_from = true;
             return;
         } else if (null == from) {
-            from = new HashSet<InternetAddress>();
+            from = new LinkedHashSet<InternetAddress>();
             b_from = true;
         }
         from.addAll(Arrays.asList(addrs));
@@ -510,7 +512,7 @@ public abstract class MailMessage extends MailPart {
             b_to = true;
             return;
         } else if (null == to) {
-            to = new HashSet<InternetAddress>();
+            to = new LinkedHashSet<InternetAddress>();
             b_to = true;
         }
         to.add(addr);
@@ -526,7 +528,7 @@ public abstract class MailMessage extends MailPart {
             b_to = true;
             return;
         } else if (null == to) {
-            to = new HashSet<InternetAddress>();
+            to = new LinkedHashSet<InternetAddress>();
             b_to = true;
         }
         to.addAll(Arrays.asList(addrs));
@@ -577,7 +579,7 @@ public abstract class MailMessage extends MailPart {
             b_cc = true;
             return;
         } else if (null == cc) {
-            cc = new HashSet<InternetAddress>();
+            cc = new LinkedHashSet<InternetAddress>();
             b_cc = true;
         }
         cc.add(addr);
@@ -593,7 +595,7 @@ public abstract class MailMessage extends MailPart {
             b_cc = true;
             return;
         } else if (null == cc) {
-            cc = new HashSet<InternetAddress>();
+            cc = new LinkedHashSet<InternetAddress>();
             b_cc = true;
         }
         cc.addAll(Arrays.asList(addrs));
@@ -644,7 +646,7 @@ public abstract class MailMessage extends MailPart {
             b_bcc = true;
             return;
         } else if (null == bcc) {
-            bcc = new HashSet<InternetAddress>();
+            bcc = new LinkedHashSet<InternetAddress>();
             b_bcc = true;
         }
         bcc.add(addr);
@@ -660,7 +662,7 @@ public abstract class MailMessage extends MailPart {
             b_bcc = true;
             return;
         } else if (null == bcc) {
-            bcc = new HashSet<InternetAddress>();
+            bcc = new LinkedHashSet<InternetAddress>();
             b_bcc = true;
         }
         bcc.addAll(Arrays.asList(addrs));
@@ -935,6 +937,13 @@ public abstract class MailMessage extends MailPart {
         b_subject = true;
     }
 
+    private static final MailDateFormat MAIL_DATE_FORMAT;
+
+    static {
+        MAIL_DATE_FORMAT = new MailDateFormat();
+        MAIL_DATE_FORMAT.setTimeZone(TimeZoneUtils.getTimeZone("GMT"));
+    }
+
     /**
      * Gets the sent date which corresponds to <i>Date</i> header
      * 
@@ -944,7 +953,16 @@ public abstract class MailMessage extends MailPart {
         if (!b_sentDate) {
             final String sentDateStr = getFirstHeader(MessageHeaders.HDR_DATE);
             if (sentDateStr != null) {
-                setSentDate(DateUtils.getDateRFC822(sentDateStr));
+                synchronized (MAIL_DATE_FORMAT) {
+                    try {
+                        final Date parsedDate = MAIL_DATE_FORMAT.parse(sentDateStr);
+                        if (null != parsedDate) {
+                            setSentDate(parsedDate);
+                        }
+                    } catch (final java.text.ParseException e) {
+                        LOG.warn("Date string could not be parsed: " + sentDateStr, e);
+                    }
+                }
             }
         }
         return sentDate == null ? null : new Date(sentDate.getTime());
@@ -1130,9 +1148,14 @@ public abstract class MailMessage extends MailPart {
      */
     public int getPriority() {
         if (!b_priority) {
-            final String prioStr = getFirstHeader(MessageHeaders.HDR_X_PRIORITY);
-            if (prioStr != null) {
-                setPriority(MIMEMessageConverter.parsePriority(prioStr));
+            final String imp = getFirstHeader(MessageHeaders.HDR_IMPORTANCE);
+            if (imp != null) {
+                setPriority(MIMEMessageConverter.parseImportance(imp));
+            } else {
+                final String prioStr = getFirstHeader(MessageHeaders.HDR_X_PRIORITY);
+                if (prioStr != null) {
+                    setPriority(MIMEMessageConverter.parsePriority(prioStr));
+                }
             }
         }
         return priority;
@@ -1142,7 +1165,7 @@ public abstract class MailMessage extends MailPart {
      * @return <code>true</code> if priority is set; otherwise <code>false</code>
      */
     public boolean containsPriority() {
-        return b_priority || containsHeader(MessageHeaders.HDR_X_PRIORITY);
+        return b_priority || containsHeader(MessageHeaders.HDR_IMPORTANCE) || containsHeader(MessageHeaders.HDR_X_PRIORITY);
     }
 
     /**
@@ -1150,6 +1173,7 @@ public abstract class MailMessage extends MailPart {
      */
     public void removePriority() {
         priority = PRIORITY_NORMAL;
+        removeHeader(MessageHeaders.HDR_IMPORTANCE);
         removeHeader(MessageHeaders.HDR_X_PRIORITY);
         b_priority = false;
     }
@@ -1349,16 +1373,16 @@ public abstract class MailMessage extends MailPart {
     public Object clone() {
         final MailMessage clone = (MailMessage) super.clone();
         if (from != null) {
-            clone.from = new HashSet<InternetAddress>(from);
+            clone.from = new LinkedHashSet<InternetAddress>(from);
         }
         if (to != null) {
-            clone.to = new HashSet<InternetAddress>(to);
+            clone.to = new LinkedHashSet<InternetAddress>(to);
         }
         if (cc != null) {
-            clone.cc = new HashSet<InternetAddress>(cc);
+            clone.cc = new LinkedHashSet<InternetAddress>(cc);
         }
         if (bcc != null) {
-            clone.bcc = new HashSet<InternetAddress>(bcc);
+            clone.bcc = new LinkedHashSet<InternetAddress>(bcc);
         }
         if (receivedDate != null) {
             clone.receivedDate = new Date(receivedDate.getTime());
