@@ -28,7 +28,7 @@
  *    http://www.open-xchange.com/EN/developer/. The contributing author shall be
  *    given Attribution for the derivative code and a license granting use.
  *
- *     Copyright (C) 2004-2006 Open-Xchange, Inc.
+ *     Copyright (C) 2004-2010 Open-Xchange, Inc.
  *     Mail: info@open-xchange.com
  *
  *
@@ -74,32 +74,105 @@ public final class HeaderName implements Serializable, Cloneable, Comparable<Hea
         CACHE.put("Bcc", HeaderName.valueOf("Bcc"));
         CACHE.put("Cc", HeaderName.valueOf("Cc"));
         CACHE.put("Content-Disposition", HeaderName.valueOf("Content-Disposition"));
-        CACHE.put("Content-ID", HeaderName.valueOf("Content-ID"));
+        {
+            final HeaderName headerName = HeaderName.valueOf("Content-ID");
+            CACHE.put("Content-ID", headerName);
+            CACHE.put("Content-Id", headerName);
+        }
         CACHE.put("Content-Transfer-Encoding", HeaderName.valueOf("Content-Transfer-Encoding"));
         CACHE.put("Content-Type", HeaderName.valueOf("Content-Type"));
         CACHE.put("Date", HeaderName.valueOf("Date"));
         CACHE.put("Disposition-Notification-To", HeaderName.valueOf("Disposition-Notification-To"));
         CACHE.put("Content-Disposition", HeaderName.valueOf("Content-Disposition"));
         CACHE.put("From", HeaderName.valueOf("From"));
+        CACHE.put("ReplyTo", HeaderName.valueOf("ReplyTo"));
         CACHE.put("In-Reply-To", HeaderName.valueOf("In-Reply-To"));
-        CACHE.put("Message-ID", HeaderName.valueOf("Message-ID"));
+        {
+            final HeaderName headerName = HeaderName.valueOf("Message-ID");
+            CACHE.put("Message-ID", headerName);
+            CACHE.put("Message-Id", headerName);
+        }
         CACHE.put("MIME-Version", HeaderName.valueOf("MIME-Version"));
         CACHE.put("Organization", HeaderName.valueOf("Organization"));
         CACHE.put("Received", HeaderName.valueOf("Received"));
         CACHE.put("References", HeaderName.valueOf("References"));
         CACHE.put("Reply-To", HeaderName.valueOf("Reply-To"));
         CACHE.put("Subject", HeaderName.valueOf("Subject"));
+        CACHE.put("Sender", HeaderName.valueOf("Sender"));
         CACHE.put("To", HeaderName.valueOf("To"));
         CACHE.put("X-Mailer", HeaderName.valueOf("X-Mailer"));
         CACHE.put("X-OX-Marker", HeaderName.valueOf("X-OX-Marker"));
         CACHE.put("X-OXMsgref", HeaderName.valueOf("X-OXMsgref"));
         CACHE.put("X-Priority", HeaderName.valueOf("X-Priority"));
         CACHE.put("X-Spam-Flag", HeaderName.valueOf("X-Spam-Flag"));
+        CACHE.put("Return-Path", HeaderName.valueOf("Return-Path"));
+        CACHE.put("X-OX-VCard-Attached", HeaderName.valueOf("X-OX-VCard-Attached"));
+        CACHE.put("X-OX-Notification", HeaderName.valueOf("X-OX-Notification"));
         /*
          * User flags
          */
         CACHE.put("$Forwarded", new HeaderName("$Forwarded"));
         CACHE.put("$MDNSent", new HeaderName("$MDNSent"));
+        CACHE.put("NonJunk", new HeaderName("NonJunk"));
+        /*
+         * Some charsets
+         */
+        {
+            final HeaderName headerName = new HeaderName("us-ascii");
+            CACHE.put("us-ascii", headerName);
+            CACHE.put("US-ASCII", headerName);
+        }
+        {
+            final HeaderName headerName = new HeaderName("utf-8");
+            CACHE.put("utf-8", headerName);
+            CACHE.put("UTF-8", headerName);
+        }
+        {
+            final HeaderName headerName = new HeaderName("iso-8859-1");
+            CACHE.put("iso-8859-1", headerName);
+            CACHE.put("ISO-8859-1", headerName);
+        }
+        {
+            final HeaderName headerName = new HeaderName("windows-1258");
+            CACHE.put("windows-1258", headerName);
+            CACHE.put("WINDOWS-1258", headerName);
+        }
+    }
+
+    /**
+     * Initializes header names from specified character sequences.
+     * <p>
+     * Yields significantly better space and time performance by caching frequently requested headers.
+     * 
+     * @param names The character sequences
+     * @return The header names
+     */
+    public static HeaderName[] valuesOf(final CharSequence... names) {
+        if (null == names) {
+            return null;
+        }
+        final HeaderName[] ret = new HeaderName[names.length];
+        for (int i = 0; i < ret.length; i++) {
+            ret[i] = valueOf(names[i]);
+        }
+        return ret;
+    }
+
+    /**
+     * Initializes a new header name from specified character sequence.
+     * <p>
+     * Yields significantly better space and time performance by caching frequently requested headers.
+     * 
+     * @param s The character sequence
+     * @return The new header name.
+     */
+    public static HeaderName valueOf(final CharSequence s) {
+        final String key = s.toString();
+        final HeaderName cached = CACHE.get(key);
+        if (cached == null) {
+            return new HeaderName(key);
+        }
+        return cached;
     }
 
     private final String s;
@@ -127,23 +200,6 @@ public final class HeaderName implements Serializable, Cloneable, Comparable<Hea
         }
     }
 
-    /**
-     * Initializes a new header name from specified character sequence.
-     * <p>
-     * Yields significantly better space and time performance by caching frequently requested headers.
-     * 
-     * @param s The character sequence
-     * @return The new header name.
-     */
-    public static HeaderName valueOf(final CharSequence s) {
-        final String key = s.toString();
-        final HeaderName cached = CACHE.get(key);
-        if (cached == null) {
-            return new HeaderName(key);
-        }
-        return cached;
-    }
-
     @Override
     public boolean equals(final Object other) {
         if (other == this) {
