@@ -91,21 +91,21 @@ public class MIMEMailException extends MailException {
          */
         LOGIN_FAILED("There was an issue in authenticating your E-Mail password. This may be because of a recent password change. " + "To continue please logout now and then log back in with your most current password. (server=%1$s | user=%2$s)", Category.PERMISSION, 1000),
         /**
-         * Wrong or missing login data to access server %1$s. Error message from server: %2$s
+         * Wrong or missing login data to access mail server %1$s. Error message from mail server: %2$s
          */
-        INVALID_CREDENTIALS("Wrong or missing login data to access server %1$s. Error message from server: %2$s", Category.PERMISSION, 1001),
+        INVALID_CREDENTIALS("Wrong or missing login data to access mail server %1$s. Error message from mail server: %2$s", Category.PERMISSION, 1001),
         /**
-         * Wrong or missing login data to access server %1$s with login %2$s (user=%3$s, context=%4$s). Error message from server: %5$s
+         * Wrong or missing login data to access mail server %1$s with login %2$s (user=%3$s, context=%4$s). Error message from mail server: %5$s
          */
-        INVALID_CREDENTIALS_EXT("Wrong or missing login data to access server %1$s with login %2$s (user=%3$s, context=%4$s). Error message from server: %5$s", Category.PERMISSION, INVALID_CREDENTIALS.detailNumber),
+        INVALID_CREDENTIALS_EXT("Wrong or missing login data to access mail server %1$s with login %2$s (user=%3$s, context=%4$s). Error message from mail server: %5$s", Category.PERMISSION, INVALID_CREDENTIALS.detailNumber),
         /**
          * Mail folder "%1$s" could not be found.
          */
         FOLDER_NOT_FOUND("Mail folder \"%1$s\" could not be found.", Category.CODE_ERROR, 1002),
         /**
-         * Mail folder "%1$s" could not be found on server %2$s with login %3$s (user=%4$s, context=%5$s).
+         * Mail folder "%1$s" could not be found on mail server %2$s with login %3$s (user=%4$s, context=%5$s).
          */
-        FOLDER_NOT_FOUND_EXT("Mail folder \"%1$s\" could not be found on server %2$s with login %3$s (user=%4$s, context=%5$s).", Category.CODE_ERROR, FOLDER_NOT_FOUND.detailNumber),
+        FOLDER_NOT_FOUND_EXT("Mail folder \"%1$s\" could not be found on mail server %2$s with login %3$s (user=%4$s, context=%5$s).", Category.CODE_ERROR, FOLDER_NOT_FOUND.detailNumber),
         /**
          * Folder "%1$s" has been closed due to some reason.<br>
          * Probably your request took too long.
@@ -116,10 +116,10 @@ public class MIMEMailException extends MailException {
          */
         FOLDER_CLOSED("Folder \"%1$s\" is closed due to some reason.\nProbably your request took too long", Category.CODE_ERROR, 1003),
         /**
-         * Folder "%1$s" has been closed on server %2$s with login %3$s (user=%4$s, context=%5$s) due to some reason.<br>
+         * Folder "%1$s" has been closed on mail server %2$s with login %3$s (user=%4$s, context=%5$s) due to some reason.<br>
          * Probably your request took too long.
          */
-        FOLDER_CLOSED_EXT("Folder \"%1$s\" has been closed on server %2$s with login %3$s (user=%4$s, context=%5$s) due to some reason.\nProbably your request took too long.", Category.CODE_ERROR, FOLDER_CLOSED.detailNumber),
+        FOLDER_CLOSED_EXT("Folder \"%1$s\" has been closed on mail server %2$s with login %3$s (user=%4$s, context=%5$s) due to some reason.\nProbably your request took too long.", Category.CODE_ERROR, FOLDER_CLOSED.detailNumber),
         /**
          * Illegal write attempt: %1$s
          * <p>
@@ -162,9 +162,9 @@ public class MIMEMailException extends MailException {
          */
         READ_ONLY_FOLDER("An attempt was made to open a read-only folder with read-write \"%1$s\"", Category.PERMISSION, 1010),
         /**
-         * An attempt was made to open a read-only folder with read-write "%1$s" on server %2$s with login %3$s (user=%4$s, context=%5$s)
+         * An attempt was made to open a read-only folder with read-write "%1$s" on mail server %2$s with login %3$s (user=%4$s, context=%5$s)
          */
-        READ_ONLY_FOLDER_EXT("An attempt was made to open a read-only folder with read-write \"%1$s\" on server %2$s with login %3$s (user=%4$s, context=%5$s)", Category.PERMISSION, 1010),
+        READ_ONLY_FOLDER_EXT("An attempt was made to open a read-only folder with read-write \"%1$s\" on mail server %2$s with login %3$s (user=%4$s, context=%5$s)", Category.PERMISSION, 1010),
         /**
          * Invalid search expression: %1$s
          */
@@ -186,9 +186,9 @@ public class MIMEMailException extends MailException {
          */
         STORE_CLOSED("Store already closed: %1$s", Category.CODE_ERROR, 1014),
         /**
-         * Connection closed to server %1$s with login %2$s (user=%3$s, context=%4$s): %5$s
+         * Connection closed to mail server %1$s with login %2$s (user=%3$s, context=%4$s): %5$s
          */
-        STORE_CLOSED_EXT("Connection closed to server %1$s with login %2$s (user=%3$s, context=%4$s): %5$s", STORE_CLOSED.category, STORE_CLOSED.detailNumber),
+        STORE_CLOSED_EXT("Connection closed to mail server %1$s with login %2$s (user=%3$s, context=%4$s): %5$s", STORE_CLOSED.category, STORE_CLOSED.detailNumber),
         /**
          * Could not bind mail connection to local port %1$s
          * <p>
@@ -272,8 +272,16 @@ public class MIMEMailException extends MailException {
         /**
          * Message cannot be displayed.
          */
-        MESSAGE_NOT_DISPLAYED("Message cannot be displayed.", Category.SUBSYSTEM_OR_SERVICE_DOWN, 1029);
-
+        MESSAGE_NOT_DISPLAYED("Message cannot be displayed.", Category.SUBSYSTEM_OR_SERVICE_DOWN, 1029),
+        /**
+         * Wrong or missing login data to access mail transport server %1$s. Error message from mail transport server: %2$s
+         */
+        TRANSPORT_INVALID_CREDENTIALS("Wrong or missing login data to access mail transport server %1$s. Error message from mail transport server: %2$s", Category.PERMISSION, 1030),
+        /**
+         * Wrong or missing login data to access mail transport server %1$s with login %2$s (user=%3$s, context=%4$s). Error message from mail transport server: %5$s
+         */
+        TRANSPORT_INVALID_CREDENTIALS_EXT("Wrong or missing login data to access mail transport server %1$s with login %2$s (user=%3$s, context=%4$s). Error message from mail transport server: %5$s", Category.PERMISSION, TRANSPORT_INVALID_CREDENTIALS.detailNumber);
+        
         private final String message;
 
         private final int detailNumber;
@@ -299,26 +307,26 @@ public class MIMEMailException extends MailException {
         }
     }
 
-    protected MIMEMailException(final AbstractOXException cause) {
+    public MIMEMailException(final AbstractOXException cause) {
         super(cause);
     }
 
-    protected MIMEMailException(final Code code, final Object... messageArgs) {
+    public MIMEMailException(final Code code, final Object... messageArgs) {
         this(code, null, messageArgs);
     }
 
-    protected MIMEMailException(final Code code, final Throwable cause, final Object... messageArgs) {
+    public MIMEMailException(final Code code, final Throwable cause, final Object... messageArgs) {
         super(EnumComponent.MAIL, code.getCategory(), code.getNumber(), code.getMessage(), cause);
         super.setMessageArgs(messageArgs);
     }
 
     private static final transient Object[] EMPTY_ARGS = new Object[0];
 
-    protected MIMEMailException(final Code code) {
+    public MIMEMailException(final Code code) {
         this(code, EMPTY_ARGS);
     }
 
-    protected MIMEMailException(final Component component, final Category category, final int detailNumber, final String message, final Throwable cause) {
+    public MIMEMailException(final Component component, final Category category, final int detailNumber, final String message, final Throwable cause) {
         super(component, category, detailNumber, message, cause);
     }
 
