@@ -56,6 +56,7 @@ import java.io.IOException;
 import java.io.InputStream;
 import java.io.UnsupportedEncodingException;
 import java.sql.Connection;
+import java.util.ArrayList;
 import java.util.Date;
 import java.util.HashSet;
 import java.util.Iterator;
@@ -69,10 +70,10 @@ import javax.activation.DataSource;
 import javax.activation.FileDataSource;
 import javax.mail.BodyPart;
 import javax.mail.Flags;
+import javax.mail.Message.RecipientType;
 import javax.mail.MessagingException;
 import javax.mail.Multipart;
 import javax.mail.Part;
-import javax.mail.Message.RecipientType;
 import javax.mail.internet.AddressException;
 import javax.mail.internet.InternetAddress;
 import javax.mail.internet.InternetHeaders;
@@ -97,6 +98,7 @@ import com.openexchange.groupware.container.FolderObject;
 import com.openexchange.groupware.contexts.Context;
 import com.openexchange.groupware.i18n.MailStrings;
 import com.openexchange.groupware.ldap.User;
+import com.openexchange.groupware.ldap.UserException;
 import com.openexchange.groupware.ldap.UserStorage;
 import com.openexchange.groupware.userconfiguration.UserConfigurationStorage;
 import com.openexchange.i18n.tools.StringHelper;
@@ -110,8 +112,8 @@ import com.openexchange.mail.dataobjects.MailPart;
 import com.openexchange.mail.dataobjects.compose.ComposeType;
 import com.openexchange.mail.dataobjects.compose.ComposedMailMessage;
 import com.openexchange.mail.dataobjects.compose.ComposedMailPart;
-import com.openexchange.mail.dataobjects.compose.ReferencedMailPart;
 import com.openexchange.mail.dataobjects.compose.ComposedMailPart.ComposedPartType;
+import com.openexchange.mail.dataobjects.compose.ReferencedMailPart;
 import com.openexchange.mail.mime.ContentDisposition;
 import com.openexchange.mail.mime.ContentType;
 import com.openexchange.mail.mime.MIMEMailException;
@@ -127,6 +129,7 @@ import com.openexchange.mail.usersetting.UserSettingMail;
 import com.openexchange.mail.usersetting.UserSettingMailStorage;
 import com.openexchange.mailaccount.MailAccountException;
 import com.openexchange.mailaccount.MailAccountStorageService;
+import com.openexchange.server.ServiceException;
 import com.openexchange.server.impl.DBPool;
 import com.openexchange.server.impl.Version;
 import com.openexchange.server.services.ServerServiceRegistry;
@@ -139,6 +142,7 @@ import com.openexchange.tools.versit.VersitDefinition;
 import com.openexchange.tools.versit.VersitObject;
 import com.openexchange.tools.versit.converter.ConverterException;
 import com.openexchange.tools.versit.converter.OXContainerConverter;
+import com.openexchange.user.UserService;
 
 /**
  * {@link MIMEMessageFiller} - Provides basic methods to fills an instance of {@link MimeMessage} with headers/contents given through an
@@ -198,7 +202,7 @@ public class MIMEMessageFiller {
      * @param ctx The context
      */
     public MIMEMessageFiller(final Session session, final Context ctx) {
-        this(session, ctx, null);
+        this(session, ctx, UserSettingMailStorage.getInstance().getUserSettingMail(session.getUserId(), ctx));
     }
 
     /**
@@ -212,7 +216,7 @@ public class MIMEMessageFiller {
         super();
         this.session = session;
         this.ctx = ctx;
-        this.usm = usm == null ? UserSettingMailStorage.getInstance().getUserSettingMail(session.getUserId(), ctx) : usm;
+        this.usm = usm;
     }
 
     /*
@@ -297,12 +301,13 @@ public class MIMEMessageFiller {
              */
             mimeMessage.setHeader(MessageHeaders.HDR_ORGANIZATION, org.toString());
         }
+        mimeMessage.setHeader("X-Originating-IP", session.getLocalIp());
     }
 
     private static final String[] SUPPRESS_HEADERS =
         {
             MessageHeaders.HDR_X_OX_VCARD, MessageHeaders.HDR_X_OXMSGREF, MessageHeaders.HDR_X_OX_MARKER,
-            MessageHeaders.HDR_X_OX_NOTIFICATION, MessageHeaders.HDR_X_PRIORITY, MessageHeaders.HDR_X_MAILER };
+            MessageHeaders.HDR_X_OX_NOTIFICATION, MessageHeaders.HDR_IMPORTANCE, MessageHeaders.HDR_X_PRIORITY, MessageHeaders.HDR_X_MAILER };
 
     /**
      * Sets necessary headers in specified MIME message: <code>From</code>/ <code>Sender</code>, <code>To</code>, <code>Cc</code>,
@@ -356,11 +361,24 @@ public class MIMEMessageFiller {
                     LOG.debug(e.getMessage(), e);
                 }
             }
+            final List<InternetAddress> aliases;
+            try {
+                UserService userService = ServerServiceRegistry.getInstance().getService(UserService.class, true);
+                User user = userService.getUser(session.getUserId(), ctx);
+                aliases = new ArrayList<InternetAddress>();
+                for (String alias : user.getAliases()) {
+                    aliases.add(new QuotedInternetAddress(alias));
+                }
+            } catch (ServiceException e) {
+                throw new MailException(e);
+            } catch (UserException e) {
+                throw new MailException(e);
+            }
             /*
              * Taken from RFC 822 section 4.4.2: In particular, the "Sender" field MUST be present if it is NOT the same as the "From"
              * Field.
              */
-            if (sender != null && !from.equals(sender)) {
+            if (sender != null && !from.equals(sender) && !aliases.contains(from)) {
                 mimeMessage.setSender(sender);
             }
         }
@@ -481,7 +499,15 @@ public class MIMEMessageFiller {
         /*
          * Set priority
          */
-        mimeMessage.setHeader(MessageHeaders.HDR_X_PRIORITY, String.valueOf(mail.getPriority()));
+        final int priority = mail.getPriority();
+        mimeMessage.setHeader(MessageHeaders.HDR_X_PRIORITY, String.valueOf(priority));
+        if (MailMessage.PRIORITY_NORMAL == priority) {
+            mimeMessage.setHeader(MessageHeaders.HDR_IMPORTANCE, "Medium");
+        } else if (priority > MailMessage.PRIORITY_NORMAL) {
+            mimeMessage.setHeader(MessageHeaders.HDR_IMPORTANCE, "Low");
+        } else {
+            mimeMessage.setHeader(MessageHeaders.HDR_IMPORTANCE, "High");
+        }
         /*
          * Headers
          */
@@ -1247,8 +1273,6 @@ public class MIMEMessageFiller {
         return html;
     }
 
-    private static final String IMG_PAT = "<img src=\"cid:#1#\">";
-
     /**
      * Processes referenced local images, inserts them as inlined html images and adds their binary data to parental instance of <code>
 	 * {@link Multipart}</code>.
@@ -1286,15 +1310,13 @@ public class MIMEMessageFiller {
                          * Anyway, replace image tag
                          */
                         tmp.setLength(0);
-                        mr.appendLiteralReplacement(sb, IMG_PAT.replaceFirst(
-                            "#1#",
-                            tmp.append(id).append('@').append("notfound").toString()));
+                        mr.appendLiteralReplacement(sb, m.group().replaceFirst("(?i)src=\"[^\"]*\"", "src=\"cid:" + tmp.append(id).append('@').append("notfound").toString() + "\""));
                         continue;
                     }
                 } else {
                     ImageData imageData = imageService.getImageData(session, id);
                     if (imageData == null) {
-                        imageData = imageService.getImageData(session.getContextId(), id);
+                        imageData = imageService.getImageData(session, id);
                     }
                     if (imageData == null) {
                         if (LOG.isWarnEnabled()) {
@@ -1305,9 +1327,7 @@ public class MIMEMessageFiller {
                          * Anyway, replace image tag
                          */
                         tmp.setLength(0);
-                        mr.appendLiteralReplacement(sb, IMG_PAT.replaceFirst(
-                            "#1#",
-                            tmp.append(id).append('@').append("notfound").toString()));
+                        mr.appendLiteralReplacement(sb, m.group().replaceFirst("(?i)src=\"[^\"]*\"", "src=\"cid:" + tmp.append(id).append('@').append("notfound").toString() + "\""));
                         continue;
                     }
                     try {
@@ -1315,9 +1335,7 @@ public class MIMEMessageFiller {
                     } catch (final MailException e) {
                         if (MailException.Code.IMAGE_ATTACHMENT_NOT_FOUND.getNumber() == e.getDetailNumber()) {
                             tmp.setLength(0);
-                            mr.appendLiteralReplacement(sb, IMG_PAT.replaceFirst(
-                                "#1#",
-                                tmp.append(id).append('@').append("notfound").toString()));
+                            mr.appendLiteralReplacement(sb, m.group().replaceFirst("(?i)src=\"[^\"]*\"", "src=\"cid:" + tmp.append(id).append('@').append("notfound").toString() + "\""));
                             continue;
                         }
                         throw e;
@@ -1333,10 +1351,8 @@ public class MIMEMessageFiller {
                     msgFiller.uploadFileIDs.add(id);
                     appendBodyPart = true;
                 }
-                /*
-                 * Replace image tag
-                 */
-                mr.appendLiteralReplacement(sb, IMG_PAT.replaceFirst("#1#", processLocalImage(imageProvider, id, appendBodyPart, tmp, mp)));
+                mr.appendLiteralReplacement(sb, m.group().replaceFirst("(?i)src=\"[^\"]*\"", "src=\"cid:" + processLocalImage(imageProvider, id, appendBodyPart, tmp, mp) + "\""));
+                //mr.appendLiteralReplacement(sb, IMG_PAT.replaceFirst("#1#", processLocalImage(imageProvider, id, appendBodyPart, tmp, mp)));
             } while (m.find());
         }
         mr.appendTail(sb);
