@@ -28,7 +28,7 @@
  *    http://www.open-xchange.com/EN/developer/. The contributing author shall be
  *    given Attribution for the derivative code and a license granting use.
  *
- *     Copyright (C) 2004-2006 Open-Xchange, Inc.
+ *     Copyright (C) 2004-2010 Open-Xchange, Inc.
  *     Mail: info@open-xchange.com
  *
  *
@@ -53,7 +53,10 @@ import static com.openexchange.mail.text.HTMLProcessing.getConformHTML;
 import static com.openexchange.mail.text.HTMLProcessing.htmlFormat;
 import java.io.IOException;
 import java.io.UnsupportedEncodingException;
+import java.text.DateFormat;
+import java.util.Date;
 import java.util.Locale;
+import java.util.TimeZone;
 import javax.mail.Part;
 import javax.mail.internet.InternetAddress;
 import com.openexchange.mail.MailException;
@@ -86,6 +89,36 @@ public final class MimeProcessingUtility {
         super();
     }
 
+    /**
+     * Formats specified date in given style with given locale and time zone.
+     * 
+     * @param date The date to format
+     * @param style The style to use
+     * @param locale The locale
+     * @param timeZone The time zone
+     * @return The formatted date
+     */
+    static final String getFormattedDate(final Date date, final int style, final Locale locale, final TimeZone timeZone) {
+        final DateFormat dateFormat = DateFormat.getDateInstance(style, locale);
+        dateFormat.setTimeZone(timeZone);
+        return dateFormat.format(date);
+    }
+
+    /**
+     * Formats specified time in given style with given locale and time zone.
+     * 
+     * @param date The time to format
+     * @param style The style to use
+     * @param locale The locale
+     * @param timeZone The time zone
+     * @return The formatted time
+     */
+    static final String getFormattedTime(final Date date, final int style, final Locale locale, final TimeZone timeZone) {
+        final DateFormat dateFormat = DateFormat.getTimeInstance(style, locale);
+        dateFormat.setTimeZone(timeZone);
+        return dateFormat.format(date);
+    }
+
     /**
      * Checks if given part's disposition is inline; meaning more likely a regular message body than an attachment.
      * 
@@ -258,9 +291,8 @@ public final class MimeProcessingUtility {
      * @param contentType Current text's content type
      * @param text The text content
      * @param textBuilder The text builder to append to
-     * @throws IOException
      */
-    static void appendRightVersion(final ContentType rootType, final ContentType contentType, final String text, final StringBuilder textBuilder) throws IOException {
+    static void appendRightVersion(final ContentType rootType, final ContentType contentType, final String text, final StringBuilder textBuilder) {
         if (rootType.getBaseType().equalsIgnoreCase(contentType.getBaseType())) {
             textBuilder.append(text);
         } else if (rootType.startsWith(CT_TEXT_HTM)) {
