@@ -166,6 +166,10 @@ public final class StructureMailMessageParser {
      * +++++++++++++++++++ MEMBERS +++++++++++++++++++
      */
 
+    private boolean parseTNEFParts;
+
+    private boolean parseUUEncodedParts;
+
     private boolean stop;
 
     private boolean multipartDetected;
@@ -191,6 +195,28 @@ public final class StructureMailMessageParser {
         return this;
     }
 
+    /**
+     * Sets whether TNEF parts should be parsed or not.
+     * 
+     * @param parseTNEFParts <code>true</code> to parse TNEF parts; otherwise <code>false</code>
+     * @return This parser with new behavior applied
+     */
+    public StructureMailMessageParser setParseTNEFParts(final boolean parseTNEFParts) {
+        this.parseTNEFParts = parseTNEFParts;
+        return this;
+    }
+
+    /**
+     * Sets whether UUEncoded parts should be parsed or not.
+     * 
+     * @param parseUUEncodedParts <code>true</code> to parse UUEncoded parts; otherwise <code>false</code>
+     * @return This parser with new behavior applied
+     */
+    public StructureMailMessageParser setParseUUEncodedParts(final boolean parseUUEncodedParts) {
+        this.parseUUEncodedParts = parseUUEncodedParts;
+        return this;
+    }
+
     /**
      * Resets this parser and returns itself
      * 
@@ -273,32 +299,55 @@ public final class StructureMailMessageParser {
         if (isText(lcct)) {
             if (isInline) {
                 final String content = readContent(mailPart, contentType);
-                final UUEncodedMultiPart uuencodedMP = new UUEncodedMultiPart(content);
-                if (uuencodedMP.isUUEncoded()) {
+                final UUEncodedMultiPart uuencodedMP = parseUUEncodedParts ? new UUEncodedMultiPart(content) : null;
+                if (parseUUEncodedParts && uuencodedMP.isUUEncoded()) {
                     /*
                      * UUEncoded content detected. Handle normal text.
                      */
-                    if (!handler.handleInlineUUEncodedPlainText(
-                        uuencodedMP.getCleanText(),
-                        contentType,
-                        uuencodedMP.getCleanText().length(),
-                        filename,
-                        getSequenceId(prefix, partCount))) {
-                        stop = true;
-                        return;
-                    }
-                    /*
-                     * Now handle uuencoded attachments
-                     */
                     final int count = uuencodedMP.getCount();
-                    for (int a = 0; a < count; a++) {
+                    if (count > 0) {
                         /*
-                         * Increment part count by 1
+                         * Handle as a multipart
                          */
-                        partCount++;
-                        if (!handler.handleInlineUUEncodedAttachment(uuencodedMP.getBodyPart(a), StructureMailMessageParser.getSequenceId(
-                            prefix,
-                            partCount))) {
+                        if (!handler.handleMultipartStart(new ContentType("multipart/mixed"), count, prefix)) {
+                            stop = true;
+                            return;
+                        }
+                        if (!handler.handleInlineUUEncodedPlainText(
+                            uuencodedMP.getCleanText(),
+                            contentType,
+                            uuencodedMP.getCleanText().length(),
+                            filename,
+                            getSequenceId(prefix, partCount))) {
+                            stop = true;
+                            return;
+                        }
+                        /*
+                         * Now handle uuencoded attachments
+                         */
+                        for (int a = 0; a < count; a++) {
+                            /*
+                             * Increment part count by 1
+                             */
+                            partCount++;
+                            if (!handler.handleInlineUUEncodedAttachment(uuencodedMP.getBodyPart(a), StructureMailMessageParser.getSequenceId(
+                                prefix,
+                                partCount))) {
+                                stop = true;
+                                return;
+                            }
+                        }
+                        if (!handler.handleMultipartEnd()) {
+                            stop = true;
+                            return;
+                        }
+                    } else {
+                        if (!handler.handleInlineUUEncodedPlainText(
+                            uuencodedMP.getCleanText(),
+                            contentType,
+                            uuencodedMP.getCleanText().length(),
+                            filename,
+                            getSequenceId(prefix, partCount))) {
                             stop = true;
                             return;
                         }
@@ -336,7 +385,7 @@ public final class StructureMailMessageParser {
             if (!mailPart.containsSequenceId()) {
                 mailPart.setSequenceId(mpId);
             }
-            if (!handler.handleMultipartStart(mailPart, count, mpId)) {
+            if (!handler.handleMultipartStart(mailPart.getContentType(), count, mpId)) {
                 stop = true;
                 return;
             }
@@ -351,7 +400,7 @@ public final class StructureMailMessageParser {
                 final MailPart enclosedContent = mailPart.getEnclosedMailPart(i);
                 parseMailContent(enclosedContent, handler, mpPrefix, i + 1);
             }
-            if (!handler.handleMultipartEnd(mailPart, count, mpId)) {
+            if (!handler.handleMultipartEnd()) {
                 stop = true;
                 return;
             }
@@ -370,7 +419,7 @@ public final class StructureMailMessageParser {
                     return;
                 }
             }
-        } else if (TNEFUtils.isTNEFMimeType(lcct)) {
+        } else if (parseTNEFParts && TNEFUtils.isTNEFMimeType(lcct)) {
             try {
                 /*
                  * Here go with TNEF encoded messages. Since TNEF library is based on JavaMail API we are forced to use JavaMail-specific
