@@ -104,10 +104,9 @@ import com.openexchange.mail.structure.StructureMailMessageParser;
 import com.openexchange.mail.utils.CharsetDetector;
 import com.openexchange.mail.utils.MessageUtility;
 import com.openexchange.mail.uuencode.UUEncodedPart;
-import com.openexchange.tools.ByteBuffers;
 import com.openexchange.tools.TimeZoneUtils;
-import com.openexchange.tools.encoding.Charsets;
 import com.openexchange.tools.regex.MatcherReplacer;
+import com.openexchange.tools.stream.UnsynchronizedByteArrayInputStream;
 import com.openexchange.tools.stream.UnsynchronizedByteArrayOutputStream;
 
 /**
@@ -122,6 +121,13 @@ public final class MIMEStructureHandler implements StructureHandler {
      */
     private static final org.apache.commons.logging.Log LOG = org.apache.commons.logging.LogFactory.getLog(MIMEStructureHandler.class);
 
+    private static final MailDateFormat MAIL_DATE_FORMAT;
+
+    static {
+        MAIL_DATE_FORMAT = new MailDateFormat();
+        MAIL_DATE_FORMAT.setTimeZone(TimeZoneUtils.getTimeZone("GMT"));
+    }
+
     /*-
      * #####################################################################################
      */
@@ -289,13 +295,13 @@ public final class MIMEStructureHandler implements StructureHandler {
         addBodyPart(size, new InputStreamProvider() {
 
             public InputStream getInputStream() throws IOException {
-                return ByteBuffers.newUnsynchronizedInputStream(Charsets.UTF_8.encode(decodedTextContent));
+                return new UnsynchronizedByteArrayInputStream(decodedTextContent.getBytes("UTF-8"));
             }
         }, contentType, id, headers.entrySet().iterator());
         return true;
     }
 
-    public boolean handleMultipartStart(final MailPart mp, final int bodyPartCount, final String id) throws MailException {
+    public boolean handleMultipartStart(final ContentType contentType, final int bodyPartCount, final String id) throws MailException {
         try {
             // Increment
             if (++multipartCount > 1) { // Enqueue nested multipart
@@ -309,8 +315,24 @@ public final class MIMEStructureHandler implements StructureHandler {
                 currentBodyObject = null;
                 // Add multipart's headers
                 final Map<String, String> headers = new HashMap<String, String>(1);
-                headers.put(CONTENT_TYPE, mp.getContentType().toString());
+                headers.put(CONTENT_TYPE, contentType.toString());
                 generateHeadersObject(headers.entrySet().iterator(), currentMailObject);
+            } else {
+                /*
+                 * Ensure proper content type
+                 */
+                final JSONObject headers = currentMailObject.getJSONObject(KEY_HEADERS);
+                if (null == headers) {
+                    // Add multipart's headers
+                    final Map<String, String> headersMap = new HashMap<String, String>(1);
+                    headersMap.put(CONTENT_TYPE, contentType.toString());
+                    generateHeadersObject(headersMap.entrySet().iterator(), currentMailObject);
+                } else {
+                    // Set content type in existing headers
+                    headers.put(CONTENT_TYPE, generateParameterizedHeader(
+                        contentType,
+                        contentType.getBaseType().toLowerCase(Locale.ENGLISH)));
+                }
             }
             return true;
         } catch (final JSONException e) {
@@ -318,7 +340,7 @@ public final class MIMEStructureHandler implements StructureHandler {
         }
     }
 
-    public boolean handleMultipartEnd(final MailPart mp, final int bodyPartCount, final String id) throws MailException {
+    public boolean handleMultipartEnd() throws MailException {
         // Decrement
         if (--multipartCount > 0) { // Dequeue nested multipart
             // Dequeue
@@ -597,13 +619,6 @@ public final class MIMEStructureHandler implements StructureHandler {
             HeaderName.valueOf("Resent-Sender"),
             HeaderName.valueOf("Disposition-Notification-To")));
 
-    private static final MailDateFormat MAIL_DATE_FORMAT;
-
-    static {
-        MAIL_DATE_FORMAT = new MailDateFormat();
-        MAIL_DATE_FORMAT.setTimeZone(TimeZoneUtils.getTimeZone("GMT"));
-    }
-
     private JSONObject generateHeadersObject(final Iterator<Entry<String, String>> iter, final JSONObject parent) throws MailException {
         try {
             final JSONObject hdrObject = new JSONObject();
@@ -694,15 +709,23 @@ public final class MIMEStructureHandler implements StructureHandler {
                 paramListJsonObject.put(paramName.toLowerCase(Locale.ENGLISH), parameterizedHeader.getParameter(paramName));
             }
         }
-        parameterJsonObject.put("params", paramListJsonObject);
+        if (paramListJsonObject.length() > 0) {
+            parameterJsonObject.put("params", paramListJsonObject);
+        }
         return parameterJsonObject;
     }
 
-    private JSONObject generateDateObject(final String date) throws JSONException {
+    private Object generateDateObject(final String date) throws JSONException {
+        if (null == date) {
+            return JSONObject.NULL;
+        }
         final JSONObject dateObject = new JSONObject();
         synchronized (MAIL_DATE_FORMAT) {
             try {
-                dateObject.put("utc", MAIL_DATE_FORMAT.parse(date).getTime());
+                final Date parsedDate = MAIL_DATE_FORMAT.parse(date);
+                if (null != parsedDate) {
+                    dateObject.put("utc", parsedDate.getTime());
+                }
             } catch (final ParseException pex) {
                 LOG.warn("Date string could not be parsed: " + date);
             }
@@ -809,7 +832,12 @@ public final class MIMEStructureHandler implements StructureHandler {
     private static String getCharset(final InputStreamProvider isp, final ContentType contentType) throws IOException {
         final String charset;
         if (contentType.startsWith(PRIMARY_TEXT)) {
-            charset = CharsetDetector.detectCharset(isp.getInputStream());
+            final String cs = contentType.getCharsetParameter();
+            if (!CharsetDetector.isValid(cs)) {
+                charset = CharsetDetector.detectCharset(isp.getInputStream());
+            } else {
+                charset = cs;
+            }
         } else {
             charset = MailProperties.getInstance().getDefaultMimeCharset();
         }
