@@ -328,8 +328,8 @@ public final class HTML2TextHandler implements HTMLHandler {
                 textBuilder.append(CRLF);
                 quoteText();
             } else if (tag.equalsIgnoreCase(TAG_P)) {
-                textBuilder.append(CRLF);
-                quoteText();
+                // textBuilder.append(CRLF);
+                // quoteText();
             } else if (tag.equalsIgnoreCase(TAG_OL) || tag.equalsIgnoreCase(TAG_UL)) {
                 // Starting list
                 textBuilder.append(CRLF);
