@@ -67,68 +67,24 @@ public class ReentrantLockPool<T> implements Pool<T>, Runnable {
 
     static final Log LOG = LogFactory.getLog(ReentrantLockPool.class);
 
-    /* --- Constants --- */
-
-    /**
-     * Possible actions if the pool is exhausted.
-     */
-    public static enum ExhaustedActions {
-        /**
-         * An error will be thrown if a maximum number of active objects is
-         * defined and the pool has no more idle objects.
-         */
-        FAIL,
-
-        /**
-         * The thread will have to wait if a maximum number of active objects is
-         * defined and the pool has no more idle objects. A maximum wait time
-         * can be defined.
-         */
-        BLOCK,
-
-        /**
-         * Allthough a maximum number of active objects is defined the pool will
-         * enlarge the number of pooled objects if they are needed.
-         */
-        GROW
-    }
-
-    /* --- Settings --- */
-
     private final int minIdle;
-
     private final int maxIdle;
-
     private final long maxIdleTime;
-
     private final int maxActive;
-
     private final long maxWait;
-
     private final long maxLifeTime;
-
-    private ExhaustedActions exhaustedAction;
-
+    private final ExhaustedActions exhaustedAction;
     private final boolean testOnActivate;
-
     private final boolean testOnDeactivate;
-
     private final boolean testOnIdle;
-
     private final boolean testThreads;
-
-    private boolean running = true;
-
     private final PoolImplData<T> data = new PoolImplData<T>();
-
     private final PoolableLifecycle<T> lifecycle;
-
     private final ReentrantLock lock = new ReentrantLock(true);
-
     private final Condition idleAvailable = lock.newCondition();
-
     private final long[] useTimes = new long[1000];
 
+    private boolean running = true;
     private int useTimePointer;
 
     /**
@@ -142,21 +98,22 @@ public class ReentrantLockPool<T> implements Pool<T>, Runnable {
     private long minUseTime = Long.MAX_VALUE;
 
     /**
-     * Number of broken objects. An object is broken if
-     * {@link PoolableLifecycle#activate(PooledData)},
-     * {@link PoolableLifecycle#deactivate(PooledData)} or
-     * {@link PoolableLifecycle#validate(PooledData)} return <code>false</code>.
+     * Number of broken objects. An object is broken if one of {@link PoolableLifecycle#activate(PooledData)},
+     * {@link PoolableLifecycle#deactivate(PooledData)} or {@link PoolableLifecycle#validate(PooledData)} returns <code>false</code>.
      */
     private int numBroken;
 
+    /**
+     * Keeps the time stamp when the last warning was logged. Warnings should only be logged once a minute.
+     */
+    private long lastWarning;
+
     /**
      * Default constructor.
-     * @param lifecycle Implementation of the interface for handling the life
-     * cycle of pooled objects.
+     * @param lifecycle Implementation of the interface for handling the life cycle of pooled objects.
      * @param config Configuration of the pool parameters.
      */
-    public ReentrantLockPool(final PoolableLifecycle<T> lifecycle,
-        final Config config) {
+    public ReentrantLockPool(PoolableLifecycle<T> lifecycle, Config config) {
         super();
         minIdle = Math.max(0, config.minIdle);
         maxIdle = config.maxIdle;
@@ -172,46 +129,18 @@ public class ReentrantLockPool<T> implements Pool<T>, Runnable {
         this.lifecycle = lifecycle;
         try {
             ensureMinIdle();
-        } catch (final PoolingException e) {
+        } catch (PoolingException e) {
             LOG.error("Problem while creating initial objects.", e);
         }
     }
 
-    /**
-     * @return the exhaustedAction
-     */
-    public ExhaustedActions getExhaustedAction() {
-        return exhaustedAction;
-    }
-
-    /**
-     * @param exhaustedAction the exhaustedAction to set
-     */
-    public void setExhaustedAction(final ExhaustedActions exhaustedAction) {
-        this.exhaustedAction = exhaustedAction;
-    }
-
-    /**
-     * @return the lifecycle
-     */
     protected final PoolableLifecycle<T> getLifecycle() {
         return lifecycle;
     }
 
-    /**
-     * @return the testThreads
-     */
-    public boolean isTestThreads() {
-        return testThreads;
-    }
-
-    /**
-     * {@inheritDoc}
-     */
-    public void back(final T pooled) throws PoolingException {
+    public void back(T pooled) throws PoolingException {
         if (null == pooled) {
-            throw new PoolingException(
-                "A null reference was returned to pool.");
+            throw new PoolingException("A null reference was returned to pool.");
         }
         back(pooled, true);
     }
@@ -223,8 +152,7 @@ public class ReentrantLockPool<T> implements Pool<T>, Runnable {
      * @return if the object has been put to pool.
      * @throws PoolingException if the object does not belong to this pool.
      */
-    private boolean back(final T pooled, final boolean decrementActive)
-        throws PoolingException {
+    private boolean back(T pooled, boolean decrementActive) throws PoolingException {
         final long startTime = System.currentTimeMillis();
         // checks
         final PooledData <T> metaData;
@@ -240,8 +168,7 @@ public class ReentrantLockPool<T> implements Pool<T>, Runnable {
         }
         // object of this pool?
         if (null == metaData) {
-            throw new PoolingException("Object \"" + pooled
-                + "\" does not belong to this pool.");
+            throw new PoolingException("Object \"" + pooled + "\" does not belong to this pool.");
         }
         // reuseable?
         boolean poolable;
@@ -254,8 +181,7 @@ public class ReentrantLockPool<T> implements Pool<T>, Runnable {
             if (!poolable) {
                 numBroken++;
             }
-            poolable &= (maxLifeTime <= 0
-                || metaData.getLiveTime() < maxLifeTime);
+            poolable &= (maxLifeTime <= 0 || metaData.getLiveTime() < maxLifeTime);
         } else {
             poolable = false;
         }
@@ -295,9 +221,6 @@ public class ReentrantLockPool<T> implements Pool<T>, Runnable {
         return !destroy;
     }
 
-    /**
-     * {@inheritDoc}
-     */
     public T get() throws PoolingException {
         final long startTime = System.currentTimeMillis();
         while (running) {
@@ -324,8 +247,7 @@ public class ReentrantLockPool<T> implements Pool<T>, Runnable {
                 }
                 retval = data.popIdle();
                 if (null == retval && maxActive > 0 && data.numActive() >= maxActive) {
-                    // now we are getting in trouble. no more idle objects, a
-                    // maximum number of active is defined and we reached this
+                    // now we are getting in trouble. no more idle objects, a maximum number of active is defined and we reached this
                     // border.
                     switch (exhaustedAction) {
                     case GROW:
@@ -333,7 +255,17 @@ public class ReentrantLockPool<T> implements Pool<T>, Runnable {
                     case FAIL:
                         throw new PoolingException("Pool exhausted.");
                     case BLOCK:
-                        boolean timedOut = true;
+                        final String threadName = Thread.currentThread().getName();
+                        boolean writeWarning = System.currentTimeMillis() > (lastWarning + 60000l);
+                        if (writeWarning) {
+                            lastWarning = System.currentTimeMillis();
+                            PoolingException warn = new PoolingException("Thread " + threadName
+                                + " is sent to sleep until an object in the pool is available. " + data.numActive()
+                                + " objects are already in use.");
+                            LOG.warn(warn.getMessage(), warn);
+                        }
+                        final long sleepStartTime = System.currentTimeMillis();
+                        boolean timedOut = false;
                         try {
                             if (maxWait > 0) {
                                 timedOut = !idleAvailable.await(maxWait - getWaitTime(startTime), TimeUnit.MILLISECONDS);
@@ -341,7 +273,12 @@ public class ReentrantLockPool<T> implements Pool<T>, Runnable {
                                 idleAvailable.await();
                             }
                         } catch (InterruptedException e) {
-                            LOG.error("Thread was interrupted.", e);
+                            LOG.error("Thread " + threadName + " was interrupted.", e);
+                        }
+                        if (writeWarning) {
+                            PoolingException warn = new PoolingException("Thread " + threadName + " slept for "
+                                + (System.currentTimeMillis() - sleepStartTime) + "ms.");
+                            LOG.warn(warn.getMessage(), warn);
                         }
                         if (timedOut) {
                             idleAvailable.signal();
@@ -353,23 +290,38 @@ public class ReentrantLockPool<T> implements Pool<T>, Runnable {
                         throw new IllegalStateException("Unknown exhausted action: " + exhaustedAction);
                     }
                 }
-                // create
                 if (null == retval) {
-                    LOG.trace("Creating object.");
-                    final T pooled;
-                    try {
-                        pooled = lifecycle.create();
-                    } catch (Exception e) {
-                        idleAvailable.signal();
-                        throw new PoolingException("Cannot create pooled object.", e);
-                    }
-                    retval = new PooledData<T>(pooled);
-                    data.addActive(retval);
-                    created = true;
+                    data.addCreating();
                 }
             } finally {
                 lock.unlock();
             }
+            // create
+            if (null == retval) {
+                LOG.trace("Creating object.");
+                final T pooled;
+                try {
+                    pooled = lifecycle.create();
+                } catch (Exception e) {
+                    lock.lock();
+                    try {
+                        data.removeCreating();
+                        idleAvailable.signal();
+                    } finally {
+                        lock.unlock();
+                    }
+                    throw new PoolingException("Cannot create pooled object.", e);
+                }
+                retval = new PooledData<T>(pooled);
+                lock.lock();
+                try {
+                    data.addActive(retval);
+                    data.removeCreating();
+                } finally {
+                    lock.unlock();
+                }
+                created = true;
+            }
             // LifeCycle
             if (!lifecycle.activate(retval) || (testOnActivate && !lifecycle.validate(retval))) {
                 lock.lock();
@@ -410,16 +362,10 @@ public class ReentrantLockPool<T> implements Pool<T>, Runnable {
         return System.currentTimeMillis() - startTime;
     }
 
-    /**
-     * {@inheritDoc}
-     */
     public void destroy() {
         running = false;
     }
 
-    /**
-     * {@inheritDoc}
-     */
     public boolean isEmpty() {
         lock.lock();
         try {
@@ -429,9 +375,6 @@ public class ReentrantLockPool<T> implements Pool<T>, Runnable {
         }
     }
 
-    /**
-     * {@inheritDoc}
-     */
     public int getNumIdle() {
         lock.lock();
         try {
@@ -441,9 +384,6 @@ public class ReentrantLockPool<T> implements Pool<T>, Runnable {
         }
     }
 
-    /**
-     * {@inheritDoc}
-     */
     public int getNumActive() {
         lock.lock();
         try {
@@ -453,9 +393,6 @@ public class ReentrantLockPool<T> implements Pool<T>, Runnable {
         }
     }
 
-    /**
-     * {@inheritDoc}
-     */
     public int getPoolSize() {
         lock.lock();
         try {
@@ -465,9 +402,6 @@ public class ReentrantLockPool<T> implements Pool<T>, Runnable {
         }
     }
 
-    /**
-     * @return the number of threads waiting for an object.
-     */
     public int getNumWaiting() {
         lock.lock();
         try {
@@ -477,37 +411,22 @@ public class ReentrantLockPool<T> implements Pool<T>, Runnable {
         }
     }
 
-    /**
-     * {@inheritDoc}
-     */
     public long getMaxUseTime() {
         return maxUseTime;
     }
 
-    /**
-     * {@inheritDoc}
-     */
     public long getMinUseTime() {
         return minUseTime;
     }
 
-    /**
-     * {@inheritDoc}
-     */
     public int getNumBroken() {
         return numBroken;
     }
 
-    /**
-     * {@inheritDoc}
-     */
     public void resetMaxUseTime() {
         maxUseTime = 0;
     }
 
-    /**
-     * {@inheritDoc}
-     */
     public void resetMinUseTime() {
         minUseTime = Long.MAX_VALUE;
     }
@@ -558,10 +477,8 @@ public class ReentrantLockPool<T> implements Pool<T>, Runnable {
     }
 
     /**
-     * Fills the pool that it provides the minimum count of idle object without
-     * exceeding the maximum number objects.
-     * @throws PoolingException if creating an object or putting it to the pool
-     * fails.
+     * Fills the pool that it provides the minimum count of idle object without exceeding the maximum number objects.
+     * @throws PoolingException if creating an object or putting it to the pool fails.
      */
     private void ensureMinIdle() throws PoolingException {
         boolean successfullyAdded = true;
@@ -585,9 +502,6 @@ public class ReentrantLockPool<T> implements Pool<T>, Runnable {
         return back(pooled, false);
     }
 
-    /**
-     * {@inheritDoc}
-     */
     public void run() {
         final long startTime = System.currentTimeMillis();
         if (LOG.isTraceEnabled()) {
@@ -669,9 +583,6 @@ public class ReentrantLockPool<T> implements Pool<T>, Runnable {
         public boolean testThreads;
         public boolean forceWriteOnly;
 
-        /**
-         * Default constructor.
-         */
         public Config() {
             super();
             minIdle = 0;
@@ -680,16 +591,14 @@ public class ReentrantLockPool<T> implements Pool<T>, Runnable {
             maxActive = -1;
             maxWait = 10000;
             maxLifeTime = -1;
-            exhaustedAction = ReentrantLockPool.ExhaustedActions.GROW;
+            exhaustedAction = ExhaustedActions.GROW;
             testOnActivate = true;
             testOnDeactivate = true;
             testOnIdle = false;
             testThreads = false;
             forceWriteOnly = false;
         }
-        /**
-         * {@inheritDoc}
-         */
+
         @Override
         public Config clone() {
             try {
@@ -699,6 +608,7 @@ public class ReentrantLockPool<T> implements Pool<T>, Runnable {
                 throw new Error("Assertion failed!", e);
             }
         }
+
         @Override
         public String toString() {
             final StringBuilder sb = new StringBuilder();
