@@ -28,7 +28,7 @@
  *    http://www.open-xchange.com/EN/developer/. The contributing author shall be
  *    given Attribution for the derivative code and a license granting use.
  *
- *     Copyright (C) 2004-2006 Open-Xchange, Inc.
+ *     Copyright (C) 2004-2010 Open-Xchange, Inc.
  *     Mail: info@open-xchange.com
  *
  *
@@ -227,7 +227,7 @@ public class CompositeSearchTerm implements SearchTerm<SearchTerm<?>> {
     }
 
     public SearchTerm<?>[] getOperands() {
-        return operands.toArray(new SingleSearchTerm[operands.size()]);
+        return operands.toArray(new SearchTerm[operands.size()]);
     }
 
     public Operation getOperation() {
