@@ -61,11 +61,16 @@ import com.openexchange.server.osgiservice.CompositeBundleActivator;
 public class Activator extends CompositeBundleActivator {
 
     private final BundleActivator[] activators = {
+        new com.openexchange.tools.pipesnfilters.osgi.PipesAndFiltersActivator(),
+        new com.openexchange.tools.file.osgi.LocalFileStorageActivator(),
         new com.openexchange.database.osgi.Activator(),
+        new com.openexchange.tools.file.osgi.DBQuotaFileStorageActivator(),
+        new com.openexchange.tools.file.osgi.FileStorageWrapperActivator(),
         new com.openexchange.groupware.update.osgi.Activator(),
         new com.openexchange.groupware.reminder.osgi.Activator(),
         new com.openexchange.server.osgi.ServerActivator(),
-        new com.openexchange.groupware.tasks.osgi.Activator()
+        new com.openexchange.groupware.tasks.osgi.Activator(),
+        new com.openexchange.groupware.infostore.osgi.InfostoreActivator()
     };
 
     public Activator() {
