@@ -112,6 +112,7 @@ import com.openexchange.groupware.calendar.CalendarCollectionService;
 import com.openexchange.groupware.contact.ContactInterfaceDiscoveryService;
 import com.openexchange.groupware.contact.ContactInterfaceProvider;
 import com.openexchange.groupware.contact.datahandler.ContactInsertDataHandler;
+import com.openexchange.groupware.contact.datahandler.ContactJSONDataHandler;
 import com.openexchange.groupware.contact.datasource.ContactDataSource;
 import com.openexchange.groupware.contact.datasource.ContactImageDataSource;
 import com.openexchange.groupware.contact.internal.ContactInterfaceDiscoveryServiceImpl;
@@ -120,6 +121,7 @@ import com.openexchange.groupware.datahandler.ICalJSONDataHandler;
 import com.openexchange.groupware.delete.DeleteListener;
 import com.openexchange.groupware.importexport.importers.ExtraneousSeriesMasterRecoveryParser;
 import com.openexchange.groupware.infostore.InfostoreFacade;
+import com.openexchange.groupware.infostore.osgi.InfostoreActivator;
 import com.openexchange.groupware.notify.hostname.HostnameService;
 import com.openexchange.groupware.reminder.TargetService;
 import com.openexchange.groupware.settings.PreferencesItemService;
@@ -154,12 +156,15 @@ import com.openexchange.multiple.MultipleHandlerFactoryService;
 import com.openexchange.multiple.internal.MultipleHandlerServiceTracker;
 import com.openexchange.passwordchange.PasswordChangeService;
 import com.openexchange.publish.PublicationTargetDiscoveryService;
+import com.openexchange.report.internal.LastLoginRecorder;
 import com.openexchange.resource.ResourceService;
 import com.openexchange.resource.internal.ResourceServiceImpl;
 import com.openexchange.search.SearchException;
 import com.openexchange.search.SearchExceptionFactory;
 import com.openexchange.search.SearchService;
 import com.openexchange.search.internal.SearchServiceImpl;
+import com.openexchange.secret.SecretService;
+import com.openexchange.secret.osgi.tools.WhiteboardSecretService;
 import com.openexchange.server.impl.Starter;
 import com.openexchange.server.impl.Version;
 import com.openexchange.server.osgiservice.BundleServiceTracker;
@@ -230,6 +235,8 @@ public final class ServerActivator extends DeferredActivator {
 
     private Boolean adminBundleInstalled;
 
+    private WhiteboardSecretService secretService;
+
     /**
      * Initializes a new {@link ServerActivator}
      */
@@ -499,6 +506,7 @@ public final class ServerActivator extends DeferredActivator {
         // TODO: Register server's login handler here until its encapsulated in an own bundle
         registrationList.add(context.registerService(LoginHandlerService.class.getName(), new MailLoginHandler(), null));
         registrationList.add(context.registerService(LoginHandlerService.class.getName(), new TransportLoginHandler(), null));
+        registrationList.add(context.registerService(LoginHandlerService.class.getName(), new LastLoginRecorder(), null));
         // Register table creation for mail account storage.
         registrationList.add(context.registerService(CreateTableService.class.getName(), new CreateMailAccountTables(), null));
         // TODO: Register server's mail account storage here until its encapsulated in an own bundle
@@ -549,6 +557,11 @@ public final class ServerActivator extends DeferredActivator {
             props.put(STR_IDENTIFIER, "com.openexchange.contact");
             registrationList.add(context.registerService(DataHandler.class.getName(), new ContactInsertDataHandler(), props));
         }
+        {
+            final Dictionary<Object, Object> props = new Hashtable<Object, Object>();
+            props.put(STR_IDENTIFIER, "com.openexchange.contact.json");
+            registrationList.add(context.registerService(DataHandler.class.getName(), new ContactJSONDataHandler(), props));
+        }
         {
             final Dictionary<Object, Object> props = new Hashtable<Object, Object>();
             props.put(STR_IDENTIFIER, "com.openexchange.ical");
@@ -594,7 +607,10 @@ public final class ServerActivator extends DeferredActivator {
         for (final BundleActivator activator : activators) {
             activator.start(context);
         }
-
+        
+        ServerServiceRegistry.getInstance().addService(SecretService.class, secretService = new WhiteboardSecretService(context));
+        secretService.open();
+        
         /*
          * Register components
          */
@@ -662,6 +678,7 @@ public final class ServerActivator extends DeferredActivator {
              * Clear service registry
              */
             ServerServiceRegistry.getInstance().clearRegistry();
+            secretService.close();
         } finally {
             started.set(false);
             adminBundleInstalled = null;
