@@ -983,7 +983,7 @@ final class OXFolderManagerImpl extends OXFolderManager {
         }
     }
 
-    private final int[] SYSTEM_PUBLIC_FOLDERS = { FolderObject.SYSTEM_PUBLIC_FOLDER_ID, FolderObject.SYSTEM_INFOSTORE_FOLDER_ID };
+    private final int[] SYSTEM_PUBLIC_FOLDERS = { FolderObject.SYSTEM_PUBLIC_FOLDER_ID, FolderObject.SYSTEM_PUBLIC_INFOSTORE_FOLDER_ID };
 
     private static boolean isInArray(final int key, final int[] a) {
         Arrays.sort(a);
@@ -1600,10 +1600,11 @@ final class OXFolderManagerImpl extends OXFolderManager {
                 Links.deleteAllFolderLinks(folderID, ctx.getContextId(), wc);
 
                 final ServerUserSetting sus = ServerUserSetting.getInstance(wc);
-                final Integer collectFolder = sus.getIContactCollectionFolder(ctx.getContextId(), user.getId());
+                final Integer collectFolder = sus.getContactCollectionFolder(ctx.getContextId(), user.getId());
                 if (null != collectFolder && folderID == collectFolder.intValue()) {
-                    sus.setIContactColletion(ctx, session, user.getId(), false);
-                    sus.setIContactCollectionFolder(ctx.getContextId(), user.getId(), null);
+                    sus.setContactCollectOnMailAccess(ctx.getContextId(), user.getId(), false);
+                    sus.setContactCollectOnMailTransport(ctx.getContextId(), user.getId(), false);
+                    sus.setContactCollectionFolder(ctx.getContextId(), user.getId(), null);
                 }
             } catch (final SettingException e) {
                 throw new OXFolderException(e);
