@@ -28,7 +28,7 @@
  *    http://www.open-xchange.com/EN/developer/. The contributing author shall be
  *    given Attribution for the derivative code and a license granting use.
  *
- *     Copyright (C) 2004-2006 Open-Xchange, Inc.
+ *     Copyright (C) 2004-2010 Open-Xchange, Inc.
  *     Mail: info@open-xchange.com
  *
  *
@@ -60,6 +60,11 @@ import javax.servlet.http.HttpServlet;
  */
 public interface IHttpServletManager {
 
+    /**
+     * The init parameter which indicates to enforce servlet registration even though another servlet is associated with same path.
+     */
+    public static final String HTTP_REGISTER_FORCE = "org.osgi.service.http.register.force";
+
     /**
      * Determines the instance of {@link HttpServlet} that corresponds to given path; e.g. <code>/servlet/path</code>
      * 
